<?php
include("includes/social_counter_widget.php");

class Affilo_Avenue {
	
	private $hooks = array(
		"init" => array(
			"init_theme_options"
		),
		"affilo_primary_nav_extras" => array(
			"admin_nav_extras"
		),
		"affilo_secondary_nav_extras" => array(
			"admin_nav_extras"
		),
		"affilo_primary_nav_positions" => array(
			"admin_nav_positions"
		),
		"affilo_secondary_nav_positions" => array(
			"admin_nav_positions"
		),
		"before_affilo_navigation_settings_init" => array(
			"navigation_settings_init"
		),
		"affilo_init" => array(
			"remove_layouts_style"
		),
		"affilo_page_title_container" => array(
			"page_title_container"
		),
		"affilo_default_page_title" => array(
			"default_page_title"
		),
		"affilo_breadcrumb_output" => array(
			"breadcrumb_output"
		),
		"affilo_theme_after_init_population" => array(
			"theme_init_population"
		),
		"affilo_widget_tabbed_posts_header" => array(
			"widget_tabbed_posts_header"
		)
	);
	
	public function getHooks() {
		return $this->hooks;
	}
	
	static function init() {
		global $_affilo_subtheme_instance;
		if(!$_affilo_subtheme_instance) {
			$class = __CLASS__;
			$_affilo_subtheme_instance = new $class;
		}
		$_affilo_subtheme_instance->init_hooks();
		return $_affilo_subtheme_instance;
	}
	
	function init_hooks() {
		do_action("Affilo_Avenue_before_init_hooks");
		foreach($this->getHooks() as $hook => $callbacks) {
			do_action("Affilo_Avenue_before_add_hook_".$hook);
			foreach((array)$callbacks as $callback) {
				if(method_exists($this,$callback)) {
					add_action($hook, array($this, $callback));
				}
			}
			do_action("Affilo_Avenue_after_add_hook_".$hook);
		}
		do_action("Affilo_Avenue_after_init_hooks");
	}
	
	function init_theme_options() {
		remove_action('affilo_footer', 'affilo_footer_left_right', 15);
	}
	
	function admin_nav_extras() {
		return array(
			'disabled' => __('Disabled', 'affilo')
		);
	}
	
	function admin_nav_positions() {
		return array(
			'affilo_before_header' => __('Before Header', 'affilo'),
			'affilo_after_header' => __('After Header', 'affilo'),
		);
	}
	
	function remove_layouts_style() {
		wp_deregister_style("layouts");
	}
	
	function page_title_container() {
		return "h3";
	}
	
	function default_page_title($content) {
		$tag = "</".$this->page_title_container().">";
		return str_replace($tag,"<span class=\"arrows\">&raquo;</span>{$tag}",$content);
	}
	
	function breadcrumb_output() {
		return "";
	}
	
	function navigation_settings_init($instance) {
		if(isset($instance->options['footer_nav'])) {
			unset($instance->options['footer_nav']);
		}
		if(isset($instance->options['div2'])) {
			unset($instance->options['div2']);
		}
	}
	
	function theme_init_population() {
		$affilo_options = array(
			"secondary_nav" => "pages",
				"secondary_nav-depth" => "1",
				"secondary_nav-position" => "affilo_before_header"
		);
	
		foreach($affilo_options as $key => $val) {
			affilo_update_option($key, $val);
		}
		
		$new_sidebars_widgets = array(
			"primary_widget_area" => array(
				"text-2" => array(
					"widget_text" => array(
						2 => array(
							"title"			=> "Find us on Facebook",
							"text" 			=> '<iframe src="//www.facebook.com/plugins/likebox.php?href=http%3A%2F%2Fwww.facebook.com%2Faffilorama&amp;width=300&amp;height=395&amp;colorscheme=light&amp;show_faces=false&amp;border_color&amp;stream=true&amp;header=false&amp;appId=116571678448067" scrolling="no" frameborder="0" style="border:none; overflow:hidden; width:300px; height:395px;" allowTransparency="true"></iframe>'
						),
						"_multiwidget" 	=> 1
					)
				),
				"affilo_tabbed_posts-3" => array(
					"widget_affilo_tabbed_posts" => array(
						3 => array(),
						"_multiwidget" 	=> 1
					)
				),
				"affilo_social_counter-widget-2" => array(
					"widget_affilo_social_counter-widget" => array(
						2 => array(
							"twitter_id" 	=> "affilorama",
							"fb_id" 		=> "affilorama"
						),
						"_multiwidget" 	=> 1
					)
				),
				"search-widget-2" => array(
					"widget_search-widget" => array(
						2 => array(
							"title" 		=> "",
							"search-input" 	=> "Search",
							"search-button" => "Search"
						),
						"_multiwidget" 	=> 1
					)
				)
			),
			"footer_widget_area_1" => array(
				"recent-comments-2"
			),
			"footer_widget_area_2" => array(
				"archives-2"
			),
			"footer_widget_area_3" => array(
				"text-3" => array(
					"widget_text" => array(
						3 => array(
							"title"			=> "About",
							"text" 			=> '<p>Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.</p>'
						),
						"_multiwidget" 	=> 1
					)
				)
			)
		);
		
		Affilo::populate_sidebars_widgets($new_sidebars_widgets);
		
		if($slide = array_pop(get_posts(array("post_type"=>"slideshow")))) {
			$vars = array(
				"size" => "min",
				"size_custom" => array(
					"width" => "620",
					"height" => "280"
				),
				"size_min" => array(
					"width" => "620",
					"height" => "280"
				),
				"size_max" => array(
					"width" => "620",
					"height" => "280"
				)
			);
			foreach($vars as $key => $val) {
				update_post_meta($slide->ID, $key, $val);
			}
		}
	}
	
	function widget_tabbed_posts_header() {
	return <<<HTML

	<div id="recentpoststab" class="single-tab active-tab"><div class="tab-inner-glow widget-title">Posts</div><!--glow--></div>
	<div id="popularpoststab" class="single-tab"><div class="tab-inner-glow widget-title">Popular</div><!--glow--></div>
	<div id="commentstab" class="comment-tab single-tab"><div class="tab-inner-glow widget-title">Comments</div><!--glow--></div>
	<div class="clear"></div>

HTML;
	}
	
}

Affilo_Avenue::init();


/** comments template view **/
function avenue_comment($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment; ?>
	<li <?php comment_class(); ?> id="comment-<?php comment_ID() ?>">
		<div class="the-comment">
			<?php echo get_avatar($comment,$size='60'); ?>
			<div class="comment-arrow"></div>
			<div class="comment-box">
				<div class="comment-author">
					<strong><?php echo get_comment_author_link() ?></strong>
					<small><?php printf(__('%1$s at %2$s', 'Avenue'), get_comment_date(),  get_comment_time()) ?></a><?php edit_comment_link(__('Edit'),'  ','') ?> - <?php comment_reply_link(array_merge( $args, array('reply_text' => 'Reply', 'add_below' => $add_below, 'depth' => $depth, 'max_depth' => $args['max_depth']))) ?></small>
				</div>
				<div class="comment-text">
					<?php if ($comment->comment_approved == '0') : ?>
					<em><?php _e('Your comment is awaiting moderation.', 'Avenue') ?></em>
					<br />
					<?php endif; ?>
					<?php comment_text() ?>
				</div>
			</div>
		</div>
<?php }