<?php
include("includes/glide-twitter-widget.php");

/**
 * Initialize Glide theme
 */

function affilo_glide_init() {
	//remove the dfeault split footer content, this is embedded direct in footer.php
	remove_action( 'affilo_footer', 'affilo_footer_left_right', 15);
	
	//filter the primary & secondary menus to modify markeup slightly
	add_filter('affilo_primary_nav_menu', 'affilo_glide_nav_menu_filter');
	add_filter('affilo_secondary_nav_menu', 'affilo_glide_nav_menu_filter');
	
	//remove default breadcrumb placement, this is embedded direct in header.php
	remove_action( 'affilo_before_content', 'affilo_breadcrumbs', 15 );
	
	//filter page title to add Home as default text o the title bar
	add_filter('affilo_default_page_title', 'affilo_glide_page_title');
	
	add_filter( 'affilo_nav_social_images_size', create_function(null, 'return 16;') );
	
	add_action( 'after_setup_theme', 'affilo_glide_includes', 20 );
	
	remove_action('comment_form_top', 'affilo_insert_comment_form');
	
	add_action('affilo_theme_after_init_population', "affilo_glide_init_population");
	
	add_action("affilo_social_images_url", "glide_social_images_url");
	
// 	add_action('admin_menu', 'affilo_glide_menu', 15);
	add_action("affilo_widget_tabbed_posts_header", "affilo_glide_widget_tabbed_posts_header");
}

/*
 * Add action hook to affilo init to intialize glide theme
 */
add_action('affilo_init', 'affilo_glide_init');


function affilo_glide_includes() {
	$path = get_stylesheet_directory() . '/includes/';
	require_once $path . 'admin/glide.php';
}

function glide_social_images_url() {
	return get_stylesheet_directory_uri()."/images/social/";
}

function affilo_glide_menu(){
	add_submenu_page( 'affilo_admin', __('Glide Settings', 'affilotheme'), __('Glide Settings', 'affilotheme'), 'manage_options', 'affilo_glide_settings', 'affilo_glide_settings');
}

/**
 * Filter primary and secondary nav menus to insert required markup for this theme
 * 
 * @param string $menu menu markup formatted
 * @return string $menu filtered
 */
function affilo_glide_nav_menu_filter($menu) {
	$menu = str_replace(array(
		'</a>',
		'<div class="nav'
	), array(
		'<span class="left"></span></a>',
		'<div class="nav-main nav'
	), $menu);
	return $menu;
}

/**
 * Filters page title to set the default tile to 'Home' if it is not a page.
 * As this theme embeds the page title in the nheader this function also
 * returns a completely empty title on all subsequent calls. This removes the
 * need to remove the title call from all `single` templates.
 * 
 * @param string $title
 * @return string
 */
function affilo_glide_page_title($title) {
	static $called = false;
	if ($called) {
		return '';
	}
	if (is_front_page() && preg_match('/\>\</', $title)) {
		$text = 'Home';
		$title = str_replace('><', ">$text<", $title);
	}
	$called = true;
	return $title;
}


function glide_comment($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment;
?>
<li <?php comment_class(); ?> id="li-comment-<?php comment_ID() ?>">
	<div class="single-comment" id="comment-<?php comment_ID(); ?>">
		<div class="avatar-img">
			<?php echo get_avatar($comment, $size = '55', $default = '' ); ?>			
		</div><!--avatar-img-->
		<div class="comment_content">
			<span class="author_name"><?php echo comment_author_link(); ?></span> 
			<span class="comment-date">on <?php comment_date(); ?></span>
			<?php  edit_comment_link(__('(Edit)', 'affilo'),'  ','') ?>
			<div class="comment_text">
				<?php if ($comment->comment_approved == '0') : ?>
					<em><?php _e('Your comment is awaiting moderation.', 'affilo') ?></em>
				<?php endif; ?>
				<?php comment_text() ?>
				<?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
			</div><!--comment_text-->
		</div><!--comment_content-->
	<div class="clear"></div>
	</div>
	<div class="clear"></div>	
<?php
}


function affilo_glide_init_population() {
	
	$affilo_options = array(
		"primary_nav" 				=> "pages",
		"primary_nav-enable-home"	=> "true",
		"primary_nav-extras" 		=> "none",
		"home_layout" 				=> "two-col-right",
		"layout" 					=> "two-col-right",
		"secondary_nav" 			=> "none",
		"footer_nav"				=> "none"
	);
	
	foreach($affilo_options as $key => $val) {
		affilo_update_option($key, $val);
	}
	
	$new_sidebars_widgets = array(
		"primary_widget_area" => array(
			"affilo_tabbed_posts-3" => array(
				"widget_affilo_tabbed_posts" => array(
				3 => array(),
					"_multiwidget" 	=> 1
				)
			),
			"text-2" => array(
				"widget_text" => array(
					2 => array(
						"title"			=> "Advertisement",
						"text" 			=> '<p style="text-align:center;"><a href="http://www.affilorama.com/"><img src="'.get_template_directory_uri().'/images/theme_assets/logo-180.png" alt="default logo" /></a></p>'
					),
					"_multiwidget" 	=> 1
				)
			),
			"search-widget-2" => array(
				"widget_search-widget" => array(
					2 => array(
						"title" 		=> "",
						"search-input" 	=> "Search",
						"search-button" => "Search"
					),
					"_multiwidget" 	=> 1
				)
			)
		),
		"footer_widget_area_1" => array(
			"stay-connected-widget-2" => array(
				"widget_stay-connected-widget" => array(
					2 => array(
						"title" 		=> "Stay Connected",
						"intro" 		=> "",
						"rss" 			=> null,
						"comment_rss" 	=> null,
						"twitter" 		=> "twitter-user",
						"facebook"		=> "facebook-user",
						"delicious" 	=> "delicious",
						"flickr" 		=> "flickr",
						"youtube" 		=> "",
						"vimeo" 		=> "vm",
						"digg" 			=> "digg",
						"linkedin" 		=> "li",
						"linksopen" 	=> "",
						"display" 		=> "icon"
					),
					"_multiwidget" 	=> 1
				)
			),
			"text-3" => array(
				"widget_text" => array(
					3 => array(
						"title"			=> "About this site",
						"text" 			=> '<p>Glide is a fresh new theme suited for business and portfolio sites. It gives you the power to customize it to your hearts content without touching the template files at all</p>'
					),
					"_multiwidget" 	=> 1
				)
			),
		),
		"footer_widget_area_2" => array(
			"glide_twitter_widget-5" => array(
				"widget_glide_twitter_widget" => array(
					5 => array(
						"title" => "Twitter News",
						"twitter_id" => "Affilorama",
						"no_tweets" => "3"
					),
					"_multiwidget" 	=> 1
				)
			)
		),
		"footer_widget_area_3" => array(
			"archives-2",
			"recent-comments-2"
		),
		"footer_widget_area_4" => array(
			
		)
	);
	
	Affilo::populate_sidebars_widgets($new_sidebars_widgets);
	
	if($slide = array_pop(get_posts(array("post_type"=>"slideshow")))) {
		$vars = array(
			"size" => "min",
			"size_custom" => array(
				"width" => "600",
				"height" => "250"
			),
			"size_min" => array(
				"width" => "600",
				"height" => "250"
			),
			"size_max" => array(
				"width" => "600",
				"height" => "250"
			)
		);
		foreach($vars as $key => $val) {
			update_post_meta($slide->ID, $key, $val);
		}
	}
	
	if(get_option('show_on_front', false) == "page") {
		$hp_id = get_option('page_on_front');
		if($hp = get_page($hp_id)) {
			$hp->post_content .= <<<HTML
[one_half]<div class="icon-feature"><div class="icon-heading"><img class="icon" src="http://i.imgur.com/SYL7v.png"/><h4 class="feature-heading">Lorem Ipsum</h4><div class="clear"></div></div><!--icon-heading--><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Mauris nibh lorem, venenatis ac venenatis placerat, sodales id.</p></div><div class="icon-feature"><div class="icon-heading"><img class="icon" src="http://i.imgur.com/E1ONn.png"><h4 class="feature-heading">Donec commodo</h4><div class="clear"></div></div><!--icon-heading--><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec commodo diam at turpis tincidunt in tincidunt arcu metus.</p></div>[/one_half][one_half_last]<div class="icon-feature"><div class="icon-heading"><img class="icon" src="http://i.imgur.com/5soDE.png"/><h4 class="feature-heading">Quisque volutpat</h4><div class="clear"></div></div><!--icon-heading--><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Quisque volutpat quam id nibh ornare a tempus mauris cras amet.</p></div><div class="icon-feature"><div class="icon-heading"><img class="icon" src="http://i.imgur.com/8Q6M7.png"/><h4 class="feature-heading">Cras quam tellus</h4><div class="clear"></div></div><!--icon-heading--><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Cras quam tellus, accumsan sit amet tempus non, ultrices metus.</p></div>[/one_half_last]
HTML;
			wp_update_post($hp);
		}
		
	}	
}

function affilo_glide_widget_tabbed_posts_header() {
	return <<<HTML

	<div id="recentpoststab" class="single-tab active-tab"><div class="tab-inner-glow"><span>Recent</span><span> Posts</span></div><!--glow--></div>
	<div id="popularpoststab" class="single-tab"><div class="tab-inner-glow"><span>Popular</span><span> Posts</span></div><!--glow--></div>
	<div id="commentstab" class="comment-tab single-tab"><div class="tab-inner-glow">Comments</div><!--glow--></div>
	<div class="clear"></div>

HTML;
}

?>