<?php

add_action('widgets_init', 'seventeen_twitter_widget_init');

function seventeen_twitter_widget_init() {
	register_widget( 'Seventeen_Twitter_Widget' );
}

class Seventeen_Twitter_Widget extends WP_Widget {
	
	function Seventeen_Twitter_Widget() {
		$widget_ops = array('classname' => 'widget_twitter', 'description' => 'A widget to display latest tweets from a username.');
		$control_ops = array('id_base' => 'twitter-widget' );
		$this->WP_Widget( 'twitter-widget', 'AffiloTheme Twitter Feed', $widget_ops, $control_ops );
	}

	function widget($args, $instance) {
		global $wpdb;
		extract($args);

		$title = apply_filters('widget_title', $instance['title']);
		$limit = ($instance['count']) ? $instance['count'] : 3;
		$output = '';

		echo $before_widget;

		if($title)
			echo $before_title . $title . $after_title;	
		
		if (isset($instance['username'])) {
			
			$trans_name = __CLASS__.md5($instance['username'].$instance['limit']);
			
			if(!$json = get_transient($trans_name)) {
				@$api = wp_remote_get('https://api.twitter.com/1/statuses/user_timeline.json?screen_name='.$instance['username'].'&count='.$limit);
				@$json = $api['body'];
				set_transient($trans_name, $json, 600);
			}
			$stream = json_decode($json);
			if (isset($stream->errors)) {
				$stream = false;
			}
			
			if ($stream) {
				$output = '<ul class="clearfix">';
				$linkbase = "https://twitter.com/{$instance['username']}/statuses/";
				foreach ($stream as $item) {
					$tweet_text = $item->text;
					$tweet_text = html_entity_decode( $tweet_text );
					$tweet_text = str_replace( "&#8211;", "&mdash;", $tweet_text );
					$tweet_text = preg_replace( "/(http:\/\/|(www\.))(([^\s<]{4,68})[^\s<]*)/", '<a href="http://$2$3" target="_blank">$1$2$4</a>', $tweet_text);
					$tweet_text = preg_replace( "/@(\w+)/", "<a href=\"http://www.twitter.com/\\1\" target=\"_blank\">@\\1</a>", $tweet_text);
					$tweet_text = preg_replace( "/#(\w+)/", "<a href=\"http://search.twitter.com/search?q=\\1\" target=\"_blank\">#\\1</a>", $tweet_text);
					$tweet_link = $linkbase.$item->id;
					$tweet_time = strtotime($item->created_at);
					$tweet_time = human_time_diff( $tweet_time, current_time('timestamp') );
					
					$output .= '<li class="clearfix"><span class="tweet-content">'.$tweet_text.
						'</span><span class="tweet-meta"><a href="'.$tweet_link. '">'.$tweet_time.' ago</a></li>';
				}
				$output .= '</ul>';
			} else { echo '<p>There are no tweets to be displayed at this time. Try again later.</p>'; }
			echo $output;
		} else {
			echo '<p>There are no tweets to display because no username has been entered.</p>';
		}	
		echo $after_widget;
	}

	
	function update($new_instance, $old_instance) {
		$instance = $old_instance;

		$instance['title'] = strip_tags($new_instance['title']);
		$instance['username'] = strip_tags($new_instance['username']);
		$instance['count'] = strip_tags($new_instance['count']);		

		return $instance;
	}
	
	
	function form( $instance ) {

		$defaults = array( 'title' => 'Latest from the Twitter Feed', 'username' => '', 'count' => '5');
		$instance = wp_parse_args((array) $instance, $defaults ); ?>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>">Title:</label>
			<input type="text" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>"  class="widefat"/>
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'username' ); ?>">Twitter Username:</label>
			<input type="text" id="<?php echo $this->get_field_id( 'username' ); ?>" name="<?php echo $this->get_field_name( 'username' ); ?>" value="<?php echo $instance['username']; ?>"  class="widefat"/>
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'count' ); ?>">Number of tweets:</label>
			<input type="text" id="<?php echo $this->get_field_id( 'count' ); ?>" name="<?php echo $this->get_field_name( 'count' ); ?>" value="<?php echo $instance['count']; ?>"  class="widefat"/>
		</p>
		
		<?php
	}
	
}

?>