<?php
/**
 * Initialize Super Massive theme
 */
function affilo_supermassive_init() {
	remove_action( 'affilo_footer', 'affilo_footer_left_right', 15);
	
	add_filter('affilo_breadcrumb_params', 'affilo_supermassive_breadcrumb_params');
	
	add_filter( 'affilo_nav_social_images_size', create_function(null, 'return 16;') );
	
	add_action( 'after_setup_theme', 'affilo_supermassive_includes', 20 );
	
	add_action('affilo_theme_after_init_population', "affilo_supermassive_init_population");
	
	add_action("affilo_widget_tabbed_posts_header", "affilo_supermassive_widget_tabbed_posts_header");
}

/*
 * Add action hook to affilo init to intialize glide theme
 */
add_action('affilo_init', 'affilo_supermassive_init');

function affilo_supermassive_includes() {
	$path = get_stylesheet_directory() . '/includes/';
	require_once $path . 'admin/supermassive.php';
}

function affilo_supermassive_breadcrumb_params($params) {
	$params['seperator'] = '/';
	return $params;
}


function affilo_supermassive_init_population() {
	
	$affilo_options = array(
		"primary_nav" 				=> "pages",
		"primary_nav-enable-home"	=> "true",
		"primary_nav-extras" 		=> "search",
		"home_layout" 				=> "two-col-right",
		"layout" 					=> "two-col-right",
		"secondary_nav" 			=> "none"
	);
	
	foreach($affilo_options as $key => $val) {
		affilo_update_option($key, $val);
	}
	
	
	
	$new_sidebars_widgets = array(
		"primary_widget_area" => array(
			"text-2" => array(
				"widget_text" => array(
					2 => array(
						"title"			=> "Advertisement",
						"text" 			=> '<p><a href="http://www.affilorama.com/"><img src="'.get_template_directory_uri().'/images/theme_assets/logo-180.png" alt="default logo" /></a></p>'
					),
					"_multiwidget" 	=> 1
				)
			),
			"affilo_tabbed_posts-3" => array(
				"widget_affilo_tabbed_posts" => array(
				3 => array(),
					"_multiwidget" 	=> 1
				)
			),
			"categories-3" => array(
				"widget_categories"		=> array(
					3 => array(
						"title" 		=> "Categories",
						"count" 		=> 0,
						"hierarchical" 	=> 0,
						"dropdown"		=> 0
					),
					"_multiwidget" 	=> 1
				)
			)
		),
		"footer_widget_area_1" => array(
			"recent-posts-2" //just moves the existing instance
		),
		"footer_widget_area_2" => array(
			"categories-2"
		),
		"footer_widget_area_3" => array(
			"archives-2"
		),
		"footer_widget_area_4" => array(
			"text-3" => array(
				"widget_text" => array(
					3 => array(
						"title"			=> "",
						"text" 			=> '<p><img src="'.get_template_directory_uri().'/images/theme_assets/logo-180.png" alt="default logo" /></p><p>Welcome to the Supermassive theme. You can edit this widget to provide any content you like.</p>'
					),
					"_multiwidget" 	=> 1
				)
			)
		)
	);
	
	Affilo::populate_sidebars_widgets($new_sidebars_widgets);
	
	if($slide = array_pop(get_posts(array("post_type"=>"slideshow")))) {
		$vars = array(
			"size" => "min",
			"size_custom" => array(
				"width" => "660",
				"height" => "280"
			),
			"size_min" => array(
				"width" => "660",
				"height" => "280"
			),
			"size_max" => array(
				"width" => "660",
				"height" => "280"
			)
		);
		foreach($vars as $key => $val) {
			update_post_meta($slide->ID, $key, $val);
		}
	}
	
	if(get_option('show_on_front', false) == "page") {
		$hp_id = get_option('page_on_front');
		
		if($hp = get_page($hp_id)) {
			
			$images = glob(get_template_directory()."/images/theme_assets/photos/*");
			
			$image_uri = get_template_directory_uri()."/images/theme_assets/photos/".basename($images[array_rand($images)]);
			$img_src = affilo_timthumb($image_uri, 417);
			
			$hp->post_content .= <<<HTML
[one_third]

There are many variations of passages of Lorem Ipsum available, but the majority have suffered alteration in some form, by injected humour, or randomised words which don't look even slightly believable. If you are going to use a passage of Lorem Ipsum, you need to be sure there isn't anything embarrassing hidden in the middle of text. All the Lorem Ipsum generators on the Internet tend to repeat predefined chunks as necessary, making this the first true generator on the Internet.

[/one_third]

[two_thirds_last]
<img src="{$img_src}" alt="sample image" />

[/two_thirds_last]

HTML;
			wp_update_post($hp);
		}
		
	}
}

function affilo_supermassive_widget_tabbed_posts_header() {
	return <<<HTML

	<div id="recentpoststab" class="single-tab active-tab"><div class="tab-inner-glow">Posts</div><!--glow--></div>
	<div id="popularpoststab" class="single-tab"><div class="tab-inner-glow">Popular</div><!--glow--></div>
	<div id="commentstab" class="comment-tab single-tab"><div class="tab-inner-glow">Comments</div><!--glow--></div>
	<div class="clear"></div>

HTML;

}

?>