<?php
/**
 * Authenticate and setup required FlashVars for the HeaderCreator swf
 * Will load previous settings from options, or default to those passed in
 * 
 * @param array $query $_GET
 * @param string $target
 * @param string $verifyNonceAction
 * @param string $verifyNonceKey
 * @return array flash vars to pass to creator
 */
function affilo_hc_setup($query, $target, $verifyNonceAction, $verifyNonceKey){
	check_admin_referer($verifyNonceAction, $verifyNonceKey);
	$flashVars = affilo_hc_load_settings();
	if (!$flashVars) {
		$flashVars = affilo_hc_create_flash_vars($query);
	}
	if ($themeOverides = affilo_hc_get_theme_vars()) {
		$flashVars = $themeOverides + $flashVars;
	}
	$flashVars = array_map('stripslashes', $flashVars);
	$q = strpos($target, '?') === false ? '?' : '&';
	$nonce = wp_create_nonce($verifyNonceAction);
	$flashVars['target'] = get_bloginfo('url') . "{$target}{$q}{$verifyNonceKey}={$nonce}";
	return $flashVars;
}

/**
 * Authenticate and process the images from the HeaderCreator swf
 * 
 * @param array $request $_POST
 * @param array $query $_GET
 * @param string $verifyNonceAction
 * @param string $verifyNonceKey
 * @return string json response
 */

function affilo_hc_process($request, $query, $verifyNonceAction, $verifyNonceKey){
	$verified = isset($query[$verifyNonceKey]);// && wp_verify_nonce($query[$verifyNonceKey], $verifyNonceAction);
	//var_dump($verified);
	$verified = true;
	// Is this for a bg/stock image, or header image insert?
	if (isset($_GET['folder']) && !empty($_FILES)) {
		$result = @affilo_hc_process_custom_image($verified);
	} else {
		$result = @affilo_hc_process_image($request, $verified);
	}
	if (!$result) {
		$result = affilo_hc_new_image_response();
		$result['status'] = affilo_hc_process_error('error');
	}
	$result['data'] = json_encode($result['data']);
	return json_encode($result);
}


/**
 * Get key for storing header creator options as WP option
 * 
 * @return string options key
 */
function affilo_hc_settings_option_key(){
	return 'affilo_header_creator_settings';
}

/**
 * Get variables passed through to the HeaderCreator swf via FlashVars, used to map, populate &
 * validate passed variables from form values in AffiloTheme options
 * 
 * Each key of this array is an incoming varaible name, that is mapped to `var`
 * preg_match'd against `match` and set to default if this fails or varibale was not passed
 * 
 * @return array
 */
function affilo_hc_flash_vars(){
	$flashVars = array(
		'ddm_page_width' => array(
			'var' => 'width',
			'match' => '/^([1-9]|[1-9][0-9]|[1-9](?<!96)[0-9](?<!96)[0-9]|960)$/',
			'default' => 960
		),
  		'ddm_header_height' => array(
			'var' => 'height',
			'match' => '/^([1-9]|[1-9][0-9]|1(?<!15)[0-9](?<!15)[0-9]|150)$/',
			'default' => 150
		),
  		'ddm_header_bg' => array(
			'var' => array('background_bottom_color', 'background_top_color'),
			'match' => '/^#?([a-f]|[A-F]|[0-9]){3}(([a-f]|[A-F]|[0-9]){3})?$/',
			'default' => '#FFFFFF'
		),
  		'ddm_title' => array(
			'var' => 'top_text',
			'match' => '/\w+/',
			'default' => 'Header Text'
		),
  		'ddm_title_color' => array(
			'var' => 'top_text_color',
			'match' => '/^#?([a-f]|[A-F]|[0-9]){3}(([a-f]|[A-F]|[0-9]){3})?$/',
			'default' => '#000000'
		),
		'ddm_tagline' => array(
			'var' => 'bottom_text',
			'match' => '/\w+/',
			'default' => 'Tagline Text'
		),
		'ddm_tagline_color' => array(
			'var' => 'bottom_text_color',
			'match' => '/^#?([a-f]|[A-F]|[0-9]){3}(([a-f]|[A-F]|[0-9]){3})?$/',
			'default' => '#000000'
		)
	);
	return $flashVars;
}

/**
 * Response error strings returned in the key `status` from affilo_hc_process_image()
 * 
 * @param string $error optional key
 * @return string error
 */
function affilo_hc_process_error($error = 'error'){
	$processErrors = array(
		'unverified' => 'request was not correctly verified', //request was not correctly verfied
		'invalid' => 'request did not contain all required data', 	//request did not conaint all required data
		'corrupt' => 'image data is corrupt', 	//image data is corrupt
		'upload' => 'upload directory not writable', 	//upload directoy not writable
		'error' => 'There has been an unidentified error, please try again.'
	);
	return isset($processErrors[$error]) ? $processErrors[$error] : $processErrors['error'];
}

/**
 * Get expected variable keys from request containing image data from the HeaderCreator swf
 * 
 * Each key of this array is an incoming varaible name, that is mapped to `var`
 * preg_match'd against `match`
 * 
 * @return array
 */
function affilo_hc_process_vars(){	
	$processVars = array(
		'image' => array(
			'var' => 'ddm_header_bg_image',
			'match' => '/\w+/'
		),
		'width' => array(
			'var' => 'ddm_page_width',
			'match' => '/^([1-9]|[1-9][0-9]|[1-9](?<!96)[0-9](?<!96)[0-9]|960)$/'
		),
  		'height' => array(
			'var' => 'ddm_header_height',
			'match' => '/^([1-9]|[1-9][0-9]|1(?<!15)[0-9](?<!15)[0-9]|150)$/'
		),
		'background_top_color' => array(
			'var' => 'dm_header_bg',
			'match' => '/^.*$/'
		),
		'background_bottom_color' => array(
			'var' => 'dm_header_bg_',
			'match' => '/^.*$/'
		),
		'top_text' => array(
			'var' => 'ddm_title',
			'match' => '/^.*$/'
		),
		'top_text_color' => array(
			'var' => 'ddm_title_color',
			'match' => '/^.*$/'
		),
		'bottom_text' => array(
			'var' => 'ddm_tagline',
			'match' => '/^.*$/'
		),
		'bottom_text_color' => array(
			'var' => 'ddm_tagline_color',
			'match' => '/^.*$/'
		),
		'background_patterns' => array(
			'var' => 'ddm_background_patterns',
			'match' => '/^.*$/'
		),
		'small_font_size' => array(
			'var' => 'ddm_small_font_size',
			'match' => '/^.*$/'
		),
		'large_font_size' => array(
			'var' => 'ddm_large_font_size',
			'match' => '/^.*$/'
		),
		'small_font_family' => array(
			'var' => 'ddm_small_font_family',
			'match' => '/^.*$/'
		),
		'large_font_family' => array(
			'var' => 'ddm_large_font_family',
			'match' => '/^.*$/'
		),
		'background_alpha' => array(
			'var' => 'ddm_background_alpha',
			'match' => '/^.*$/'
		),
		'small_x' => array(
			'var' => 'ddm_small_x',
			'match' => '/^.*$/'
		),
		'small_y' => array(
			'var' => 'ddm_small_y',
			'match' => '/^.*$/'
		),
		'large_x' => array(
			'var' => 'ddm_large_x',
			'match' => '/^.*$/'
		),
		'large_y' => array(
			'var' => 'ddm_large_y',
			'match' => '/^.*$/'
		),
		'stocks_x' => array(
			'var' => 'ddm_stocks_x',
			'match' => '/^.*$/'
		),
		'stocks_y' => array(
			'var' => 'ddm_stocks_y',
			'match' => '/^.*$/'
		),
		'stock_images' => array(
			'var' => 'ddm_stock_images',
			'match' => '/^.*$/'
		),
		'text_size' => array(
			'var' => 'ddm_text_size',
			'match' => '/^.*$/'
		),
		'text_style' => array(
			'var' => 'ddm_text_style',
			'match' => '/^.*$/'
		)
	);
	return $processVars;
}

/**
 * Formats FlashVars for the HeaderCreator swf as per affilo_hc_flash_vars()
 * 
 * @param array $request current request containing flashvars
 * @return array formatted full flash vars
 */
function affilo_hc_create_flash_vars($request){
	$flashVars = array();
	$_flashVars = affilo_hc_flash_vars();
	foreach ($_flashVars as $expected => $params) {
		$vars = is_array($params['var']) ? $params['var'] : array($params['var']);
		$value = $params['default'];
		if (isset($request[$expected]) && preg_match($params['match'], $request[$expected])) {
			$value = $request[$expected];	
		}
		$flashVars += array_fill_keys($vars, $value);
	}
	foreach (array('background_top_color', 'background_bottom_color', 'top_text_color', 'bottom_text_color') as $color) {
		$hex = affilo_hc_normalize_hex_color($flashVars[$color]);
		//White background bad, change
		if (($color == 'background_top_color' || $color == 'background_bottom_color') && $hex == 'FFFFFF') {
			$hex = '000000';
		}
		//ensure contrasting colors for text & background
		if ($color == 'top_text_color' || $color == 'bottom_text_color') {
			if($flashVars['background_top_color'] == "#$hex"){
				$hex = affilo_hc_hex_opposite($hex);
			}
		}
		$flashVars[$color] = "#$hex";
	}
	return $flashVars;
}

/**
 * Load options from a themes options file to be used as persistent options
 * to overide any settings used for the HC.
 */
function affilo_hc_get_theme_vars() {
	$themeVars = array();
	if ($options = affilo_get_options_file(array(), get_current_theme())) {
		$map = array(
			'max-logo-height' => 'maxheight',
			'max-logo-width' => 'maxwidth'
		);
		if ($options = array_intersect_key($options, $map)) {
			foreach ($options as $key => $value) {
				if (is_numeric($value)) {
					$var = $map[$key];
					$themeVars[$var] = $value;
				}
			}
		}	
	}
	return $themeVars;
}

/**
 * Processes incoming header data request from the HeaderCreator swf. If request conatins key 
 * `image` conataingin image data process this data and save to file
 * 
 * @param array $request request vars  ($_REQUEST | $_POST)
 * @param boolean $verified Request has been verified, must be true to process
 * @return object affilo_hc_new_image_respone() with status set & data on success
 */
function affilo_hc_process_image($request, $verified){
	$result = affilo_hc_new_image_response();
	if ($verified) {
		$request = affilo_hc_validate_image_request($request);
		if ($request) {
			affilo_hc_store_settings($request);
			if (!isset($request['image'])) {
				$result['status'] = 'success';
			} else {
				$imageData = affilo_hc_prepare_image_data($request['image']);
				if ($imageData) {
					$imagePaths = affilo_hc_save_image_to_file($imageData);
					if ($imagePaths) {
						$result['status'] = 'success';
						$result['data'] = affilo_hc_prepare_image_response($imagePaths, $request);
					} else { 
						$result['status'] = 'upload';
					}
				} else {
					$result['status'] = 'corrupt';
				}
			}
		} else {
			$result['status'] = 'invalid';
		}
	} else {
		$result['status'] = 'unverified';
	}
	if ($result['status'] != 'success') {
		$result['status'] = affilo_hc_process_error($result['status']);
	}
	return $result;
}

function affilo_hc_process_custom_image($verified) {
	$result = affilo_hc_new_image_response();
	if ($verified) {
		$uploadPath = wp_upload_dir(time());
		if (isset($uploadPath['error']) && !$uploadPath['error']) {
			$prefix = $_GET['folder'] == 'stock' ? 'stock_' : 'bg_';
			$fileName = wp_unique_filename($uploadPath['path'], $prefix . $_FILES['Filedata']['name']);
			
			$localFileName = $uploadPath['path'] . '/' . $fileName;
			$webFileName = '/wp-content/uploads' . $uploadPath['subdir'] . '/' . $fileName;
			//var_dump($webFileName);
			
			if (move_uploaded_file($_FILES['Filedata']['tmp_name'], $localFileName)) {
				$result['status'] = 'success';
				$result['data'] = array('source' => $webFileName, 'label' => substr($_FILES['Filedata']['name'], 0, -4));
			} else { 
				$result['status'] = 'upload';
			}
		}
	} else {
		$result['status'] = 'unverified';
	}
	if ($result['status'] != 'success') {
		$result['status'] = affilo_hc_process_error($result['status']);
	}
	return $result;
}

/**
 * Validate image processing request as per affilo_hc_process_vars() 
 * 
 * @param array $request request vars
 * @return boolean data validity
 */
function affilo_hc_validate_image_request($request){
	$validated = array();
	$_processVars = affilo_hc_process_vars();
	foreach ($_processVars as $expected => $params) {
		if (isset($request[$expected])) {
			if ($params['match'] && !preg_match($params['match'], $request[$expected])) {
				return false;
			}
			$validated[$expected] = $request[$expected];
		} elseif ($expected != 'image') {
			return false;
		}
	}
	return $validated;
}

/**
 * Decode & prepare image data from image processing request
 * 
 * @param string $imageDataRaw raw image data from request
 * @return string image data decoded ready for writing to file
 */
function affilo_hc_prepare_image_data($imageDataRaw){
	$imageData = base64_decode($imageDataRaw);
	return $imageData;
}

/**
 * Save image data to an image file in WordpRess uplaod directory
 * 
 * @param string $imageData decoded output of affilo_hc_prepare_image_data()
 * @return mixed array upalod path setting | null
 */
function affilo_hc_save_image_to_file($imageData){
	$uploadPath = wp_upload_dir(time());
	if (isset($uploadPath['error']) && !$uploadPath['error']) {
		if($_POST['text_size'] == 'p')
		{
			$fileName = wp_unique_filename($uploadPath['path'], 'header.png');
		}
		else if($_POST['text_size'] == 'j')
		{
			$fileName = wp_unique_filename($uploadPath['path'], 'header.jpg');
		}
		else
		{
			
		}
		$filePath = $uploadPath['path'] . '/' . $fileName;
		if(file_put_contents($filePath, $imageData)) {
			$uploadPath['file'] = $fileName;
			return $uploadPath;
		}			
	}
}

/**
 * Filter & set return values for successful affilo_hc_process_image() call
 * 
 * @param array $imagePaths file & url paths returned from affilo_hc_save_image_to_file()
 * @param array $request request vars
 * @return array response data keys:
 *         `image`: full url path to the created image
 *         `width`: width in pixels of the created image
 *         `height`: height in pixels of the created image
 */
function affilo_hc_prepare_image_response($imagePaths, $request){
	$request['image'] = $imagePaths['url'] . '/' . $imagePaths['file'];
	$fomatted =  affilo_hc_format_settings($request);
	$response = array();
	$_processVars = affilo_hc_process_vars();
	foreach ($fomatted as $key => $var) {
		$response[$_processVars[$key]['var']] = $var;
	}
	return $response;
}
	
/**
 * Format settings recieved from header creator
 * 
 * @param array $settings
 * @return array settings formatted
 */
function affilo_hc_format_settings($settings){
	foreach ($settings as $key => $var) {
		if (strpos($key, 'color') !== false) {
			$var = affilo_hc_normalize_hex_color($var, true, '');
		} elseif (($key == 'bottom_text' || $key == 'top_text') && empty($var)) {
			$var = ' ';
		}
		$settings[$key] = $var;
	}
	return $settings;
}
	
/**
 * Get response object
 * 
 * @return object
 */
function affilo_hc_new_image_response(){
	$response = array(
		'status' => null,
		'data' => null
	);
	return $response;
}
	
/**
 * Store Header Creator settings to options
 * 
 * @param array $settings params sent from flash as per affilo_hc_process_vars()
 * @return null
 */
function affilo_hc_store_settings($settings){
	unset($settings['image']);
	$settings = affilo_hc_format_settings($settings);
	$key = affilo_hc_settings_option_key();
	if (get_option($key) !== false) {
		update_option($key, $settings);					
	} else {
		add_option($key, $settings);
	}
}
	
/**
 * Load Header Creator settings from options
 * 
 * @return mixed
 */
function affilo_hc_load_settings(){
	return get_option(affilo_hc_settings_option_key());
}
	
/**
 * Calculate the opposite color of a given color in hex format
 * 
 * @param string $color hex color
 * @return string 6 digit hex color opposite
 */
function affilo_hc_hex_opposite($color){
	$hash = strpos($color, '#') === 0;
	$hex = affilo_hc_normalize_hex_color($color);
	list($r, $g, $b) = str_split($hex, 2);
	foreach (array('r', 'g', 'b') as $h) {
		$$h = dechex(255 - hexdec($$h));
		$$h = (strlen($$h) > 1) ? $$h : '0'. $$h;
	}
	$hex = "{$r}{$g}{$b}";
	if ($hash) {
		$hex = "#$hex";
	}
	return $hex;
}
	
/**
 * Noramilze a colour value
 * 
 * @param string $color accepts 1, 3 & 6 digit hex colors, will pad 4, 5 with last value
 * @param boolean $hash return prefixed with #
 * @param string $default return value for empty colors
 * @return string 6 digit hex color
 */
function affilo_hc_normalize_hex_color($color, $hash = false, $default = '000000'){
	$hex = substr(strtoupper(str_replace('#', '', $color)), 0, 6);
	$length = strlen($hex);
	if (!$length) {
		return $default;
	}
	
	if($length == 3) {
		list($r, $g, $b) = str_split($hex);
		$hex = "{$r}{$r}{$g}{$g}{$b}{$b}";
	} elseif ($length < 6) {
		$hex = str_pad($hex, 6, '0', STR_PAD_LEFT);
	}
	
	if ($hash) {
		$hex = "#$hex";
	}
	return $hex;
}

/**
 * Compatability Functions
 * 
 * Functions not included in WP compat
 */

/**
 * array_fill_keys(array $keys, mixed $value)
 * 
 * http://nz2.php.net/manual/en/function.array-fill-keys.php
 */
if (!function_exists('array_fill_keys')) {
	function array_fill_keys($keys, $value = '') {
		if(is_array($keys)) {
			$filled = array();
			foreach($keys as $key => $val) {
				$filled[$val] = $value;
			}
			return $filled;
		}
	}
}

/**
 * str_split(string $string [,int $split_length = 1 ])
 * 
 * http://nz2.php.net/manual/en/function.str-split.php
 * 
 */
if (!function_exists('str_split')) {
	function str_split($string, $split_length = 1) {
		$length = strlen($string);
		$out = array();
		for ($i = 0; $i < $length; $i += $split_length) {
			$out[] = substr($string, $i, $split_length);
		}
		return $out;
	}
}

/**
 * file_put_contents(string $filename, mixed $data  [,int $flags = 0])
 * 
 * http://nz2.php.net/manual/en/function.file-put-contents.php
 * 
 * Source: http://www.phpbuilder.com/board/showthread.php?t=10292234
 * 
 * Note: no stream context support
 */
if (!function_exists('file_put_contents')) {
	if (!defined('FILE_USE_INCLUDE_PATH')) {
		define('FILE_USE_INCLUDE_PATH', 1);
	}
	if (!defined('FILE_APPEND')) {
		define('FILE_APPEND', 8);
	}
	function file_put_contents($filename, $data, $flags = 0){
		if (!is_string($filename)) {
			return false;
		}
		if (!is_string($data) && !is_array($data)) {
			return false;
		}
		if (!is_int($flags)) {
			return false;
		}
		$include = false;
		$mode    = 'wb';
		if (is_array($data)) {
			reset($data);
			while (list(, $value) = each($data)) {
				if (is_array($value)) {
					return false;
				}
			}
			unset($value);
			reset($data);
			$data = implode('', $data);
		}
		if ($flags & FILE_USE_INCLUDE_PATH) {
			$include = true;
		}
		if ($flags & FILE_APPEND) {
			$mode = 'ab';
		}
		if (!$handle = @fopen($filename, $mode, $include)) {
			return false;
		}
		if (($bytes = @fwrite($handle, $data)) === false) {
			fclose($handle);
			return false;
		}
		fclose($handle);
		return $bytes;
	}
}
?>
