<?php
/**
 * AffiloTheme Activation Processes
 */

global $affilo_api_error;

define('AFFILO_API_ERROR_AUTH', 1);

define('AFFILO_API_ERROR_CON', 2);

require_once dirname(dirname(__FILE__)) . '/vendors/minixml/minixml.inc.php';

/**
 * Initialize Activation Hooks
 */
function affilo_activation_init() {
	if (!affilo_validated()) {
		add_action('admin_head', 'affilo_activation_prompt');	
	}
}

add_action('admin_init', 'affilo_activation_init');

/**
 * Prompt or nag the user
 */
function affilo_activation_prompt() {
	return false;
		$url = wp_nonce_url('admin-ajax.php', 'affilo_activation_page') . '&time=' . time();
		$force = false;
		if ((isset($_GET['page']) && strpos($_GET['page'], 'affilo_') !== false) || (isset($_GET['post_type']) && $_GET['post_type'] == 'sqz-page')) {
			$force = true;	
		}
	?>
	<script type="text/javascript" >

	var affiloActivation = function($){
		
		var self = this;
		var cUrl = close === true ? '1' : '0';
		var W = 600;
		var H = 330;
		var url = '<?php echo $url;?>' + '&action=affilo_activation_page&TB_ajax=true&width=' + W + '&height=' + H + '&close=' + cUrl;
		
		self.activateResponse = function(response){
			$('#affiloActivationWindow').html(response);
		}
		
		self.activationPost = function(){
			var form = $('#affiloActivateForm');
			form.submit(function(e){
				e.preventDefault();
				$.ajax({
				  type: 'POST',
				  url: url + '&step=activate',
				  data: form.serialize(),
				  success: self.activateResponse,
				  beforeSend: function(){
					  $('#affilActivationLoad').show();
					  $('#affiloActivationWindow').hide();
				  },
				  complete: function(){
					  $('#affilActivationLoad').hide();
					  $('#affiloActivationWindow').show();
			      },
				  dataType: 'html'
				});
			});
		}
		
		self.affiloActivationWindow = function(close){
			if (close !== true) window.tb_remove = function(){};
			if(tb_show('AffiloTheme Activation', url) || true) {
				if (close !== true) $("#TB_closeWindowButton").remove();
				var tbWindow = $('#TB_window');
				$('#TB_ajaxContent').width('100%');
				var resize = function(){
					if ( tbWindow.size()  && (tbWindow.width() != W || tbWindow.height() != H)) {
						tbWindow.width(W).height(H);
						$('#TB_ajaxContent').width(W -30).height(H - 27);
						tbWindow.css({'margin-left': '-' + parseInt((W / 2),10) + 'px'});
						if ( typeof document.body.style.maxWidth != 'undefined' )
							tbWindow.css({'top':'30px','margin-top':'0'});
					}
				};
				setInterval(resize, 200);
			}
		}

		if (<?php echo $force ? 'true' : 'false';?>) {
			setTimeout(self.affiloActivationWindow, 1000);
		} else {
			$('.activationNagLink').click(function(e){
				e.preventDefault();
				self.affiloActivationWindow(true);
			});
		}
	}
	var affiloActivationCaller = null;
	jQuery(document).ready(function($) {
		window.affiloActivationCaller = new affiloActivation($);
	});
	</script>
	<?php	
	if (!$force) {
		add_action('admin_notices', 'affilo_activation_nag' );
	}
}

/**
 * Output activation nag
 */
function affilo_activation_nag() {
	$output = '<div class="update-nag">';
	if (affilo_activated()) {
		$nag = 'Your copy of AffiloTheme is no longer activated, you must <a href="#" class="activationNagLink">re-activate it now</a> to continue using it.';
	} else {
		$nag = 'You have not activated your copy of AffiloTheme, you must <a href="#" class="activationNagLink">activate it now</a> to access any features.';
	}
	$output .= sprintf( __($nag, 'affilo') );
	$output .= '</div>';
	echo $output;
}

/**
 * Activation Check
 */
function affilo_activated() {
	$options = get_option(THEME_OPTIONS);
	return !empty($options['affilo_activated']);	
}

/**
 * Activate the theme be setting the api token & activation hash
 * 
 * @param string $hash Affilotheme hash
 * @param string $token Affilorama api token
 */
function affilo_activate($hash, $token) {
	$options = get_option(THEME_OPTIONS);
	$options['affilo_activated'] = true;
	$options['affilo_activation_key'] = "{$hash}:{$token}";
	update_option(THEME_OPTIONS, $options);
}

/**
 * Obtain the stored activation hash and token
 */
function affilo_activation_credentials() {
	$options = get_option(THEME_OPTIONS);
	if (!empty($options['affilo_activation_key'])) {
		list($hash, $token) = array_pad(explode(':', $options['affilo_activation_key'], 2), 2, null);
		return array('hash' => $hash, 'token' => $token);
	}
}

/**
 * Check if this AffiloTheme has been activated and validated
 */
function affilo_validated() {
	$options = get_option(THEME_OPTIONS);
	return !empty($options['affilo_activated']) && !empty($options['affilo_activation_key']);
}

/**
 * Deactivate the theme, optionally removing activation check key
 * 
 * @param boolean $full
 */
function affilo_deactivate($full = false) {
	$options = get_option(THEME_OPTIONS);
	unset($options['affilo_activation_key']);
	if ($full) {
		unset($options['affilo_activated']);
	}
	update_option(THEME_OPTIONS, $options);
}

/**
 * Render the activation page (in TB via ajax)
 */
function affilo_activation_page() {
	check_ajax_referer('affilo_activation_page');
	
	require_once dirname(dirname(__FILE__)) . '/vendors/minixml/minixml.inc.php';
	
	$run = (isset($_REQUEST['step']) && $_REQUEST['step'] == 'activate');
	
	$output = '';
	$type = 'error';
	
	$errorStrings = array(
		'default' => 'There has been an error, AffiloTheme cannot be activated at this time, please try again shortly.<br/>If you continue to have this issue please contact <a href="http://www.affilorama.com/contact" target="_blank">Affilorama Support</a>.',
		'auth' => 'Email or password incorrect, cannot activate AffiloTheme.<br />If you continue to have this problem, please visit <a href="http://www.affilorama.com" target="_blank">Affilorama</a> and check your account details.',
		'activated' => 'AffiloTheme sucessfully activated.',
		'invalid' => 'AffiloTheme activation invalid/expired.'
	);
	
	if ($run) {
		if (empty($_POST['email']) || empty($_POST['password'])) {
			$output .= 'You must supply the email address &amp; password for your Affilorama account.';
		} else {
			if ($token = affilo_api_authenticate($_POST['email'], $_POST['password'])) {
				if ($hash = affilo_api_activate($token)) {
					affilo_activate($hash, $token);
				} else {
					$output .= $errorStrings['default'];
				}
			} else {
				$error = affilo_api_error();
				if ($error == AFFILO_API_ERROR_AUTH) {
					$output .= $errorStrings['auth'];
				} else {
					$output .= $errorStrings['default'];
				}
			}
		}
	}
	
	$activated = affilo_activated();
	$validated = affilo_validated();
	
	if ($activated) {
		if ($validated) {
			$output .= $errorStrings['activated'];
			$type = 'updated';
		} else if (empty($run)) {
			$output .= $errorStrings['invalid'];
		}
	}
	
	?>
	
	<?php if(!$run):?>
	<h1>AffiloTheme Activation Required</h1>
	<div id="affilActivationLoad" style="display:none;z-index:99999;">
		<?php affilo_render_error('Activating....', 'updated')?>
	</div>
	<div id="affiloActivationWindow">
	<?php endif;?>
	
	<script type="text/javascript">
		window.affiloActivationCaller.activationPost();
	</script>
	
	<?php if(empty($_GET['close'])):?>
		<a href="<?php echo admin_url('index.php')?>">Return To WordPress Admin</a>
	<?php endif;?>
	
	<?php if(!empty($output)) affilo_render_error($output, $type);?>
	
	<?php if($activated):?>
	
		<?php if($validated):?>
	
		<a href="<?php echo admin_url('admin.php?page=affilo_layout_and_theme_settings')?>">AffiloTheme Admin</a>
	
		<?php else:?>

		<?php affilo_activation_form();?>	
		
		<h2>Why do I have to reactivate?</h2>
		
		<p>You AffiloTheme activation key will expire for one of 2 reasons:</p>
		
		<ol>
			<li><b>When the same activation key is used from multiple locations.</b> You cannot freely copy AffiloTheme once activated to a new location without reactivation. To do so simply supply your Affilorama account information again to obtain a new activation key.</li>
			<li><b>You no longer have access to AffiloTheme based products on Affilorama.</b> Access to use AffiloTheme is restricted to current members of certain Affilorama products. If you have recently cancelled your subscription, your copy of AffiloTheme will be deactivated.</li>
		</ol>
		
		<p>If you believe you are still entitled to use AffiloTheme and are unable to reactivate, please contact <a href="http://www.affilorama.com/contact" target="_blank">Affilorama Support</a></p>
	
		<?php endif;?>
		
	<?php else:?>
		
		<?php affilo_activation_form();?>
	
	<?php endif;?>	
	
	<?php if(!$run):?>
	</div>
	<?php endif;?>	
	
	<?php
	exit;
}

add_action('wp_ajax_affilo_activation_page', 'affilo_activation_page');

/**
 * Render the affilorama activation form
 */
function affilo_activation_form() {
	
	?>
	
	<form id="affiloActivateForm">
		<p>Please provide your Affilorama account information to activate this copy of AffiloTheme:</p>
		<label>
			Email Address:
			<input type="text" name="email" />
		</label>
		
		<label>
			Password:
			<input type="password" name="password" />
		</label>
		<br /><br />
		<input type="submit" value="Activate">
	</form>
	
	<?php
	
	
}

/**
 * Run an auth request for supplied Affilorama credentials
 * 
 * @param string $email
 * @param string $password
 */
function affilo_api_authenticate($email, $password) {
	if($response = affilo_api_request('authenticate', compact('email', 'password'))) {
		return affilo_api_auth_response($response);
	}
}

/**
 * Detect valid auth token from any Affilorama API response
 * 
 * @param unknown_type $response
 */
function affilo_api_auth_response($response) {
	global $affilo_api_error;
	if (is_a($response, 'MiniXMLDoc') && $user = $response->getElementByPath('/affilorama/user')) {
		$valid = $user->attribute('valid');
		$token = $user->attribute('token');
		if ($valid == 'true' && !empty($token)) {
			return $token;
		}
		$affilo_api_error = AFFILO_API_ERROR_AUTH;
	}
}

/**
 * Run an aAffilotheme activate request
 * 
 * @param string $token Affilorama API auth token
 */
function affilo_api_activate($token) {
	if($response = affilo_api_request('affilotheme/activate', compact('token'))) {
		if (affilo_api_auth_response($response) && $activate = $response->getElementByPath('/affilorama/activate')) {
			$valid = $activate->attribute('activated');
			$hash = $activate->attribute('hash');
			if ($valid == 'true' && !empty($hash)) {
				return $hash;
			}
		}
	}
}

/**
 * Obtain the chnaglog and version history, and also transaprently validate the
 * activation key, deactivating as required.
 * 
 */
function affilo_api_changelog() {
	$args = array();
	$key = affilo_activation_credentials();
	if ($key) {
		$args = array($key['hash'], 'token' => $key['token']);
	}
	$deactivate = false;
	if ($response = affilo_api_request('affilotheme/changelog', $args)) {
		$token = affilo_api_auth_response($response);
		if ($token) {
			if ($validate = $response->getElementByPath('/affilorama/validate')) {
				if ($validate->attribute('valid') != 'true') {
					$deactivate = true;
				}	
			}
		}		
		$changelog = $response->getElementByPath('/affilorama/notifier');
	}
	
	if ($deactivate || (affilo_api_error() == AFFILO_API_ERROR_AUTH)) {
		affilo_deactivate();
	}	
	
	if (isset($changelog)) {
		return $changelog;
	}		
}

/**
 * Getan error if set from the last api request
 */
function affilo_api_error() {
	global $affilo_api_error;
	return isset($affilo_api_error) ? $affilo_api_error : false;
}

/**
 * Run an http request to the Affilorama API
 * 
 * @param string $service resource identifier url portion
 * @param array $args request args, numeric indexes are treated as url params, other indexes as query params
 */
function affilo_api_request($service, $args = array()) {
	global $affilo_api_error;
	$url = 'https://www.affilorama.com/api/' . $service;
	
	//Various options for the wp_remote_get() call
	$options = array(
		'timeout' => 30, //seconds
		'headers' => array(
			'Accept' => 'text/xml'
		),
	);
	
	foreach ($args as $i => &$arg) {
		if (is_int($i) && !empty($arg)) {
			$url.= '/' . $arg;
			$arg = null;
		}
	}
	
	$queryArgs = array_filter($args);
	
	if ( !empty($queryArgs) ){
		$url = add_query_arg($queryArgs, $url);
	}
	
	//Send the request.
	$result = wp_remote_get($url, $options);
	
	//Try to parse the response
	$code = wp_remote_retrieve_response_code($result);
	$body = wp_remote_retrieve_body($result);

	if ($code == 401) {
		$affilo_api_error = AFFILO_API_ERROR_AUTH;
	} elseif ($code == 200 && !empty($body)) {
		$affilo_api_error = null;
		$xml = new MiniXMLDoc();
		$xml->fromString($body);
		return $xml;
	} else {
		$affilo_api_error = AFFILO_API_ERROR_CON;
	}
	return false;
}

?>