<?php
/**
 * Creates Theme Options page and enqueues all necessary scripts
 *
 * @since 2.2.8
 */

/**
 * Build AffiloTheme admin menu
 */
function affilo_menu(){
	global $submenu, $menu;
	$menuicon = get_template_directory_uri() . '/images/affilo_sidebar_icon.png';
	add_menu_page(__('AffiloTheme','affilotheme'), __('AffiloTheme','affilotheme'), 'manage_options', 'affilo_admin', '', $menuicon, -1);
	add_submenu_page( 'affilo_admin', __('Layout and Theme', 'affilotheme'), __('Layout and Theme', 'affilotheme'), 'manage_options', 'affilo_layout_and_theme_settings', 'affilo_layout_and_theme_settings');
	add_submenu_page( 'affilo_admin', __('Header Settings', 'affilotheme'), __('Header Settings' ,'affilotheme'), 'manage_options', 'affilo_header_settings', 'affilo_header_settings');
	add_submenu_page( 'affilo_admin', __('Navigation Settings', 'affilotheme'), __('Navigation Settings', 'affilotheme'), 'manage_options', 'affilo_navigation_settings', 'affilo_navigation_settings');
	add_submenu_page( 'affilo_admin', __('Colors and Fonts', 'affilotheme'), __('Colors and Fonts', 'affilotheme'), 'manage_options', 'affilo_color_and_font_settings', 'affilo_color_and_font_settings');
	add_submenu_page( 'affilo_admin', __('Post Settings', 'affilotheme'), __('Post Settings', 'affilotheme'), 'manage_options', 'affilo_post_settings', 'affilo_post_settings');
	add_submenu_page( 'affilo_admin', __('Affiliate Redirects', 'affilotheme'), __('Affiliate Redirects', 'affilotheme'), 'manage_options', 'affilo_affiliate_redirects', 'affilo_affiliate_redirects');
	
	//call remove_menu_page to remove the default squeeze page menu 
	remove_menu_page('edit.php?post_type=sqz-page');
	
	//now check what is the permission of user and depending on that add squeeze page menu to affilotheme
	if (current_user_can('manage_options')) { 		
		add_submenu_page( 'affilo_admin', __('Squeeze & Signup Forms', 'affilotheme'), __('Squeeze & Signup Forms', 'affilotheme'), 'manage_options', 'edit.php?post_type=sqz-page');		
	}
			
	add_submenu_page( 'affilo_admin', __('Import & Export Theme Profile', 'affilotheme'), __('Import & Export Theme Profile', 'affilotheme'), 'manage_options', 'affilo_import_export', 'affilo_import_export');
	add_submenu_page( 'affilo_admin', __('Misc. Settings', 'affilotheme'), __('Misc. Settings', 'affilotheme'), 'manage_options', 'affilo_admin');

	if (!class_exists('WP_Admin_Bar')) {
		add_submenu_page( 'affilo_admin', __('AffiloTheme Help', 'affilotheme'), __('AffiloTheme Help', 'affilotheme'), 'manage_options', 'affilo_help', 'affilo_help');
	} else {
		add_submenu_page( 'affilo_none', __('AffiloTheme Help', 'affilotheme'), __('AffiloTheme Help', 'affilotheme'), 'manage_options', 'affilo_help', 'affilo_help');
	}
	
}

add_action('admin_menu', 'affilo_menu');

function affilo_admin_init() {
	global $affilo_admin;
	$affilo_admin = add_theme_page( THEME_NAME." Options", __('Theme Options', 'affilo'), 'edit_theme_options', 'affilo_admin', 'affilo_admin_page' );
	register_setting( 'affilo_admin', THEME_OPTIONS, 'affilo_sanitize');
	affilo_admin_load();
}
add_action( 'admin_menu', 'affilo_admin_init' );

function affilo_admin_bar_init() {
    global $wp_admin_bar;
    $wp_admin_bar->add_menu( array( 'parent' => 'appearance', 'title' => __('Theme Options', 'affilo'), 'href' => admin_url( 'themes.php?page=affilo_admin' ) ) );
}
add_action( 'wp_before_admin_bar_render', 'affilo_admin_bar_init' );


function affilo_admin_load() {
	global $affilo_admin,$wp_version;

	affilo_update_options();

	// Load the scripts for handling metaboxes
	wp_enqueue_script('common');
	wp_enqueue_script('wp-lists');
	wp_enqueue_script('postbox');

	// Load Affilo-specific scripts and styles
	wp_enqueue_script( 'colorbox' );
	wp_enqueue_script( 'jquery-ajaxuploader', SCRIPTS_URL . '/jquery.ajaxupload.js' );
	//the updated color picker breaks WP media library, disable on requests to the media library
	if (!strpos($_SERVER['REQUEST_URI'], 'media-upload.php')) {
		wp_enqueue_script( 'jquery-colorpicker', SCRIPTS_URL . '/colorpicker/js/colorpicker.js' );
	}
	//wp_enqueue_script( 'jquery-ui', SCRIPTS_URL . '/jquery-ui/jquery-ui-1.8.16.custom.min.js' );
	if (version_compare($wp_version, '3.5' ,'<')) {
		wp_enqueue_script( 'jquery-ui', SCRIPTS_URL . '/jquery-ui/jquery-ui-1.8.16.custom.min.js' );
	} else {
		//include widgets, accordion of jquery ui 1.9
		wp_enqueue_script('jquery-ui-widget');
		wp_enqueue_script('jquery-ui-accordion');
	}	
	wp_enqueue_script( 'jquery-tooltip', SCRIPTS_URL . '/jquery.tools.min.js' );
	wp_enqueue_script( 'affilo-admin', SCRIPTS_URL . '/admin.js', array('jquery-colorpicker') );
	wp_enqueue_style( 'colorpicker', SCRIPTS_URL . '/colorpicker/css/colorpicker.css' );	
	$affiloPages = array(
		'affilo_admin',
		'affilo_layout_and_theme_settings',
		'affilo_header_settings',
		'affilo_navigation_settings',
		'affilo_color_and_font_settings',
		'affilo_post_settings',
		'affilo_affiliate_redirects',
		'affilo_help',
		'affilo_import_export',
		'affilo_changelog',
	);

	$affiloPostTypes = array(
		'sqz-page'
	);
	
	//include style.css selectively
	if ((isset($_GET['page']) && in_array($_GET['page'],$affiloPages)) || (isset($_GET['post_type']) && in_array($_GET['post_type'],$affiloPostTypes)))  {		
		wp_enqueue_style( 'affilo-admin', STYLES_URL . '/admin.css' );
	}

	wp_enqueue_style( 'colorbox' );

	// Load scripts for TinyMCE (Credit: Lee Doel)
	if ( user_can_richedit() ){
        wp_enqueue_script('editor');
        wp_enqueue_script('media-upload');
        wp_enqueue_style( 'thickbox' );        
        //Init tinymce on selective pages
        if ((isset($_GET['page']) && in_array($_GET['page'],$affiloPages)) || (isset($_GET['post_type']) && in_array($_GET['post_type'],$affiloPostTypes)))  {			
			add_action('admin_head', 'wp_tiny_mce');
		}
    }

	if ( affilo_get_option('reset') ) { affilo_set_default_options(); wp_redirect( admin_url( 'admin.php?page=affilo_admin&reset=true' ) ); }
}

/**
 * Adds the Screen Options tab with 2 columns. Credit: http://www.code-styling.de/english/how-to-use-wordpress-metaboxes-at-own-plugins
 */
function affilo_screen_options($columns, $screen) {
	global $affilo_admin;
	if ($screen == $affilo_admin) {
		$columns[$affilo_admin] = 2;
	}
	return $columns;
}
add_filter('screen_layout_columns', 'affilo_screen_options', 10, 2);


/**
 * Callback for Affilo Theme Options Page layout
 *
 * @since 2.2.8
 */
function affilo_admin_page() {
	global $affilo_admin, $affilo_page_title;
	if (!isset($affilo_page_title)) {
		$affilo_page_title = 'Options';
	}
	$settings = array(
		'affilo_seo_settings',
		'affilo_upgrade_settings',
		'affilo_feedburner_settings',
		'affilo_analytics_settings',
		'affilo_head_code_settings',
		'affilo_footer_code_settings'
	);
	affilo_filter_settings($settings);
?>

<div class="wrap">
    <div id="icon-options-general" class="icon32"><br/></div>

    <h2><?php _e( "AffiloTheme $affilo_page_title", 'affilo'); ?></h2>

	<?php
		if ( isset($_REQUEST['settings-updated']) && $_REQUEST['settings-updated'] == true ) {
			echo '<div id="message" class="updated fade"><p>' . __( "AffiloTheme $affilo_page_title Updated.", 'affilo') . '</p></div>';
		}
		elseif ( isset($_REQUEST['reset']) && $_REQUEST['reset'] == true ) {
			echo '<div id="message" class="updated fade"><p>' .  __( 'AffiloTheme Options Reset.', 'affilo') . '</p></div>';
		}
		if ( isset($_REQUEST['upgrade']) && $_REQUEST['upgrade'] == 'true') {
			echo '<div id="message" class="updated fade"><p>' . sprintf( __('AffiloTheme upgraded to version %s!', 'affilo'), get_option('affilo_version') ) . '</p></div>';
		}
	?>

    <div id="poststuff" class="metabox-holder<?php global $screen_layout_columns; echo 2 == $screen_layout_columns ? ' has-right-sidebar' : ''; ?>">
    	<form method="post" enctype="multipart/form-data" action="options.php" id="affilo_options">
		<?php
			echo "<input type='hidden' name='settings_classes' value='" . esc_attr(join(',', $settings)) . "' />";
			// Include Save/Reset buttons in header
			affilo_admin_buttons();

			// Make metaboxes work proper
			wp_nonce_field('affilo-admin-metaboxes');
			wp_nonce_field( 'closedpostboxes', 'closedpostboxesnonce', false );
			wp_nonce_field( 'meta-box-order', 'meta-box-order-nonce', false );

			// Make settings usoable
			settings_fields( 'affilo_admin' );
		?>
        <div id="post-body" class="has-sidebar">
			<div id="post-body-content" class="has-sidebar-content">
            	<?php do_meta_boxes( $affilo_admin, 'primary', null ); ?>
			</div>
        </div>  <!-- postbox-container -->

        <div id="side-info-column" class="inner-sidebar">
        	<?php do_meta_boxes( $affilo_admin, 'secondary', null ); ?>
        </div>  <!-- postbox-container -->

		<?php affilo_admin_buttons(); ?>
        </form>
    </div>  <!-- metabox-holder -->
</div> <!-- wrap -->
<?php
}

function affilo_admin_sub_page($settings = array(), $affilo_page_title = null) {
	global $affilo_admin, $plugin_page;
	if (!empty($settings)) {
		affilo_filter_settings($settings);
	}
	if (!isset($affilo_page_title)) {
		$affilo_page_title = 'Options';
	}
?>

<div class="wrap">
    <div id="icon-options-general" class="icon32"><br/></div>

    <h2><?php _e( "AffiloTheme $affilo_page_title", 'affilo'); ?></h2>

	<?php
		if ( isset($_REQUEST['settings-updated']) && $_REQUEST['settings-updated'] == true ) {
			echo '<div id="message" class="updated fade"><p>' . __( "AffiloTheme $affilo_page_title Updated.", 'affilo') . '</p></div>';
		}
		elseif ( isset($_REQUEST['reset']) && $_REQUEST['reset'] == true ) {
			echo '<div id="message" class="updated fade"><p>' . __( 'AffiloTheme Options Reset.', 'affilo') . '</p></div>';
		}
	?>

    <div id="poststuff" class="metabox-holder<?php global $screen_layout_columns; echo 2 == $screen_layout_columns ? ' has-right-sidebar' : ''; ?>">
    	<form method="post" enctype="multipart/form-data" action="" id="affilo_options">
		<?php
			echo "<input type='hidden' name='settings_classes' value='" . esc_attr(join(',', $settings)) . "' />";
			// Include Save/Reset buttons in header
			affilo_admin_buttons();

			// Make metaboxes work proper
			wp_nonce_field('affilo-admin-metaboxes');
			wp_nonce_field( 'closedpostboxes', 'closedpostboxesnonce', false );
			wp_nonce_field( 'meta-box-order', 'meta-box-order-nonce', false );

			// Make settings usoable
			settings_fields( $plugin_page );
		?>
        <div id="post-body" class="has-sidebar">
			<div id="post-body-content" class="has-sidebar-content">
            	<?php do_meta_boxes( $affilo_admin, 'primary', null ); ?>
			</div>
        </div>  <!-- postbox-container -->

        <div id="side-info-column" class="inner-sidebar">
        	<?php do_meta_boxes( $affilo_admin, 'secondary', null ); ?>
        </div>  <!-- postbox-container -->

		<?php affilo_admin_buttons(); ?>
        </form>
    </div>  <!-- metabox-holder -->
</div> <!-- wrap -->
<?php
}



/**
 * Callback for Affilo Theme Help Page layout
 *
 */
function affilo_help() {
	$section = isset($_GET['section']) ? $_GET['section'] : 'start';
	$user = wp_get_current_user();
	if ($user->ID && !get_user_meta($user->ID, 'affilo_welcome', true)) {
		add_user_meta($user->ID, 'affilo_welcome', true);
	}
?>

<div class="wrap about-wrap" id="affilo_help">
    <h1><?php _e( "Welcome To AffiloTheme", 'affilo'); ?></h1>

	<div class="about-text">You're on your way to using the most powerful affiliate WordPress theme in the world; let's get you started.</div>

	<div class="wp-badge"></div>

	<h2 class="nav-tab-wrapper">
		<a href="<?php echo admin_url('admin.php?page=affilo_help');?>" class="nav-tab<?php echo $section=='start'?' nav-tab-active':'';?>">Getting Started</a>
	</h2>

	<?php switch($section): case('start'):?>

	<div class="changelog point-releases">

       	<script type="text/javascript" src="http://cdn.affilorama.com/swf/flowplayer/flowplayer.min.js"></script>
		<script type="text/javascript" src="http://cdn.affilorama.com/swf/flowplayer/flowplayer.ipad.min.js"></script>
		<h2>AffiloTheme Training Videos</h2>
		<p>We have created 10 training videos to help you get the most out of AffiloTheme.</p>
		<p>&nbsp;</p>

		<h3><strong>Video 1: Getting Started With AffiloTheme</strong></h3>
		<p>In this video you will discover how quick and easy it is to get your website set up using AffiloTheme&rsquo;s legendary &ldquo;point and click&rdquo; installation system as well as get an introduction to the AffiloTheme admin panel.</p>
		<p><a href="http://cdn.affilorama.com/files/videos/519567/getting-started-with-affilotheme.mp4?1347584470" style="display: block; width: 640px; height: 360px" id="505281d6-0750-404d-be7f-33bb6cabbf1f"></a>
		<script type="text/javascript">
		var options = {"key":"#@34d2901b59201f9fac1","plugins":{"controls":{"url":"http:\/\/cdn.affilorama.com\/swf\/flowplayer\/flowplayer.controls.swf"}},"playlist":[{"url":"http:\/\/cdn.affilorama.com\/files\/image\/getting%20started%20with%20affilotheme.jpg","scaling":"orig"},{"url":"http:\/\/cdn.affilorama.com\/files\/videos\/519567\/getting-started-with-affilotheme.mp4?1347584470","autoPlay":false,"autoBuffering":false,"scaling":"orig"}]};
		$f("505281d6-0750-404d-be7f-33bb6cabbf1f", "http://cdn.affilorama.com/swf/flowplayer/flowplayer.commercial.swf", options).ipad();
		</script></p>
		<p>&nbsp;</p>

		<h3><strong>Video 2: How To Install AffiloTheme On Your Own Web Hosting (Optional)</strong></h3>
		<p>If you want to download and install AffiloTheme on your own web hosting then you must watch this video first. <a title="" href="http://www.affilorama.com/affilotheme/members">Click here to download Affilotheme and install it yourself.</a></p>
		<p><a href="http://cdn.affilorama.com/files/videos/124364/how-to-install-affilotheme-self-hosted.mp4?1347848918" style="display:block;width:640px;height:360px" id="5057b041-ec80-4bc2-a20c-2dc46cabbf1f"></a></p>
		<p><script type="text/javascript">
		var options = {"key":"#@34d2901b59201f9fac1","plugins":{"controls":{"url":"http:\/\/cdn.affilorama.com\/swf\/flowplayer\/flowplayer.controls.swf"}},"playlist":[{"url":"http:\/\/cdn.affilorama.com\/files\/image\/installing%20affilotheme%20self-hosted-no-playbutton.jpg","scaling":"orig"},{"url":"http:\/\/cdn.affilorama.com\/files\/videos\/124364\/how-to-install-affilotheme-self-hosted.mp4?1347849909","autoPlay":false,"autoBuffering":false,"scaling":"orig"}]};
		$f("5057b041-ec80-4bc2-a20c-2dc46cabbf1f", "http://cdn.affilorama.com/swf/flowplayer/flowplayer.commercial.swf", options).ipad();
		</script>
		</p>
		<p>&nbsp;</p>

		<h3><strong>Video 3: How To Adjust General Setting</strong></h3>
		<p>In this video you&rsquo;ll learn how to quickly customize the general settings of your AffiloTheme-powered site.</p>
		<p><a href="http://cdn.affilorama.com/files/videos/810783/how-to-adjust-general-settings.mp4?1347584974" style="display: block; width: 640px; height: 360px" id="505283ce-72c8-4a14-a60b-3ef36cabbf1f"></a>
		<script type="text/javascript">
		var options = {"key":"#@34d2901b59201f9fac1","plugins":{"controls":{"url":"http:\/\/cdn.affilorama.com\/swf\/flowplayer\/flowplayer.controls.swf"}},"playlist":[{"url":"http:\/\/cdn.affilorama.com\/files\/image\/how_to_adjust_general_settings.jpg","scaling":"orig"},{"url":"http:\/\/cdn.affilorama.com\/files\/videos\/810783\/how-to-adjust-general-settings.mp4?1347584974","autoPlay":false,"autoBuffering":false,"scaling":"orig"}]};
		$f("505283ce-72c8-4a14-a60b-3ef36cabbf1f", "http://cdn.affilorama.com/swf/flowplayer/flowplayer.commercial.swf", options).ipad();</script></p>
		<p>&nbsp;</p>

		<h3><strong>Video 4: How To Use Affilotheme Widgets</strong></h3>
		<p>AffiloTheme comes jam-packed with awesome widgets to make your site more attractive and beautiful for visitors. Learn how to set up your AffiloTheme widgets in just a few minutes.</p>
		<p><a href="http://cdn.affilorama.com/files/videos/713592/how-to-setup-affilotheme-widgets.mp4?1347585146" style="display: block; width: 640px; height: 360px" id="5052847a-06a8-48a9-bd5b-43cd6cabbf1f"></a>
		<script type="text/javascript">
		var options = {"key":"#@34d2901b59201f9fac1","plugins":{"controls":{"url":"http:\/\/cdn.affilorama.com\/swf\/flowplayer\/flowplayer.controls.swf"}},"playlist":[{"url":"http:\/\/cdn.affilorama.com\/files\/image\/how_to_use_affilotheme_widgets.jpg","scaling":"orig"},{"url":"http:\/\/cdn.affilorama.com\/files\/videos\/713592\/how-to-setup-affilotheme-widgets.mp4?1347585146","autoPlay":false,"autoBuffering":false,"scaling":"orig"}]};
		$f("5052847a-06a8-48a9-bd5b-43cd6cabbf1f", "http://cdn.affilorama.com/swf/flowplayer/flowplayer.commercial.swf", options).ipad();</script></p>
		<p>&nbsp;</p>

		<h3><strong>Video 5: How To Use The AffiloTheme Header Creator</strong></h3>
		<p>A professional header image can be the difference between an ugly site, and one that makes your visitors go &ldquo;WOW!&rdquo;. In this training video, you will learn how to master the built-in AffiloTheme header creator.</p>
		<p><a href="http://cdn.affilorama.com/files/videos/620612/how-to-use-the-affilotheme-header-creator.mp4?1347585280" style="display: block; width: 640px; height: 360px" id="50528500-3fe0-45c2-95de-44536cabbf1f"></a>
		<script type="text/javascript">
		var options = {"key":"#@34d2901b59201f9fac1","plugins":{"controls":{"url":"http:\/\/cdn.affilorama.com\/swf\/flowplayer\/flowplayer.controls.swf"}},"playlist":[{"url":"http:\/\/cdn.affilorama.com\/files\/image\/how_to_use_the_affilotheme_header_creator.jpg","scaling":"orig"},{"url":"http:\/\/cdn.affilorama.com\/files\/videos\/620612\/how-to-use-the-affilotheme-header-creator.mp4?1347585280","autoPlay":false,"autoBuffering":false,"scaling":"orig"}]};
		$f("50528500-3fe0-45c2-95de-44536cabbf1f", "http://cdn.affilorama.com/swf/flowplayer/flowplayer.commercial.swf", options).ipad();</script></p>
		<p>&nbsp;</p>

		<h3><strong>Video 6: How To Change Layout and Child Themes</strong></h3>
		<p>AffiloTheme has 6 awesome themes in one. These &ldquo;child themes&rdquo; offer you massive flexibility and control over the layout of your site. In this video, you will learn how to pick between child themes, as well as changing the layout of your pages.</p>
		<p><a href="http://cdn.affilorama.com/files/videos/449122/how-to-change-layout-and-child-theme.mp4?1347585397" style="display: block; width: 640px; height: 360px" id="50528575-3b58-4fab-a932-49216cabbf1f"></a>
		<script type="text/javascript">
		var options = {"key":"#@34d2901b59201f9fac1","plugins":{"controls":{"url":"http:\/\/cdn.affilorama.com\/swf\/flowplayer\/flowplayer.controls.swf"}},"playlist":[{"url":"http:\/\/cdn.affilorama.com\/files\/image\/how_to_change_layout_and_child_theme.jpg","scaling":"orig"},{"url":"http:\/\/cdn.affilorama.com\/files\/videos\/449122\/how-to-change-layout-and-child-theme.mp4?1347585397","autoPlay":false,"autoBuffering":false,"scaling":"orig"}]};
		$f("50528575-3b58-4fab-a932-49216cabbf1f", "http://cdn.affilorama.com/swf/flowplayer/flowplayer.commercial.swf", options).ipad();</script></p>
		<p>&nbsp;</p>

		<h3><strong>Video 7: How To Adjust Fonts and Colors</strong></h3>
		<p>Normally it&rsquo;s a real challenge to change fonts and colors with WordPress. However, AffiloTheme makes this process so simple! Learn how to adjust the default fonts and colors of the text on your site, with just a few mouse clicks.</p>
		<p><a href="http://cdn.affilorama.com/files/videos/748542/how-to-adjust-fonts-and-colors.mp4?1347585530" style="display: block; width: 640px; height: 360px" id="505285fa-8594-4675-b64f-4a106cabbf1f"></a>
		<script type="text/javascript">
		var options = {"key":"#@34d2901b59201f9fac1","plugins":{"controls":{"url":"http:\/\/cdn.affilorama.com\/swf\/flowplayer\/flowplayer.controls.swf"}},"playlist":[{"url":"http:\/\/cdn.affilorama.com\/files\/image\/how%20to%20adjust%20fonts%20and%20colors.jpg","scaling":"orig"},{"url":"http:\/\/cdn.affilorama.com\/files\/videos\/748542\/how-to-adjust-fonts-and-colors.mp4?1347585530","autoPlay":false,"autoBuffering":false,"scaling":"orig"}]};
		$f("505285fa-8594-4675-b64f-4a106cabbf1f", "http://cdn.affilorama.com/swf/flowplayer/flowplayer.commercial.swf", options).ipad();</script></p>
		<p>&nbsp;</p>

		<h3><strong>Video 8: How To Configure Navigation Settings</strong></h3>
		<p>Normally it can be really difficult to change the format and position of your sites navigations. Luckily for you AffiloTheme makes this easy! Learn how to enable/disable your navigation, change its position or even create your own custom navigation with just a few clicks.</p>
		<p><a href="http://cdn.affilorama.com/files/videos/980982/how-to-configure-navigation-settings.mp4?1347585650" style="display: block; width: 640px; height: 360px" id="50528672-43ec-47ac-a7bf-4c7e6cabbf1f"></a>
		<script type="text/javascript">
		var options = {"key":"#@34d2901b59201f9fac1","plugins":{"controls":{"url":"http:\/\/cdn.affilorama.com\/swf\/flowplayer\/flowplayer.controls.swf"}},"playlist":[{"url":"http:\/\/cdn.affilorama.com\/files\/image\/configure%20navigation.jpg","scaling":"orig"},{"url":"http:\/\/cdn.affilorama.com\/files\/videos\/980982\/how-to-configure-navigation-settings.mp4?1347585650","autoPlay":false,"autoBuffering":false,"scaling":"orig"}]};
		$f("50528672-43ec-47ac-a7bf-4c7e6cabbf1f", "http://cdn.affilorama.com/swf/flowplayer/flowplayer.commercial.swf", options).ipad();</script></p>
		<p>&nbsp;</p>

		<h3><strong>Video 9: How To Redirect And Cloak Your Affiliate Links</strong></h3>
		<p>Cloaking and redirecting your affiliate links means more sales and higher conversion rates. In this video you&rsquo;ll learn how to do so with just a few mouse clicks.</p>
		<p><a href="http://cdn.affilorama.com/files/videos/832355/how-to-redirect-and-cloak-your-affiliate-links.mp4?1347585742" style="display: block; width: 640px; height: 360px" id="505286ce-596c-4183-a319-4e996cabbf1f"></a>
		<script type="text/javascript">
		var options = {"key":"#@34d2901b59201f9fac1","plugins":{"controls":{"url":"http:\/\/cdn.affilorama.com\/swf\/flowplayer\/flowplayer.controls.swf"}},"playlist":[{"url":"http:\/\/cdn.affilorama.com\/files\/image\/how_to_redirect_and_cloak_your_affiliate_links.jpg","scaling":"orig"},{"url":"http:\/\/cdn.affilorama.com\/files\/videos\/832355\/how-to-redirect-and-cloak-your-affiliate-links.mp4?1347585742","autoPlay":false,"autoBuffering":false,"scaling":"orig"}]};
		$f("505286ce-596c-4183-a319-4e996cabbf1f", "http://cdn.affilorama.com/swf/flowplayer/flowplayer.commercial.swf", options).ipad();</script></p>
		<p>&nbsp;</p>

		<h3><strong>Video 10: How To Setup Squeeze Page And Opt-in Forms</strong></h3>
		<p>This is the big one! Learn exactly how to set up profitable squeeze pages and opt-in forms to boost your list numbers through the roof. AffiloTheme makes building your list a breeze.</p>
		<p><a href="http://cdn.affilorama.com/files/videos/442286/how-to-set-up-squeeze-pages-and-opt-in-forms.mp4?1347585848" style="display: block; width: 640px; height: 360px" id="50528738-4510-41fa-984d-4f9c6cabbf1f"></a>
		<script type="text/javascript">
		var options = {"key":"#@34d2901b59201f9fac1","plugins":{"controls":{"url":"http:\/\/cdn.affilorama.com\/swf\/flowplayer\/flowplayer.controls.swf"}},"playlist":[{"url":"http:\/\/cdn.affilorama.com\/files\/image\/how_to_set_up_squeeze_pages_and_opt-in_forms.jpg","scaling":"orig"},{"url":"http:\/\/cdn.affilorama.com\/files\/videos\/442286\/how-to-set-up-squeeze-pages-and-opt-in-forms.mp4?1347585848","autoPlay":false,"autoBuffering":false,"scaling":"orig"}]};
		$f("50528738-4510-41fa-984d-4f9c6cabbf1f", "http://cdn.affilorama.com/swf/flowplayer/flowplayer.commercial.swf", options).ipad();</script></p>
		<p>&nbsp;</p>

	</div>

	<?php break; endswitch;?>

	<div class="changelog">
		<h3>Further Support</h3>
		If you require further support, access your <a href="http://www.affilorama.com/affilotheme/members">AffiloTheme control panel</a> or email Affilorama Support at <a href="mailto:support@affilorama.com">support@affilorama.com</a>
	</div>
</div> <!-- wrap -->
<?php
}

function affilo_update_options() {
	global $affilo_settings_factory;
	if (!empty($_POST['option_page']) && !empty($_POST['affilo'])) {
		$option_page = $_POST['option_page'];
		check_admin_referer( $option_page . '-options' );
		$value = stripslashes_deep($_POST['affilo']);
		$options = get_option(THEME_OPTIONS);
		if (isset($affilo_settings_factory->settings[$option_page])) {
			$value = $affilo_settings_factory->settings[$option_page]->format_options($value, $options);
		}
		if (isset($_POST['settings_classes'])) {
			$classes = explode(',', $_POST['settings_classes']);
			foreach ($classes as $class) {
				if ($class != $option_page && isset($affilo_settings_factory->settings[$class])) {
					$value = $affilo_settings_factory->settings[$class]->format_options($value, $options);
				}
			}
		}
		$value += $options;
		update_option(THEME_OPTIONS, $value);

		/**
		 *  Handle settings errors and return to options page
		 */
		// If no settings errors were registered add a general 'updated' message.
		if ( !count( get_settings_errors() ) )
			add_settings_error('general', 'settings_updated', __('Settings saved.'), 'updated');
		set_transient('settings_errors', get_settings_errors(), 30);

		/**
		 * Redirect back to the settings page that was submitted
		 */
		$goback = add_query_arg( 'settings-updated', 'true',  wp_get_referer() );
		wp_redirect( $goback );
		exit;
	}
}

function affilo_render_error($message, $class = 'error'){
	?>
	<div id="message" class="<?php echo $class;?> settings-<?php echo $class;?>"><p><strong>
		<?php echo $message; ?>
	</strong></p></div>
	<?php
}

// Include the Admin Buttons
function affilo_admin_buttons() { ?>
	<div style="position:relative;clear:both; margin-bottom:20px">
		<input type="submit" name="Submit" value="<?php _e('Save Settings', 'affilo') ?>" class="button-primary" />
		<!--input type="submit" name="<?php echo THEME_OPTIONS . '[reset]'; ?>" value="<?php _e('Reset All Settings', 'affilo') ?>" class="button" onclick="if(confirm('Reset All Theme Settings?')) return true; else return false;" /-->
	</div>
<?php }

// This callback's sole responsibility is to set checkboxes to "false" if unchecked
function affilo_sanitize($inputs) {
	global $affilo_settings_factory;
	$settings = $affilo_settings_factory->settings;

	foreach ( $settings as $setting ) {
		$options = $setting->options;
		foreach ( $options as $option_id => $option ) {

			// Set unchecked checkboxes to false, otherwise their value is unset and the default gets set on every save
			if ($option['type'] == 'checkbox' && !isset($inputs[$option_id])) {
				$inputs[$option_id] = false;
			}

			// Sanitize untrusted textual inputs. Defaults to true. Set 'sanitize' => false for no satitization, or use 'sanitize' => array( 'allowed_html' => '', 'allowed_protocols' => '' ) to allow specific tags.
			if ( ( $option['type'] == 'text' || $option['type'] == 'textarea') && ( isset($option['sanitize']) && $option['sanitize'] != false ) ) {
				$inputs[$option_id] = wp_kses( $inputs[$option_id], $option['sanitize']['allowed_html'], ( empty ( $option['sanitize']['allowed_protocols']) ? array() : $option['sanitize']['allowed_protocols'] ) );
			}

		}
	}
	return $inputs;
}

function affilo_admin_favicon() {
	echo '<link rel="shortcut icon" href="'.get_template_directory_uri().'/images/favicon.ico" />';
}
add_action('admin_head','affilo_admin_favicon');

?>
