<?php
	class affilo_footer_settings extends affilo_settings {
		
		function affilo_footer_settings() {
			$this->name = __( 'Footer Settings', 'affilo' );
			$this->slug = 'affilo_footer_settings';
			$this->description = __( 'Select what text (if any) you would like to appear in the footer area of your site. The textbox allows use of full HTML and Shortcodes.', 'affilo' );
			$this->location = 'primary';
			$this->priority = 'core';
			$this->options = array(
					'enable_copyright' => array(
							'type'		=> 'checkbox',
							'label'		=> __( 'Enable Copyright', 'affilo' ),
							'default'	=> 'true'
						)
				);
			parent::__construct();
		}
		
		// Insert Return to Top link
		function affilo_rtt() {
			if (affilo_get_option( 'enable_rtt')) { 
				echo affilo_rtt();
			}
		}
		
		// Add Copyright, Design Credit and add'l info to footer
		function copyright() {
			$site_name = get_option( 'blogname' );
			$site_url = affilo_get_option( 'site_url' );
			$affilo_copyright = ($site_url) ? '<a href="' . $site_url . '">' . $site_name . '</a>' : $site_name;
			$design_credit = THEME_NAME . ' for <a href="http://affilo.com" title="Affilo Theme Framework for WordPress" target="_blank" class="link-designer">Affilo</a>.';
			$copyright = affilo_get_option( 'enable_copyright' );
			$copyright_year = ( affilo_get_option( 'copyright_year' ) ) ? affilo_get_option( 'copyright_year' ) : date('Y');
			$current_year = date('Y');
			$designer = affilo_get_option( 'enable_designer_credit' );
			$wordpress = affilo_get_option( 'enable_wp_credit' );
			$affilo = affilo_get_option( 'enable_affilo_credit' );
			$text = affilo_get_option( 'footer_text' );

			if ($copyright || $designer || $text) { ?>
				<div id="credits" class="fine">
					<?php if ($copyright) { ?><span class="copyright">&copy;<?php if ($copyright_year == $current_year) { echo $current_year; } else { echo $copyright_year.'-'.$current_year;} ?> <?php echo apply_filters( 'affilo_copyright', $affilo_copyright ); ?>. <span class="rights">All Rights Reserved.</span></span><?php } ?>
					<?php if ($designer) { ?><span class="design_credit"><?php echo apply_filters( 'affilo_design_credit', $design_credit ); ?></span><?php } ?>
					<?php if ($wordpress || $affilo) { ?><span class="wp_credit">Powered by <?php if ($wordpress) { ?><a href="http://www.wordpress.org/" title="WordPress" target="_blank" class="link-wordpress">WordPress</a><?php } if ($wordpress && $affilo) { ?> and <?php } if ($affilo) { ?><a href="http://affilo.com" class="link-affilo">Affilo</a><?php } ?>.</span><?php } ?>
					<?php if ($text) { ?><span class="footer_text"><?php echo do_shortcode( $text ); ?></span><?php } ?>
				</div><!-- #credits -->
			<?php }
		}

		// Add Admin links to footer
		function admin() {
			if ( affilo_get_option( 'enable_admin' ) ) { 
				
				// Grab global user data
				global $user_ID, $user_identity;
				
				// Our default links, can be overriden using the affilo_footer_admin_links filter
				$loggedin_defaults = array(
					'Admin Dashboard'	=> admin_url(),
					'Widgets'			=> admin_url('widgets.php'),
					'Theme Options'		=> admin_url('themes.php?page=affilo_admin'),
					'Logout'			=> wp_logout_url( get_permalink() )
				);
				$loggedout_defaults = array(
					'Admin Dashboard'	=> admin_url()
				);
				
				// Filter the links arrays so they can be overridden
				$loggedin_links = apply_filters( 'affilo_footer_admin_loggedin_links', $loggedin_defaults );
				$loggedout_links = apply_filters( 'affilo_footer_admin_loggedout_links', $loggedout_defaults );
				$separator = apply_filters( 'affilo_footer_admin_links_separator', '<li class="meta-sep">|</li>' );
				$links = array();
				$output = '';
				
				// If the user is logged in, use the logged in links, else use the logged out links
				if ($user_ID) { $links_array = $loggedin_links; }
				else { $links_array = $loggedout_links; }
				
				// Loop through all the links and store them in an array with proper HTML
				foreach( $links_array as $title => $url ) {
					$links[] = '<li><a href="' . esc_url( $url ) . '">' . esc_html( $title ) . '</a></li>';
				}
				
				// Begin output
				$output .= '<div id="admin_links" class="fine">';
				if ($user_ID) { $output .= '<span id="login_identity">Logged in as <strong>' . $user_identity . '</strong>.</span>'; }
				$output .= '<ul>';
				$output .= implode( $separator, $links );
				$output .= '</ul>';
				$output .= '</div> <!-- #admin_links -->';
				
				// Filter the whole thing, incase someone wants to replace it entirely
				echo apply_filters( 'affilo_footer_admin', $output );

			}
		}
		
		function hooks() {
			add_action( 'affilo_footer', array( $this, 'affilo_rtt'), 5 );
			add_action( 'affilo_footer_left', array( $this, 'copyright' ), 12 );
			add_action( 'affilo_footer_right', array( $this, 'admin' ), 12 );
		}

	}
	
	affilo_register_settings('affilo_footer_settings');
?>