<?php

function affilo_header_settings() {
	affilo_admin_sub_page(array('affilo_header_settings'), 'Header Settings');
}

	class affilo_header_settings extends affilo_settings {
		
		static $logo_hook = "affilo_header";
		
		function affilo_header_settings() {
			$this->name = __( 'Header Settings', 'affilo');
			$this->slug = 'affilo_header_settings';
			$this->description = __( 'Control various aspects of the header area of your site, including logo, site description, favicon and navigation. The logo options allow you to specify a text-based logo to use instead of an image.', 'affilo' );
			$this->location = 'primary';
			$this->priority = 'high';
			
			$this->options = array(
				'logo-intro' => array(
					'type' => 'intro',
					'label' =>  __('Header Image', 'affilo'),
				),
				'header_creator' => array(
					'col' => 'quart',
					'type' => 'header_creator_button'
				),
				'logo' => array(
					'type' => 'logo',
					'col' => '2-third',
					'label' =>  __('Header Image', 'affilo'),
					'desc' =>  __('Header Background Image (recommended)', 'affilo'),
				),
				array( 'type' => 'clear' ),
				'logo-repeat' => array(
						'type' => 'select',
						'col' => 'quart',
						'label' =>  __('Header Image repeat', 'affilo'),
						'desc' =>  __('', 'affilo'),
						'options' => $this->style_options('bg-repeat')
				),
				'logo-width' => array(
						'type' => 'text',
						'col' => 'quart',
						'label' =>  __('Header Width', 'affilo'),
				),
				'logo-height' => array(
					'type' => 'text',
					'col' => 'quart',
					'label' =>  __('Header Height', 'affilo'),
				),
				'header-info' => $this->after_header_section(),
				array( 'type' => 'divider' ),
				'logo-text-intro' => array(
					'type' => 'intro',
					'label' =>  __('Header Text', 'affilo'),
				),
				'logo-link' => array(
					'type'		=> 'checkbox',
					'col' => 'third',
					'label'		=> __( 'Link header to homepage?', 'affilo' ),
				),
				'tagline' => array(
					'type'		=> 'radio',
					'col' => 'third',
					'label'		=> __( 'Hide header text from displaying?', 'affilo' ),
					'options' => array('Hide', 'Show'),
				),
				array( 'type' => 'clear' ),
				'logo-text' => array(
					'label' => __('Header Text', 'affilo'),
					'col' => array('class' => 'third', 'id' => 'logo-text-wrapper'),
					'type' => 'text',
					'size' => 'large',
				),
				'blogdescription' => array(
					'label' => __('Tagline Text', 'affilo'),
					'col' => array('class' => 'third', 'id' => 'logo-text-wrapper-1'),
					'type' => 'text',
					'size' => 'large'
				),
				array( 'type' => 'divider' ),
				'other-intro' => array(
					'type' => 'intro',
					'label' =>  __('Other Settings', 'affilo'),
				),
				'favicon' => array(
					'type'		=> 'upload',
					'label'		=> __( 'Favicon', 'affilo' ),
					'desc'		=> __( 'A favicon is a small icon that displays alongside a URL in most browsers,
					<a href="http://www.favicongenerator.com/" target="_blank">click here to create one.</a> <br />Please use the image which has <b>.ico</b> extension.', 'affilo' ),
					'default'	=> '/wp-content/themes/affilotheme_2/images/favicon.ico'
				)
			);	
			parent::__construct();
		}
		
		function after_header_section() {
			$maxWidth = affilo_get_option('max-logo-width');
			$maxHeight = affilo_get_option('max-logo-height');
			if ($maxWidth || $maxHeight) {
				$string = '';
				
				if ($maxWidth) {
					$string.= "width of {$maxWidth}px";
				}
				if ($maxHeight) {
					$string.= !empty($string) ? ' and ' : '';
					$string.= "height of {$maxHeight}px";
				}
				return array(
					'type' => 'info', 
					'desc' => __("The Current theme only supports headers to the maximum " . $string . '.', 'affilo')
				);
			}
		}
		
		function format_options($value, $options) {
			foreach (array('logo-height', 'logo-width') as $opt) {
				$max = 'max-' . $opt;
				if (!empty($options[$max]) && !empty($value[$opt])) {
					if ((int) $value[$opt] > (int) $options[$max ]) {
						$value[$opt] = $options[$max ];
					}
				}
			}
			return $value;
		}
		
		function styles() {
			$logo = affilo_get_option( 'logo-image' );
			if (empty($logo)) {
				return false;
			}
			if ($height = affilo_get_option('logo-height')) {
				$height = "\n\t" . 'height:' . $height . 'px;';
			} else {
				$height = '';
			}
			if ($width = affilo_get_option('logo-width')) {
				$width = "\n\t" . 'width:' . $width . 'px;';
			} else {
				$width = '';
			}
			$style = "#logo{\n\t" . 
			"background-image: url({$logo});" .
			"\n\t" . self::style_option('bg-repeat', affilo_get_option('logo-repeat')) .
			"{$height}{$width}" .
			"\n}\n";
			echo $style;
		}
		
		function logo() {
			echo '<div id="logo">';
			if (affilo_get_option('tagline')) {
				$logo_container = apply_filters( 'affilo_logo_container', 'h1');
				echo "<{$logo_container} id=\"blog-title\">";
				if ( affilo_get_option( 'logo-link') ) {
					echo '<a href="' . home_url() . '">';
				}
				echo affilo_get_option('logo-text');
				if ( affilo_get_option( 'logo-link') ) {
					echo '</a>';
				}
				echo "</{$logo_container}>";
				self::tagline();
			} else {
				if ( affilo_get_option( 'logo-link') ) {
					echo '<a href="' . home_url() . '"></a>';
				}
			}
			echo '</div>';
		}
		
		function favicon() {
			if ( affilo_get_option( 'favicon' ) ) {
				echo '<link rel="shortcut icon" href="' . affilo_get_option( 'favicon' ) . '" />'."\n";
			} else {
				echo '<link rel="shortcut icon" href="' . IMAGES_URL . '/favicon.ico" />'."\n";
			}
		}
		
		function tagline() {
			if ( affilo_get_option( 'tagline' ) ) {
				if (!($tagline = affilo_get_option( 'blogdescription' ))) {
					$tagline = get_bloginfo( 'description' );
				}
				$tag_container = apply_filters( 'affilo_description_container', 'h4');
				echo '<' . $tag_container . ' id="blog-description">' . $tagline . '</' . $tag_container . '>';
			}
		}
		
		function hooks() {
			if(self::$logo_hook) {
				add_action(self::$logo_hook, array( $this, 'logo') );
			}
			add_action( 'wp_head', array( $this, 'favicon') );
		}
	}
	
	affilo_register_settings('affilo_header_settings');
?>