<?php
/**
 * Affiliate Redirects Admin
 */

//add generate rewrites hook
add_action('generate_rewrite_rules', 'affilo_add_rewrite_rules');
//add install hook
add_action('affilo_install', 'affilo_redirects_install');
//add upgrade hook
add_action('affilo_upgrade', 'affilo_redirects_upgrade');
//add hook to clear the rules on insall/upgrade
add_action('affilo_install', 'affilo_flush_rewrite_rules');
add_action('affilo_upgrade', 'affilo_flush_rewrite_rules');

/**
 * Admin init
 */
function affilo_affiliate_redirects_init() {
	add_option("affilo_affiliate_redirects_prefix","go");
}

/** Register and load tinymce plugin **/
function affilo_affiliate_redirects_addbuttons() {
   if ( ! current_user_can('edit_posts') && ! current_user_can('edit_pages') )
     return;
   if ( get_user_option('rich_editing') == 'true') {
     add_filter("mce_external_plugins", "add_affilo_affiliate_redirects_tinymce_plugin");
     add_filter('mce_buttons', 'register_affilo_affiliate_redirects_button');
   }
}
function register_affilo_affiliate_redirects_button($buttons) {
   array_push($buttons, "separator", "RedirectLinks");
   return $buttons;
}
function add_affilo_affiliate_redirects_tinymce_plugin($plugin_array) {
   $plugin_array['RedirectLinks'] =  SCRIPTS_URL."/redirects_mce_plugin.js.php";
   return $plugin_array;
}
// init process for button control
add_action('admin_head', 'affilo_affiliate_redirects_addbuttons');



/**
 * Affiliate Redirects Page
 */
function affilo_affiliate_redirects() {
	global $wpdb;
	$settings = affilo_redirect_settings();
	extract($settings);
	
	$action = !empty($_GET['action']) ? $_GET['action'] : false;
?>
<div class="wrap">
    <div id="icon-tools" class="icon32"><br/></div>

    <h2><?php _e( 'Affiliate Redirects', 'affilo'); ?></h2>

	<?php
		if (!get_option('permalink_structure')) {
			affilo_render_error('You need to enable permalinks to use Affiliate Redirects.<br/>Go to <a href="options-permalink.php">Permalinks</a> under Settings and choose any setting other than "Default"');
		}
	?>
	
    <div id="poststuff" class="metabox-holder" style="position:relative;clear:both; margin:20px 0 0 0">
        <?php 
            $render_forms=false;
			switch($action){
				case 'new':
					// do add 
					$render_forms = affilo_redirect_edit(affilo_redirect_clean_name($_POST['keycode']), $_POST['target'], $action);
					break;
				case 'add':
					// setup add form
					affilo_redirect_render_form('new');
					break;
				case 'delete':
					// do delete
					if(!empty($_POST['confirm'])){
						$delete = "DELETE FROM ".$tableName." WHERE id='".$wpdb->escape($_GET['id'])."'";
						$wpdb->query($delete);
						$render_forms=true;
						break;
					}				
					affilo_redirect_render_delete($action, $_GET['id']);
					break;
				case 'edit':
					// populate fields for edit
					$keycodeID = $_GET['id'];
					affilo_redirect_edit('', '', $action, $keycodeID);
					break;
				case 'edit2':
					// edit and commit				
					$keycodeID = $_POST['id'];
					affilo_redirect_edit(affilo_redirect_clean_name($_POST['keycode']), $_POST['target'], 'edit2', $keycodeID);
					break;
				case 'update-settings':
					affilo_redirect_update_settings();
					$render_forms=true;
					break;
				default:
					// anything else, just show the table.
					$render_forms=true;
					break;
			}
			if ($render_forms) {
			    affilo_redirect_render_settings_form();
			    affilo_redirect_render_table();
			}
    	?>
    </div>  <!-- metabox-holder -->
</div> <!-- wrap -->	
<?php
}


/**
 * Cirect edit/crete new functions
 */
function affilo_redirect_edit($keycode='', $target='', $action, $id=''){
	global $wpdb;
	$settings = affilo_redirect_settings();
	extract($settings);
	
	
	if($action == 'edit'){
		// edit mode
		$select = $wpdb->get_row('SELECT * FROM '.$tableName.' WHERE id=\''.$wpdb->escape($id).'\'', ARRAY_A);
        affilo_redirect_render_form('edit2', affilo_redirect_clean_name($select['keycode']), $select['target'], $select['id']);
	}
	if($action == 'edit2'){		
		// edit commit mode
		if(affilo_redirect_keycode_in_use($keycode, $_POST['id'])){
			affilo_render_error('"'.$keycode.'" has already been used. Please select a different name.');
			affilo_redirect_edit('', '', 'edit', $_POST['id']);
		} else if(affilo_redirect_target_in_use($target, $_POST['id'])){
			affilo_render_error('A redirect already exists for "'.$target.'".');
			affilo_redirect_edit('', '', 'edit', $_POST['id']);
		} 
		else {
			$update = "UPDATE " . $tableName . " SET target='".$wpdb->escape($target)."', keycode='".$wpdb->escape($keycode)."' WHERE id='".$id."'";
        	$results = $wpdb->query($update);
        	affilo_render_error('Redirect <strong>"'.$keycode.'"</strong> updated.', updated);
        	affilo_redirect_render_settings_form();
    	    affilo_redirect_render_table();
        }
	}
	if($action == 'new' && $keycode != ''){
		if(affilo_redirect_keycode_in_use($keycode)){
			affilo_render_error('"'.$keycode.'" has already been used. Please select a different name.');
			affilo_redirect_render_form('new', affilo_redirect_clean_name($_POST['keycode']), $_POST['target']);
		} else if(affilo_redirect_target_in_use($target)){
			affilo_render_error('A redirect already exists for "'.$target.'".');
			affilo_redirect_render_form('new', affilo_redirect_clean_name($_POST['keycode']), $_POST['target']);
		} else {
			$insert = "INSERT INTO " . $tableName . " (target, keycode) " . "VALUES ('" . $wpdb->escape($target) . "','" . $wpdb->escape($keycode) . "')";
        	$results = $wpdb->query($insert);
        	affilo_render_error('Redirect <strong>"'.$keycode.'"</strong> created.', updated);
        	return true;
        }
	}
}

function affilo_redirect_update_settings() {
	
	$new = affilo_redirect_clean_name($_POST['prefix']);
	$old = get_option("affilo_affiliate_redirects_prefix");
	
	$settings = affilo_redirect_settings();
	
	if($new)  {
		
		if($new != $old) {
			affilo_redirect_replace_redirect($old,$new);
			update_option("affilo_affiliate_redirects_prefix", $new);
			affilo_flush_rewrite_rules();
			affilo_add_rewrite_rules();
		}
	}
}

function affilo_redirect_replace_redirect($old, $new) {
	global $wpdb;
	
	$old_url = get_option('siteurl')."/".$old."/";
	$new_url = get_option('siteurl')."/".$new."/";
	
	$query = "UPDATE wp_posts SET post_content = REPLACE(post_content, '{$old_url}', '{$new_url}') WHERE post_content LIKE '%{$old_url}%'";
	
	$wpdb->query($query);
}


/**
 * Checks to see if a keycode is in use accepts an id to be excluded from check
 * E.g. you're editing that id's target, you can re-use the keycode
 */
function affilo_redirect_keycode_in_use($keycode, $id = false){
	global $wpdb;
	$settings = affilo_redirect_settings();
	extract($settings);
	if($id){
		$select = $wpdb->get_row('SELECT * FROM '.$tableName.' WHERE keycode=\''.$wpdb->escape($keycode).'\' AND id!=\''.$wpdb->escape($id).'\'', ARRAY_A);
	}
	else {
		$select = $wpdb->get_row('SELECT * FROM '.$tableName.' WHERE keycode=\''.$wpdb->escape($keycode).'\'', ARRAY_A);
	}
	return ($select) ? true : false;
}


/**
 * Checks to see if a target url is in use accepts an id to be excluded from check
 * E.g you're editing that id's keycode, you can re-use the target
 */
function affilo_redirect_target_in_use($target, $id = false){
	global $wpdb;
	$settings = affilo_redirect_settings();
	extract($settings);
	if($id){
		$select = $wpdb->get_row('SELECT * FROM '.$tableName.' WHERE target=\''.$wpdb->escape($target).'\' AND id!=\''.$wpdb->escape($id).'\'', ARRAY_A);
	}
	else {
		$select = $wpdb->get_row('SELECT * FROM '.$tableName.' WHERE target=\''.$wpdb->escape($target).'\'', ARRAY_A);
	}
	return ($select) ? true : false;
}


/**
 * Creates the delete form and opportunity to confirm or cancel delete
 */
function affilo_redirect_render_delete($action, $id){
	global $wpdb;
	$tableName = $wpdb->prefix .'affilliate_redirects';
	$select = $wpdb->get_row('SELECT * FROM '.$tableName.' WHERE id=\''.$wpdb->escape($id).'\'', ARRAY_A);
	?>
	<form action="admin.php?page=affilo_affiliate_redirects&action=<?php echo $action; ?>&confirm=true&id=<?php echo $id; ?>" method="post" class="redirect_form">
	 	<div>
			Are you sure you want to delete the redirect "<?php echo $select['keycode']; ?>"?
		</div>
		<p class="submit">
			<input type="submit" name="confirm" class="button" value="Delete" />
			&nbsp;&nbsp;&nbsp;<a href="admin.php?page=affilo_affiliate_redirects">Cancel</a>
		</p>
	</form>
	<?php
}


/**
 * creates form used to add and edit redirect entries
 */
function affilo_redirect_render_form($action, $keycode='', $target='', $id=''){ 
    $settings = affilo_redirect_settings(); 
?>    
	<form action="admin.php?page=affilo_affiliate_redirects&action=<?php echo $action; ?>" method="post" id="addDialog" class="redirect_form">
		<div id="post-body">
	 		<div id="post-body-content">
		       	<div id="namediv" class="stuffbox">
	          		<h3><label for="keycode">Name</label></h3>
		 	      	<div class="inside">
				    	<input name="keycode" type="text" value="<?php echo $keycode; ?>"/>
				    <p>Example: <code>affiliate</code> will produce the redirect <code><?php echo get_option('siteurl').'/'.$settings['redirectHandle'].'/<em>affiliate</em>/';?></code></p>
			    	</div>
		    	</div>
 				<div id="namediv" class="stuffbox">
					<h3><label for="keycode">Web Address</label></h3>
					<div class="inside">
						<input name="target" type="text" value="<?php echo $target; ?>"/>
				    	<p>Example: <code>http://www.affilorama.com</code> &mdash; don't forget the <code>http://</code></p>
					</div>
					<input name="id" type="hidden" value="<?php echo $id; ?>"/>
				</div>
			</div>
		</div>
		<div>
			<p class="submit">
				<?php $button = ($action=='add' || $action=='new') ? 'Create' : 'Update';?>
				<input type="submit" name="submit" class="button-primary" value="<?php echo $button; ?> " />
				&nbsp;&nbsp;&nbsp;<a href="admin.php?page=affilo_affiliate_redirects">Cancel</a>
			</p>
		</div>
	</form>
	<?php
}


/**
 * creates form used edit redirect settings
 */
function affilo_redirect_render_settings_form(){
	$settings = affilo_redirect_settings();

?>
    <div>
	<form action="admin.php?page=affilo_affiliate_redirects&action=update-settings" method="post" id="addDialog" style="width:550px;" class="redirect_form">
		<div id="post-body">
	 		<div id="post-body-content">
		       	<div id="namediv" class="stuffbox">
	          		<h3><label for="keycode">Prefix</label></h3>
		 	      	<div class="inside">
				    	<input type="text" name="prefix" value="<?php echo $settings['redirectHandle']; ?>">
							
						<p>Prefix for url redirects, Eg. <?php echo get_option('siteurl').'/<em>'.$settings['redirectHandle'].'</em>/affiliate/'; ?></p>
			    	</div>
		    	</div>
			</div>
		</div>
		<div>
			<input type="submit" name="submit" class="button-primary" value="Save" />
		</div>
	</form>
	<br/><br/>
	<?php
}



/**
 * Cleans names to be url-safe
 */
function affilo_redirect_clean_name($text){ 
    $text = trim($text); 
    $removeChars  = array( "([\40])" , "([^a-zA-Z0-9-])", "(-{2,})" ); 
    $replaceWith = array("-", "", "-"); 
    return preg_replace($removeChars, $replaceWith, $text); 
} 


/**
 * Table of values
 */
function affilo_redirect_render_table(){
	global $wpdb;
	$settings = affilo_redirect_settings();
	extract($settings);
	$result = $wpdb->get_results("SELECT * FROM $tableName;", ARRAY_A);	
	?>
	<div style="position:relative;clear:both; margin:0 0 20px 0">
		<a href="admin.php?page=affilo_affiliate_redirects&action=edit&action=add" class="button-primary"><?php _e('Add New Redirect', 'affilo') ?></a>
	</div>
	<table class="widefat page fixed">
		<thead>
			<tr>
				<th class="manage-column column-cb keycode">Display Text</th>
				<th class="manage-column column-cb">Link URL</th>
				<th class="manage-column column-cb clicks">Clicks</th>
				<th class="manage-column column-cb action" colspan="3">Action</th>
			</tr>
		</thead>
			<tbody>
				<?php affilo_redirect_render_rows($result); ?>
			<tbody>
		</table>
	</div> <!-- end of wrap container -->
	<div style="position:relative;clear:both; margin:20px 0">
		<a href="admin.php?page=affilo_affiliate_redirects&action=edit&action=add" class="button-primary"><?php _e('Add New Redirect', 'affilo') ?></a>
	</div>
	<?php
}


/**
 * Creates the list of redirects
 */
function affilo_redirect_render_rows($table){
	global $wpdb;
	$settings = affilo_redirect_settings();
	extract($settings);
	$i = 0;
	foreach($table as $row){
		$targetDisplayURL = get_option('siteurl') . '/' . $redirectHandle . '/' . $row['keycode'];
		$alt = $i++ % 2 == 0 ? '' : 'alternate'
		?>
			<tr class="iedit <?php echo $alt; ?> ">
				<td>
					<strong class="row-title">
						<?php echo $row['keycode']; ?>
					</strong>
				</td>
				<td>
					<a href=" <?php echo $targetDisplayURL; ?>" target="_blank"><?php echo $targetDisplayURL; ?></a>
				</td>
				<td class="clicks">
					<?php echo $row['clicks']; ?>
				</td>
				<td class="action ddm_view">
					<a href="<?php echo $targetDisplayURL; ?>" target="_blank">view</a>
				</td>
				<td class="action ddm_edit">
					<a href="admin.php?page=affilo_affiliate_redirects&action=edit&id=<?php echo $row['id']; ?>">edit</a>
				</td>
				<td class="action ddm_delete">
					<a href="admin.php?page=affilo_affiliate_redirects&action=delete&id=<?php echo $row['id']; ?>">delete</a>
				</td>
			</tr>
		<?php
	}
}


/**
 * Flush rewrite rules
 */
function affilo_flush_rewrite_rules(){
	global $wp_rewrite;
	
	$wp_rewrite->flush_rules();
}


/**
 * Add rewrite rules to WP
 */
function affilo_add_rewrite_rules(){ 
	global $wp_rewrite;
	
	$settings = affilo_redirect_settings();
	extract($settings);
	
	$affilo_rules = array($redirectHandle . '/(.+)' => 'index.php?red=$1');
 	$wp_rewrite->non_wp_rules = $affilo_rules + $wp_rewrite->non_wp_rules;
}


/**
 * Install hook for Affiliate Redirects
 */
function affilo_redirects_install() {
	global $wpdb;
	
	$settings = affilo_redirect_settings();
	extract($settings);

	// check if table exists
	if ($wpdb->get_var("SHOW TABLES LIKE '{$tableName}'") != $tableName) {
		//create table
		$schema = join(', ', array(
    		'id mediumint(11) NOT NULL AUTO_INCREMENT',
    		'target varchar(255) NOT NULL',
    		'keycode varchar(255) NOT NULL',
    		'clicks mediumint(15) NOT NULL',
    		'UNIQUE KEY id (id)'
    	));
        $sql = "CREATE TABLE {$tableName} ({$schema});";
        $wpdb->query($sql);
        
        // insert an example value
        $exampleTarget = $wpdb->escape("http://www.affilotheme.com");
        $exampleKey = $wpdb->escape("affiliate");
        $insert = "INSERT INTO {$tableName} (target, keycode) VALUES ('{$exampleTarget}', '{$exampleKey}');";
        $results = $wpdb->query($insert);
        
        //create options
        add_option("affilo_redirect_handle", $redirectHandle);
        add_option("affilo_redirect_db_version", $dbVersion);
    }
}


/**
 * Upgrade Affiliate Redirects
 */
function affilo_redirects_upgrade(){}
?>