<?php
/*
 * Squeeze Page Admin
 */

if (defined('DONT_USE_CDN') && DONT_USE_CDN)
{
    define('SQZ_PREVIEW_SRC', INCLUDES_URL . '/sqz-page');
} else {
    define('SQZ_PREVIEW_SRC', 'http://cdn.affilorama.com/files/affilotheme/includes/sqz-page');
}
/**
 * Admin config / setup
 */
function affilo_signup_shortcode_meta_box_admin_setup() {
	add_meta_box( 'theme-signup-shortcode-meta-box', __( 'Shortcode', 'affilo' ), 'affilo_signup_shortcode_meta_box', 'sqz-page', 'side', 'default' );
	add_meta_box( 'theme-signup-meta-box', __( 'Newsletter Settings', 'affilo' ), 'affilo_signup_meta_box', 'sqz-page', 'side', 'default' );
}
add_action( 'admin_menu', 'affilo_signup_shortcode_meta_box_admin_setup' );

/**
 * Edit Page meta boxes / assets
 */
function affilo_sqz_page_meta_box_callback() {
	add_meta_box( 'affilo_sqz_page_layout_options', __( 'Layout Options', 'affilo' ), 'affilo_sqz_page_layout_options', 'sqz-page', 'normal', 'low' );
	add_meta_box( 'affilo_sqz_page_variation_options', __( 'Layout Variations', 'affilo' ), 'affilo_sqz_page_variation_options', 'sqz-page', 'normal', 'low' );
	add_meta_box( 'affilo_sqz_page_content_options', __( 'Content Options', 'affilo' ), 'affilo_sqz_page_content_options', 'sqz-page', 'normal', 'low' );
	add_meta_box( 'affilo_sqz_page_popover_options', __( 'Popover Settings', 'affilo' ), 'affilo_sqz_page_popover_options', 'sqz-page', 'normal', 'low' );
}

/**
 * Get squeeze page internal type(s)
 */
function affilo_sqz_types($type = null) {
	$types = array(
		'squeeze' => 'Squeeze Page',
		'sidebar' => 'Sidebar Form',
		'feature' => 'Feature Form',
		'full_feature' => 'Full Feature Form'
	);
	if (isset($type)) {
		return isset($types[$type]) ? $types[$type] : $type;
	}
	return $types;
}


/**
 * Set custom cllumns for listing table
 */
function affilo_sqz_page_columns( $columns ) {
	unset( $columns['date'] ); // remove date column
	$columns['type'] = 'Type';
	$columns['usage'] = 'URL/Shortcode';
	$columns['date'] = 'Date';
	return $columns;
}
add_filter( 'manage_edit-sqz-page_columns', 'affilo_sqz_page_columns', 10, 1 );


/**
 * Format custom collumn output
 */
function affilo_sqz_page_custom_columns( $column, $post_id ) {	
	switch( $column ) {
		case 'type':
			echo affilo_sqz_types(get_post_meta($post_id, 'sqz-form-type', true));
		break;
		case 'usage':
			if (get_post_meta($post_id, 'sqz-form-type', true) == 'squeeze') {
				$permalink = get_post_permalink($post_id);
				echo '<a href="' . $permalink . '" target="_blank" title="Squeeze page URL, click to view">' . str_replace(home_url(), '', $permalink) . '</a>';
			} else {
				echo affilo_signup_shortcode($post_id);
			}
		break;
	}
}
add_action( 'manage_sqz-page_posts_custom_column', 'affilo_sqz_page_custom_columns', 10, 2 );


/**
 * Add sortable collumns
 */
function affilo_sqz_page_sortable_columns( $columns ) {
	$columns['type'] = 'type';
	return $columns;
}
add_filter( 'manage_edit-sqz-page_sortable_columns', 'affilo_sqz_page_sortable_columns', 10, 3 );


/**
 * Add sort filter for custom collumns
 */
function affilo_sqz_page_edit_load() {
	add_filter( 'request', 'affilo_sqz_page_sort' );
}
add_action( 'load-edit.php', 'affilo_sqz_page_edit_load' );


/**
 * Apply custom collumn sorting
 */
function affilo_sqz_page_sort( $vars ) {
	if ( isset( $vars['post_type'] ) && 'sqz-page' == $vars['post_type'] ) {
		if ( isset( $vars['orderby'] )) {
			switch($vars['orderby']) {
				case 'type':
					$vars = array_merge(
						$vars,
						array(
							'meta_key' => 'sqz-form-type',
							'orderby' => 'meta_value'
						)
					);
				break;
			}
			
		}
	}
	return $vars;
}

/**
 * Newsletter settings sidebar meta box
 */
function affilo_signup_meta_box($post) {
	AffiloSignup::load(true);
	affilo_signups_do_edit($post->ID);
}

function affilo_signup_shortcode_meta_box($post) {
	echo '<p>Embed this Signup Form using this shortcode:</p>';
	echo affilo_signup_shortcode($post->ID);
}

function affilo_signup_shortcode($post_id) {
	return '<input class="text urlfield" readonly="readonly" onclick="this.select()" title="Embed this Signup Form using this shortcode" value="[signup id=&quot;' . $post_id . '&quot;]" type="text">';
}

/**
 * 
 * Layout options meta box
 */
function affilo_sqz_page_layout_options($post) {
	
	echo affilo_input::hidden('noncename', wp_create_nonce( plugin_basename( __FILE__ ) ));
	
	if ($type = get_post_meta($post->ID, 'sqz-form-type', true)) {
		$typeSelect = '<input type="text" id="affilo-type-created" name="affilo[__type]" class="select option-select-large left" readonly="readonly" value="'.affilo_sqz_types($type).'" />';
		echo affilo_input::hidden('type', $type);
	} else {
		$typeSelect = affilo_input::render(array(
			'id' => 'type',
			'label' => false,
			'type' => 'select',
			'options' => affilo_sqz_types(),
			'align' => 'left',
			'wrap' => false
		));
	}
	echo '
		<div id="affilo-sqz-type">
			<div class="inner">
			<h3>Newsletter opt-in type:</h3>
			' . $typeSelect . '
			</div>
			<div class="clearfix"></div>
			<div id="affilo-sqz-slug">
				<div id="affilo-slug-box"><strong>Permalink:</strong> Enter title to generate link</div>
			</div>
		</div>
	';
	
	if ($type) {
		$layouts = array($type => affilo_sqz_page_load_layouts($type));
	} else {
		$layouts = affilo_sqz_page_load_layouts();
	}
	$value = get_post_meta($post->ID, 'sqz-layout', true);
	foreach ($layouts as $layout => $options) {
		$_value = $value;
		if (!$_value || !isset($options[$_value])) {
			reset($options);
			$_value = key($options);
		}
		$class = '';
		if (($type && $type == $layout) || (empty($type) && $layout == 'squeeze')) {
			$class = ' current';
		}
		echo '
			<div id="sqz-layouts-'.$layout.'" class="sqz-layout-group'.$class.'">
			<div class="scrollingContainer">
				<div class="scrollingHotSpotLeft"></div><div class="scrollingHotSpotRight"></div>
				<ul class="connectedSortable">
			';
			foreach ($options as $name => $settings) {
				$checked = $name == $_value ? 'checked="checked"' : '';
				$imgUrl = $settings['screenshot'];
				echo  '<li class="affilo_item">
					<div class="layout-container">
						<label title="' . $settings['name'] . '" for="' . affilo_input::id('layout' . '.' . $layout . '.' . $name) . '">
							<input title="' . $settings['name'] . '" type="radio" id="' . affilo_input::id('layout' . '.' . $layout . '.' . $name) . '" class="sqz-layout-select" value="' . $name . '" name="' . affilo_input::name('layout' . '.' . $layout) . '" ' . $checked . ' />
							<a href="' . $imgUrl . '" title="' . $settings['name'] . '" rel="'.$settings['screenshot'].'" class="sqz-screenshot-src"></a>
						</label>
					</div>
				</li>';
			}
		echo '
				</ul>
			</div>';
		
		if ($layout == 'squeeze'){
			affilo_sqz_page_template_options($post);
		}
		
		echo '
			</div>
		';
	}	
}

function affilo_sqz_page_template_options($post) {
	$options = (array) get_post_meta($post->ID, 'sqz-page-template-options', true);
	$options += array(
		'header' => 'true',
		'footer' => 'true'
	);
	echo '<hr class=""/>';
	echo affilo_input::intro('sqz-page-template-options-intro', 'Page Template Options', 'Control how your squeeze page displays by enabling/disabling the outer page elements from your main site theme.');
	echo affilo_input::render(array(
		'id' => 'sqz-page-template-options.header',
		'type' => 'checkbox',
		'label' => 'Display Header',
		'value' => $options['header']
	));
	echo affilo_input::render(array(
		'id' => 'sqz-page-template-options.footer',
		'type' => 'checkbox',
		'label' => 'Display Footer',
		'value' => $options['footer']
	));	
}

function affilo_sqz_page_variation_options($post) {
	$type = get_post_meta($post->ID, 'sqz-form-type', true);
	if ($type) {
		$layouts = array($type => affilo_sqz_page_load_layouts($type));
	} else {
		$layouts = affilo_sqz_page_load_layouts();
	}
	
	$value = $_value = get_post_meta($post->ID, 'sqz-variation', true);
	reset($layouts);
	foreach ($layouts as $layout => $options) {
		$class = '';
		if (($type && $type == $layout) || (empty($type) && $layout == 'squeeze')) {
			$class = ' current';
		}
		echo '<div id="sqz-variations-'.$layout.'" class="sqz-variations'.$class.'">';
			foreach ($options as $name => $variations) {
				$variations = affilo_sqz_page_load_layout_variations($layout, $name);
				if (!$value) {
					reset($variations);
					$_value = key($variations);
				}
				echo '
					<div class="scrollingContainer sqz-variations-'.$layout.'" id="sqz-variations-'.$layout.'-'.$name.'">
						<div class="scrollingHotSpotLeft"></div><div class="scrollingHotSpotRight"></div>
						<ul class="connectedSortable">
					';
					foreach ($variations as $var => $settings) {
						$checked = $var == $_value ? 'checked="checked"' : '';
						$imgUrl = $settings['screenshot'];
						echo  '<li class="affilo_item">
							<div class="layout-container">
								<label title="' . $settings['name'] . '" for="' . affilo_input::id('variation' . '.' . $layout . '.' . $name . '.' . $var) . '">
									<input title="' . $settings['name'] . '" type="radio" id="' . affilo_input::id('variation' . '.' . $layout . '.' . $name . '.' . $var) . '" value="' . $var . '" name="' . affilo_input::name('variation' . '.' . $layout . '.' . $name) . '" ' . $checked . ' />
									<a href="' . $imgUrl . '" title="' . $settings['name'] . '" rel="'.$settings['screenshot'].'" class="sqz-screenshot-src"></a>
								</label>
							</div>
						</li>';
					}
				echo '
						</ul>
					</div>
				';	
			}
		echo '</div>';
	}
}

function affilo_sqz_page_content_options($post) {
	$type = get_post_meta($post->ID, 'sqz-form-type', true);
	if ($type) {
		$layouts = array($type => affilo_sqz_page_load_layouts($type));
	} else {
		$layouts = affilo_sqz_page_load_layouts();
	}
	echo affilo_input::font('placeholder-font-field', '', '', array(false, 'family' => true));
	
	$data = get_post_meta($post->ID, 'sqz-fields', true);

	foreach ($layouts as $layout => $options) {
		echo '<div id="sqz-content-'.$layout.'" class="affilobox sqz-content">';
		foreach ($options as $name => $settings) {
			$_data = array();
			if (get_post_meta($post->ID, 'sqz-form-type', true) == $layout) {
				$_data = $data;
			}
			echo '<div id="sqz-content-'.$layout.'-'.$name.'" class="sqz-content-'.$layout.'">';
				foreach ($settings['fields'] as $id => $settings) {
					if (!isset($settings['label'])) {
						$settings['label'] = ucwords(str_replace(array('_', '-', '.'), ' ', $id));
					}
					if (strpos($id, '.')) {
						$path = explode('.', $id);
						$__data = $_data;
						while ($cid = array_shift($path)) {
							if (isset($__data[$cid])) {
								$__data = $__data[$cid];
							} else {
								$__data = null;
							}
						}
						if (empty($path) && isset($__data)) {
							$value = $__data;
						} else {
							$value = isset($settings['default']) ? $settings['default'] : '';
						}
					} else {
						$value = isset($_data[$id]) ? $_data[$id] : (isset($settings['default']) ? $settings['default'] : '');	
					}
					$prefix = "content.{$layout}.$name";
					$id = "{$prefix}.{$id}";
					$settings = compact('id', 'value', 'prefix', '_data') + (array) $settings;
					echo '<div>' . affilo_input::render($settings) . '</div>';
				}
			echo '</div>';
		}
		echo '</div>';
	}
}

/**
 * Extract the content fields from a given sqz layout config,
 * recrusivly map to single level array with default values
 */
function affilo_sqz_page_content_defaults($type, $layout, $default = '') {
	if (is_array($type) && $layout === true) {
		$fields = $type;
	} else {
		$config = affilo_sqz_page_load_layout($type, $layout);
		$fields = $config['fields'];
	}
	$defaults = array();
	foreach ($fields as $field => $settings) {
		if (isset($settings['before']) && is_array($settings['before'])) {
			$defaults += affilo_sqz_page_content_defaults($settings['before'], true);
		}
		
		$defaults[$field] = isset($settings['default']) ? $settings['default'] : $default;
		
		if (isset($settings['after']) && is_array($settings['after'])) {
			$defaults += affilo_sqz_page_content_defaults($settings['after'], true, $default);
		}
	}
	return $defaults;
}


function affilo_sqz_page_popover_options($post) {
	$options = (array) get_post_meta($post->ID, 'sqz-popover-options', true) + affilo_sqz_page_popover_defaults();
	$popover = !empty($options['enabled']) ? 'true' : false;
	echo affilo_input::render(array(
		'id' => 'popover.enabled',
		'label' => 'Use this form as a popover?',
		'type' => 'checkbox',
		'value' => $popover
	));
	echo '<div id="popoverOptions"'.($popover?'':' style="display:none"').'>';
	?>
	<div class="col col-third">
		<div id="popoverLocations" class="posttypediv">
			<h4>Display Locations:</h4>
			<script type="text/javascript">
				var popoverLocations = [<?php echo join(',', $options['locations']);?>];
			</script>
			<div id="popoverLocationTabs">
				<ul id="posttype-page-tabs" class="posttype-tabs add-popover-location-tabs">
					<li class="tabs"><a class="nav-tab-link" href="#tabs-panel-pages">Pages</a></li>
					<li class="tabs"><a class="nav-tab-link" href="#tabs-panel-posts">Posts</a></li>
					<li class="tabs"><a class="nav-tab-link" href="#tabs-panel-sqz-pages">Squeeze Pages</a></li>
				</ul>
				<div id="tabs-panel-pages" class="tabs-panel tabs-panel-active">
					<ul id="pagechecklist-pages" class="categorychecklist form-no-clea popover-locations">
						<?php affilo_list_pages();?>
					</ul>
				</div>
				<div id="tabs-panel-posts" class="tabs-panel tabs-panel-inactive">
					<ul id="pagechecklist-posts" class="categorychecklist form-no-clea popover-locations">
						<?php affilo_list_pages(array('post_type' => 'post'));?>
					</ul>
				</div>
				<div id="tabs-panel-sqz-pages" class="tabs-panel tabs-panel-inactive">
					<ul id="pagechecklist-sqz-pages" class="categorychecklist form-no-clea popover-locations">
						<?php affilo_list_pages(array('post_type' => 'sqz-page'));?>
					</ul>
				</div>
			</div>
			<p class="button-controls">
				<span class="list-controls">
					<a href="#" class="select-all" id="popover-location-all">Select All</a>
					<a href="#" class="deselect-all" id="popover-location-none">Deselect All</a>
				</span>			
			</p>
		</div>
	</div>
	<div class="col col-sixth">&nbsp;</div>
	<div class="col col-half">
		<div id="popoverControl" class="popoverSection affilobox">
			<h4>Display Control:</h4>
			
			<?php 
				echo affilo_input::render(array(
					'type' => 'select',
					'align' => 'left',
					'id' => 'popover.mode',
					'label' => 'Display Mode',
					'options' => array(
						'load' => 'Page Open',
						'exit' => 'Page Exit'
					),
					'value' => $options['mode'],
					'desc' => 'Choose when your popup displays'
				));
			?>
			<div id="popoverDisplayLoad">
				<?php 
					echo '<p>' . affilo_input::render(array(
						'type' => 'text',
						'size' => 'small',
						'id' => 'popover.delay',
						'label' => 'Delay Time',
						'value' => $options['delay'],
						'desc' => 'Tell the popover to wait a set amount of time before displaying'
					)) . '</p>';
					echo '<p>' . affilo_input::render(array(
						'type' => 'text',
						'size' => 'small',
						'id' => 'popover.close',
						'label' => 'Close Time',
						'value' => $options['close'],
						'desc' => 'Tell the popover to automatically close after a set amount of time'
					)) . '</p>';
				?>
			</div>
			<div id="popoverDisplayExit">
				<?php 
					echo affilo_input::render(array(
						'type' => 'textarea',
						'size' => 'small',
						'id' => 'popover.exit_text',
						'label' => 'Exit Text',
						'value' => $options['exit_text'],
						'desc' => 'Exit popopovers must prompt the user to confirm they want to stay on the current page before displaying.<br>
									Some browsers allow you to add custom text to the prompt, you can enter custom text here. *Not supported by all browsers'
					));
				?>
			</div>
		</div>
	</div>
	<div class="col-clear"></div>
	<div class="col col-half">
		<div id="popoverOptions" class="popoverSection affilobox">
			<h4>Display Options:</h4>
			<?php 
				echo affilo_input::render(array(
					'type' => 'select',
					'align' => 'left',
					'id' => 'popover.position',
					'label' => 'Popover Position',
					'desc' => 'The position on your page where the popover appears',
					'options' => array(
						'0 0' => 'Top/Left',
						'50 0' => 'Top/Center',
						'0 100' => 'Top/Right',
						'0 50' => 'Middle/Left',
						'50 50' => 'Middle/Center',
						'100 50' => 'Middle/Right',
						'0 100' => 'Bottom/Left',
						'50 100' => 'Bottom/Center',
						'100 100' => 'Bottom/Right'
					),
					'value' => $options['position']
				));
				echo affilo_input::render(array(
					'type' => 'checkbox',
					'id' => 'popover.overlay',
					'label' => 'Display a coloured overlay over main page content',
					'value' => $options['overlay']
				));
			?>
			<div id="popoverOverly">
				<?php 
					echo affilo_input::render(array(
						'type' => 'color',
						'id' => 'popover.o_color',
						'label' => 'Overlay Color',
						'value' => $options['o_color']
					));
					$opacity = array();
					$i = 0;
					while ($i <= 10) {
						$key = ($i/10);
						$value = ((10 - $i++) * 10);
						if ($value == 0) {
							$value = 'Solid Color';
						} elseif ($value == 100) {
							$value = 'Transparent';
						} else {
							$value.= '%';
						}
						$opacity["{$key}"] = $value;
					}
					echo affilo_input::render(array(
						'type' => 'select',
						'align' => 'left',
						'id' => 'popover.o_opacity',
						'label' => 'Overlay Transparency',
						'value' => $options['o_opacity'],
						'options' => $opacity
					));
				?>
			</div>
			<?php 
				echo affilo_input::render(array(
					'type' => 'select',
					'align' => 'left',
					'id' => 'popover.close_pos',
					'label' => 'Popover close button position',
					'value' => $options['close_pos'],
					'options' => array(
						'none' => 'No close button',
						'left' => 'Top/Left',
						'right' => 'Top/Right'
					)
				));
			?>			
		</div>
	</div>
		
	<div class="col col-half">
		<div id="popoverFreq" class="popoverSection affilobox">
			<h4>Display Frequency:</h4>
			<?php 
				echo affilo_input::render(array(
					'type' => 'select',
					'align' => 'left',
					'size' => 'massive',
					'id' => 'popover.limit',
					'options' => array(
						'none' => 'Display popover on every visit',
						'defined' => 'Display popover only a set number of times.'
					),
					'desc' => 'Show popover on every page visit, or limit to a set number of times',
					'value' => $options['limit']
				));
			?>
			<div id="popoverFreqDefined">
				<?php 
					echo affilo_input::render(array(
						'type' => 'text',
						'size' => 'small',
						'id' => 'popover.frequency',
						'label' => 'Display Limit',
						'desc' => 'Select how many times your popover will appear to each user',
						'value' => $options['frequency']
					));
					echo affilo_input::render(array(
						'type' => 'select',
						'align' => 'left',
						'size' => 'massive',
						'id' => 'popover.period',
						'label' => 'Display Period',
						'options' => array(
							'day' => 'Display x times per day',
							'week' => 'Display x times per week',
							'month' => 'Display x times per month'
						),
						'desc' => 'Select the time period',
						'value' => $options['limit']
					));
				?>
			</div>
		</div>
	</div>
	<div class="col-clear"></div>
	
		
	<?php
	
	
	
	
	
	
	
	
	echo '</div>';
}


/**
 * Save Squeeze Page post type
 */
function affilo_sqz_page_save( $post_id ) {
	//taken from affilo/plugin/slideshows
	if (!isset( $_POST['affilo']['noncename'] ) || !wp_verify_nonce( $_POST['affilo']['noncename'], plugin_basename( __FILE__ ) ) // security check
		|| 'page' == $_POST['post_type'] && !(current_user_can( 'edit_page', $post_id ) || current_user_can( 'edit_post', $post_id )) // check permissions
		|| !affilo_verify_post_type('sqz-page')) return $post_id; // verify post type
	
	if (!get_post_meta($post_id, 'sqz-form-type', true)) {
		add_post_meta($post_id, 'sqz-form-type', $_POST['affilo']['type'], true);
	}
		
	if (defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE) {
		
	}
	affilo_sqz_page_save_meta($post_id, $_POST);
}
add_action('save_post', 'affilo_sqz_page_save' );

/**
 * Internal method to set meta data required for squeeze pages
 * 
 * @param int Post.id
 * @param array $post $_POST as per sqz admin
 */
function affilo_sqz_page_save_meta($post_id, $post) {
	$data = $post['affilo'];
	$type = $data['type'];
	$layout  = $data['layout'][$type];
	$variation = $data['variation'][$type][$layout];
	$fields = $data['content'][$type][$layout];
	//wysiwyg's have diff name structures, format and extract
	$wysiwygKey = "affilo-content-{$type}-{$layout}-";
	$keys = preg_grep("/{$wysiwygKey}/", array_keys($post));	
	if ($keys) {
		foreach ($keys as $key) {
			$dataKey = str_replace($wysiwygKey, '', $key);
			$fields[$dataKey] = $post[$key];
		}
	}
	$provider = isset($data['provider']['name']) ? $data['provider']['name'] : null;
	$list = $provider && isset($data['provider']['config'][$provider]) ? $data['provider']['config'][$provider] : null;
	
	//popover config
	$popCurrent = (array) get_post_meta($post_id, 'sqz-popover-options', true);
	$popDefault = affilo_sqz_page_popover_defaults();
	$popData = !empty($data['popover']['enabled']) ? $data['popover'] : array();
	$popLocations = array();
	$popOldLocations = !empty($popCurrent['locations']) ? $popCurrent['locations'] : array();
	if (!empty($popData)) {
		$popData = affilo_sqz_page_popover_sanitize_options($popData);
		if (!empty($popData['locations'])) {
			$popLocations = $popData['locations'];
		}
	}
	
	$_popLocations = $popLocations;
	$popLocations = array_diff($popLocations, $popOldLocations);
	$popOldLocations = array_diff($popOldLocations, $_popLocations);
	
	if (!empty($popOldLocations)) {
		foreach ($popOldLocations as $popOldLocation) {
			delete_post_meta($popOldLocation, 'sqz-popover-post');
		}
	}
	if (!empty($popLocations)) {
		foreach ($popLocations as $popLocation) {
			update_post_meta($popLocation, 'sqz-popover-post', $post_id);
		}
	}
	
	//get config for selected input
	$config = affilo_sqz_page_load_layout($type, $layout);
	$css = '/* -- */';
	if ($config && !empty($config['styles'])) {
		$css.= affilo_sqz_page_format_style_overides($post_id, $fields, $config['styles']);
	}
	
	//store meta data
	update_post_meta( $post_id, 'sqz-popover-options', $popData );
	update_post_meta( $post_id, 'sqz-form-provider', $provider );
	update_post_meta( $post_id, 'sqz-form-list', $list );
	update_post_meta( $post_id, 'sqz-form-type', $type );
	update_post_meta( $post_id, 'sqz-layout', $layout );
	update_post_meta( $post_id, 'sqz-variation', $variation );
	update_post_meta( $post_id, 'sqz-fields', $fields );
	update_post_meta( $post_id, 'sqz-css', $css );
	
	//squeeze page specific options
	if ($type == 'squeeze') {
		$templateOptions = array();
		if (isset($data['sqz-page-template-options'])) {
			$templateOptions += $data['sqz-page-template-options'];
		}
		$templateOptions += $data['_sqz-page-template-options'];
		update_post_meta( $post_id, 'sqz-page-template-options', $templateOptions );
	}
}

function affilo_sqz_page_popover_sanitize_options($options) {
	$defaults = affilo_sqz_page_popover_defaults();
	$options['locations'] = (array) $options['locations'];
	foreach ($options['locations'] as $loc) {
		$loc = (int) $loc;
	}
	$options['locations'] = array_filter($options['locations']);
	if (empty($options['o_color']) || !preg_match('/#[abcdef0-9]{6}/i', $options['o_color'])) {
		$options['o_color'] = $defaults['o_color'];
	}
	if (empty($options['overlay'])) {
		$options['overlay'] = false;
	}
	if (is_numeric($options['o_opacity'])) {
		$options['o_opacity'] = $options['o_opacity'] > 1 ? 1 : $options['o_opacity'];
		if ($options['o_opacity'] < 0) {
			$options['o_opacity'] = $defaults['o_opacity'];
		}
	} else {
		$options['o_opacity'] = $defaults['o_opacity'];
	}
	
	$options['delay'] = $options['delay'] ? (int)$options['delay'] : 0;
	$options['close'] = $options['close'] ? (int)$options['close'] : 0;
	$options['frequency'] = $options['frequency'] ? (int)$options['frequency'] : 0;
	$options['exit_text'] = strip_tags($options['exit_text']);
	return $options + $defaults;
}

function affilo_sqz_page_load_layouts($type = null) {
	static $layouts = array();
	if ($type) {
		if(!isset($layouts[$type]) && affilo_sqz_types($type)) {
			$layouts[$type] = array();
			if ($config = affilo_sqz_page_load_layout_options($type)) {
				$layouts[$type] = $config;
				return $config;
			}
		}
		if (isset($layouts[$type])) {
			return $layouts[$type];
		}
	} else {
		$types = affilo_sqz_types($type);
		foreach ($types as $type => $name) {
			if (!isset($layouts[$type]) && $config = affilo_sqz_page_load_layouts($type)) {
				$layouts[$type] = $config;
			}
		}
		return $layouts;	
	}
}

function affilo_sqz_page_load_layout($type, $layout) {
	$types = affilo_sqz_page_load_layouts($type);
	if ($types && isset($types[$layout])) {
		return $types[$layout];
	}
}

function affilo_sqz_page_load_layout_variations($type, $layout) {
	$layouts = affilo_sqz_page_load_layouts($type);
	$variations = array();
	if (isset($layouts[$layout]['variations'])) {
		$variations = $layouts[$layout]['variations'];
		foreach ($variations as $key => &$var) {
			$name = $var;
			$img = $key == 'default' ? $type : $type . '_'. $key;
			$var = array(
				'name' => $name,
				'screenshot' => SQZ_PREVIEW_SRC . '/' . $layout . '/' . $img .'.jpg',
			);
		}
	}
	return $variations;
}

function affilo_sqz_page_load_layout_options($type) {
	$filename = SQZ_TEMPLATE_PATH . '/' . $type . '_layouts.php';
	if (file_exists($filename)) {
		include $filename;
 		if (isset($config)) {
			foreach ($config as $name => &$values) {
				if (is_string($values) && isset($config[$values])) {
					$values = $config[$values];
				}
				foreach ($values as $key => &$value) {
					$value = affilo_sqz_page_format_layout_option($key, $value, $config);
				}
				$values = array(
					'screenshot' => SQZ_PREVIEW_SRC . '/' . $name . '/' . $type . '.jpg',
					'path' => SQZ_TEMPLATE_PATH . '/' . $name,
					'url' => SQZ_TEMPLATE_URL . '/' . $name
				) + array_filter($values);
			}
			unset($config['default']);
			return array_filter($config);
 		}
	}
	return false;
}

function affilo_sqz_page_format_layout_option($key, $value, $config) {
		//pull from another config except whnere the key is name (the only allowed string value)		
		if ($key == 'name') {
			return $value;
		}
	
		while(is_string($value) && isset($config[$value][$key])) {
			$value = $config[$value][$key];
		}
	
		//merge from another config
		if (is_array($value) && isset($value[0]) && is_string($value[0])) {
			$inherit = array_map('trim', explode(',', $value[0]));
			unset($value[0]);
			$merge = false;
			$order = array();
			if (in_array('order', $value)) {
				$merge = true;
				unset($value[array_search('order', $value)]);
			} elseif (isset($value['order']) && is_array($value['order'])) {
				$merge = true;
				$order = $value['order'];
				unset($value['order']);
			}
			foreach ($inherit as $v) {
				if (isset($config[$v][$key])) {
					$_value = affilo_merge_recursive($config[$v][$key], $value);
					$value = $merge ? array_merge($value, $_value) : $_value;
					if (!empty($order)) {
						$ordered = array();
						foreach ($order as $o) {
							if (isset($value[$o])) {
								$ordered[$o] = $value[$o];
							}
						}
						$value = $ordered + $value;
					}
				}
			}
			return affilo_sqz_page_format_layout_option($key, $value, $config);
		}
		return $value;
}

function affilo_sqz_page_format_style_overides($post_id, $fields, $config) {
	$css = '';
	$id = '#sqz-id-' . $post_id;
	$styles = array();
	foreach ($config as $field => $settings) {
		if (isset($fields[$field])) {
			$settings = (array) $settings;
			$selector = isset($settings[1]) ? $settings[1] : $field;
			if (isset($fields[$selector])) {
				$selector = '.sqz-field-' . $selector;
			} elseif (strpos($selector, '.') === false && strpos($selector, '#') === false) {
				$selector = '.' . $selector;
			}
			if (!isset($styles[$selector])) {
				$styles[$selector] = array();
			}
			$styles[$selector][$settings[0]] = $fields[$field];
		}
	}
	if (!empty($styles)) {
		$css = affilo_style_settings::format_style_array($styles, $id);
	}
	return $css;	
}

/**
 * Newsletter Signups Add/Edit action
 */
function affilo_signups_do_edit($post_id = null) {
	global $wpdb;

	$data = array();
	$providers = AffiloSignup::formList();
	
	$action = 'add';
	if (isset($post_id) && $provider = get_post_meta( $post_id, 'sqz-form-provider', true )) {
		if ($_data = get_post_meta( $post_id, 'sqz-form-list', true )) {
			$data = $_data;
			$action = 'edit';
		}
	} else {
		$provider = 'AweberSignup';//key($providers);
	}
	?>
		<div class="affilobox">
 			<?php
 				echo affilo_input::render(array(
 					'type' => 'select',
 					'id' => 'provider.name',
 					'label' => 'List Provider',
					'value' => $provider,
					'desc' => 'Select the list provider for this form.',
					'options' => $providers,
 					'align' => 'left'
 				));
	 			?>
		</div>

		<?php
			foreach($providers as $class => $name) {
 				$providerClass = AffiloSignup::instance($class);
 		?>
 		<div class="affilo_signups_provider affilobox" id="<?php echo $class;?>">
			<h4><?php echo $providerClass->title();?> Options</h4>
			<div>
				<?php if($description = $providerClass->description()); {?>
				<p><a href="#<?php echo $class;?>Description" class="toggle desc">Provider Info</a></p>
				<div class="provider-desc" id="<?php echo $class;?>Description">
					<?php echo $description;?>
				</div>
				<?php }?>
				<?php
					$providerData = $providerClass->defaults();
					if ($provider == $class) {
						$providerData = $data + $providerData;
					}
					$fields = $providerClass->fields();
					foreach ($fields as $field => $settings) {
						$settings = array(
							'id' => "provider.config.{$class}.{$field}",
							'value' => $providerData[$field],
							'size' => 'medium'
						) + $settings;
						echo affilo_input::render($settings);
					}
				?>
			</div>
		</div>

 		<?php } ?>

		<div class="clearfix"></div>

	<?php
}

/**
 * Format a scaffolded signup provider field
 */
function affilo_signup_field($key, $default, $data) {
	$field = "config.content.{$key}";
	$id = affilo_input::id($field);
	$name = affilo_input::name($field);
	$value = isset($data['config']['content'][$key]) ? $data['config']['content'][$key] : $default;
	return compact('id', 'name', 'value');
}
?>