<?php
require_once(get_theme_root().'/affilotheme_2/includes/functions/common_theme_install.php');

/**
 * Affilo - Main class
 *
 * Loads all includes, theme constants, adds/removes filters, etc.
 *
 * @package Affilo
 * @subpackage Functions
 * @since Affilo 2.4.5
 */

class Affilo {
	// Initialize Affilo - set all constants, action affilo_init available for extending init.
	public function init() {
		global $blog_id;

		// If the old strcuture exists, we need to use style and template paths like
		// affilotheme_2/affilotheme_avenue until the files are moved, which "should" happen
		// right after this INIT call
		$template_directory = get_theme_root() . '/affilotheme_2';
		if (affilo_old_structure_exists()) {
			$stylesheet_directory = get_stylesheet_directory();
			if (!file_exists($template_directory . '/style.css')) {
				$template_directory = get_theme_root() . '/affilotheme_2/affilotheme_2';
			}
		} else {
			$stylesheet_directory = get_theme_root() . '/' . affilo_get_stylesheet_template();
		}

		$affilo_data = get_theme_data( $template_directory . '/style.css' );
		$theme_data = get_theme_data( $stylesheet_directory . '/style.css' );

		define( 'AFFILO_THEME', $affilo_data['Name'] );
		define( 'THEME_NAME', $theme_data['Name'] );
		define( 'THEME_VERSION', $theme_data['Version'] );
		define( 'THEME_OPTIONS', 'affilo' );
		define( 'THEME_PREFIX', 'affilo_' );
		define( 'AFFILO_VERSION', $affilo_data['Version'] );
		if (!defined('AFFILO_PREVIEW')) {
			define( 'AFFILO_PREVIEW', (isset($_GET['stylesheet']) && isset($_GET['preview']) ) ? $_GET['stylesheet'] : false);
		}
		define( 'IS_MU', (isset($blog_id) && $blog_id > 0) ? true : false );

		// Define Theme Paths
		define( 'THEME_PATH', $stylesheet_directory );
		define( 'THEME_URI', get_stylesheet_directory_uri() );
		define( 'AFFILO_PATH', $template_directory );
		define( 'INCLUDES_PATH', $template_directory . '/includes' );
		define( 'INCLUDES_URL', get_template_directory_uri() . '/includes' );
		define( 'ADMIN_PATH', INCLUDES_PATH . '/admin' );
		define( 'FUNCTIONS_PATH', INCLUDES_PATH . '/functions' );
		define( 'PLUGINS_PATH', INCLUDES_PATH . '/plugins' );
		define( 'SCRIPTS_URL', INCLUDES_URL . '/scripts' );
		define( 'WIDGETS_PATH', INCLUDES_PATH . '/widgets' );
		define( 'STYLES_URL', INCLUDES_URL . '/styles' );
		define( 'IMAGES_PATH', $template_directory . '/images' );
		define( 'IMAGES_URL', get_template_directory_uri() . '/images' );
		define('SHORTCODES_PATH', FUNCTIONS_PATH . '/shortcodes');
		define('SHORTCODES_URL', INCLUDES_URL . '/functions/shortcodes');
		define('SIGNUPS_PATH', FUNCTIONS_PATH . '/sign-ups');
		define('SIGNUPS_URL', INCLUDES_URL .'/functions/sign-ups');
		define('SQZ_TEMPLATE_PATH', INCLUDES_PATH . '/sqz-page');

		// If you want to run this locally, use this instead
		if (defined('DONT_USE_CDN') && DONT_USE_CDN)
        {
            define('SQZ_TEMPLATE_URL', INCLUDES_URL . '/sqz-page');
        } else {
            define('SQZ_TEMPLATE_URL', 'http://cdn.affilorama.com/files/affilotheme/includes/sqz-page');
        }

		// Register Default Scripts
		wp_register_script( 'affilo', SCRIPTS_URL . '/affilo.js', array('jquery', 'colorbox', 'md5', 'smoothScroll') );
		wp_register_script( 'ui', SCRIPTS_URL . '/jquery-ui-1.8.16.custom.min.js', array('jquery'), NULL );
		wp_register_script( 'colorbox', SCRIPTS_URL . '/jquery.colorbox.min.js', array('jquery'), NULL );
		wp_register_script( 'md5', SCRIPTS_URL . '/jquery.md5.js', array('jquery') );
		wp_register_script( 'galleriffic', SCRIPTS_URL . '/jquery.galleriffic.min.js', array('jquery') );
		wp_register_script( 'galleries', SCRIPTS_URL . '/galleries.js', array('galleriffic') );
		wp_register_script( 'hovercards', ( is_ssl() ? 'https://secure' : 'http://s' ) . '.gravatar.com/js/gprofiles.js?u', array('jquery') ); // Gravatar Hovercards
		wp_register_script( 'nivoslider',  SCRIPTS_URL . '/jquery-nivo/jquery.nivo.slider.js', array('jquery'), '1.0');
		wp_register_script( 'smoothScroll', SCRIPTS_URL . '/jquery.smooth-scroll.min.js', array('jquery'), '1.4');
		wp_register_script( 'prettyPhoto', SCRIPTS_URL . '/jquery.prettyPhoto.js', array('jquery'));

		// Register Default Styles
		wp_register_style( 'affilo', STYLES_URL . '/affilo.css' );
		wp_register_style( 'layouts', STYLES_URL . '/layouts.css' );
// 		wp_register_style( 'pushup', SCRIPTS_URL . '/jquery-pushup/pushup.css', null, null, 'screen' );
		wp_register_style( 'colorbox', STYLES_URL . '/colorbox.css', null, null, 'screen' );
		wp_register_style( 'comments', STYLES_URL . '/comments.css' );
		wp_register_style( 'reset', STYLES_URL . '/reset.css' );
		wp_register_style( 'images', STYLES_URL . '/images.css' );
		wp_register_style( 'shortcodes', STYLES_URL . '/shortcodes.css' );
		wp_register_style( 'typography', STYLES_URL . '/typography.css' );
		wp_register_style( 'print', STYLES_URL . '/print.css', null, null, 'print' );
		wp_register_style( 'nivo_slider', SCRIPTS_URL . '/jquery-nivo/css/nivo-slider.css', null, null, 'screen');
		wp_register_style( 'nivo_custom', SCRIPTS_URL . '/jquery-nivo/css/custom-nivo-slider.css', array('nivo_slider'), null, 'screen');

		// Translate, if applicable
		load_theme_textdomain( 'affilo', INCLUDES_PATH . '/languages' );


		//Squeeze Pages - Signup Forms
		require_once( FUNCTIONS_PATH . '/squeeze-pages.php' );
		//Redirects
		require_once( FUNCTIONS_PATH . '/redirects.php' );


		// Register functions, hooks, shortcodes, sidebars and comments
		require_once( FUNCTIONS_PATH . '/admin_settings.php' );	// Admin Functions
		require_once( FUNCTIONS_PATH . '/custom.php' );			// Custom Functions
		require_once( FUNCTIONS_PATH . '/hooks.php' );			// Hooks
		require_once( FUNCTIONS_PATH . '/shortcodes.php' );		// Shortcodes
		require_once( FUNCTIONS_PATH . '/sidebars.php' );		// Sidebars
		require_once( FUNCTIONS_PATH . '/comment_format.php' );	// Comment Structure

		//check if migration requirement has been checked, if not load
		if (is_admin()) {
			//temp incoming args to facilitate development
			//@todo remove
			if (isset($_GET['reset-migration'])) {
				affilo_delete_option('migrated');
				affilo_delete_option('migrate');
			} elseif (isset($_GET['skip-migration'])) {
				affilo_delete_option('migrated');
				affilo_delete_option('migrate');
				affilo_add_option('migrated', 'no');
			} elseif (isset($_GET['soft-migration'])) {
				affilo_delete_option('migrated');
				affilo_delete_option('migrate');
				affilo_add_option('migrate', 'soft');
			}
			if (!affilo_get_option('migrated')) {
				require_once( FUNCTIONS_PATH . '/migration.php' );	// Migrations
			}
		}

		require_once( PLUGINS_PATH.'/class-tgm-plugin-activation.php');

		add_action('tgmpa_register', array("Affilo", "register_required_plugins"));

		// Add child theme defaults if child theme is activated for the first time (Credit: Joel Kuczmarski)
		if ( !get_option('affilo_child_install') && AFFILO_PATH != THEME_PATH ) {
			add_action( 'after_setup_theme', array( 'Affilo', 'child_install' ) );
		}

		// Included hook for other things to do during initialization
		do_action('affilo_init');

		// Setup the environment
		add_action( 'after_setup_theme', array('Affilo', 'environment'), 5 );
		add_action( 'after_setup_theme', array('Affilo', 'affilo_includes'), 15 );


		add_action('affilo_theme_init_population', array("Affilo", "theme_init_population"));

		add_action('admin_notices', array('Affilo', 'updateComplete') );

		add_action('admin_enqueue_scripts', 'affilo_enqueue_squeeze_page_scripts' );
	}

	// Setup the environment and register support for various WP features.
	public function environment() {

		// Add theme support for various WP features
		register_nav_menus( array( 'primary' => __( 'Primary Navigation', 'Affilo' ), 'secondary' => __( 'Secondary Navigation', 'Affilo' ) ) );  // Enables custom menus in the Appearance menu, since WP3.0
		add_theme_support( 'automatic-feed-links' ); // Adds default posts and comments RSS feeds, since WP3.0
		add_theme_support( 'post-thumbnails' ); // Enables post thumbnails in the write screens, since WP2.9
		set_post_thumbnail_size( 200, 200, true ); // Sets the default thumbnail size to 200x200
		add_editor_style( array(  // This sets up the content editor style to match the front-end design
			'/includes/styles/reset.css', // Global Reset
			'/includes/styles/typography.css', // Basic Typography
			'/includes/styles/editor.css' // Content-specific styles (adapted from affilo.css)
		) );

		// Add theme support for Affilo-specific features
		add_theme_support( 'affilo-updates' ); // Affilo Updates Manager
		add_theme_support( 'affilo-options' ); // Affilo Options API
		add_theme_support( 'affilo-slideshows' ); // Affilo Slideshows
		add_theme_support( 'affilo-sidebars' ); // Affilo Easy Sidebars

		// Add theme support for Affilo Layouts, redefine this list using the filter 'affilo_layouts_defaults'
		$affilo_default_layouts = array(
			'one-col' 			=> array( 'label' => '1 Column (no sidebars)', 			'img' => IMAGES_URL . '/layouts/one-col.png' ),
			'two-col-left' 		=> array( 'label' => '2 Columns, sidebar on left', 		'img' => IMAGES_URL . '/layouts/two-col-left.png' ),
			'two-col-right' 	=> array( 'label' => '2 Columns, sidebar on right', 	'img' => IMAGES_URL . '/layouts/two-col-right.png' ),
			'three-col-left' 	=> array( 'label' => '3 Columns, sidebar on left', 		'img' => IMAGES_URL . '/layouts/three-col-left.png' ),
			'three-col-right' 	=> array( 'label' => '3 Columns, sidebar on right', 	'img' => IMAGES_URL . '/layouts/three-col-right.png' ),
			'three-col-both'	=> array( 'label' => '3 Columns, sidebar on each side',	'img' => IMAGES_URL . '/layouts/three-col-both.png' )
			);

		add_theme_support( 'affilo-layouts', apply_filters( 'affilo_layouts_defaults', $affilo_default_layouts) ); // Theme Layouts
		add_theme_support( 'affilo-layouts-home', apply_filters( 'affilo_layouts_defaults_home', $affilo_default_layouts ) ); // Theme Layouts (homepage)


		// If theme has been switched, unset child defaults
		add_action( 'switch_theme', array( 'Affilo', 'child_uninstall' ) );

		// Load default Scripts and Styles
		add_action( 'wp_enqueue_scripts', array( 'Affilo', 'affilo_default_scripts'), 12 );

		// Set the content width based on the theme's layout for resizing large images.
		global $content_width;
		$layout = affilo_get_option('layout');
		if ($layout == 'one-col') { $content_width = 940; }
		elseif ( $layout == 'three-col-left' || $layout == 'three-col-right' || $layout == 'three-col-both' ) { $content_width = 540; }
		else { $content_width = 640; }

	}

	public function affilo_includes() {
		// Include all Widgets, Plugins and Theme Options
		require_if_theme_supports( 'affilo-galleriffic', PLUGINS_PATH .  '/galleriffic.php' ); 	// Galleriffic Slideshows (not supported yet)
		require_if_theme_supports( 'affilo-slideshows', PLUGINS_PATH .  '/slideshows.php' ); 	// Slideshows Post Type
		require_if_theme_supports( 'affilo-sidebars', PLUGINS_PATH .  '/sidebars.php' );		// Sidebar manager
		require_if_theme_supports( 'affilo-layouts', FUNCTIONS_PATH .  '/layouts.php' );		// Theme Layouts
		foreach ( glob( WIDGETS_PATH . '/*.php') as $widget ) { require_once( $widget ); }	// Widgets
		foreach ( glob( ADMIN_PATH . '/*.php') as $admin ) { require_if_theme_supports( 'affilo-options', $admin ); } // Theme Options
		require_if_theme_supports( 'affilo-updates', FUNCTIONS_PATH .  '/upgrade.php' ); 		// Update Manager

		// Check installed version, upgrade if needed (Credit: K2, http://getk2.com)
		$affilo_version = get_option( 'affilo_version' );

		if ( $affilo_version === false ) Affilo::install();
		elseif ($affilo_version != AFFILO_VERSION) update_option('affilo_version', AFFILO_VERSION);

		if (AFFILO_PREVIEW) {
			Affilo::preview();
		}
	}


	public function updateComplete() {
		if (!isset($_GET['updateComplete'])) {
			return false;
		}
		$output = '<div class="update-nag">';
		$output .= 'Latest AffiloTheme has been installed successfully.';
		$output .= '</div>';
		echo $output;
	}

	public function preview() {
		add_action('wp_head', 'affilo_style_override', 20);
		add_filter('affilo_get_current_theme', 'affilo_get_preview_theme', 10);
		add_filter('affilo_get_current_variation', 'affilo_get_preview_variation', 10);
	}

	// Setup default scripts and styles
	public function affilo_default_scripts() {
		if (is_admin()) { return; }
		if ( is_singular() ) wp_enqueue_style( 'print' );
		if ( is_singular() ) wp_enqueue_script( 'comment-reply' );
		wp_enqueue_style( 'shortcodes' );
		wp_enqueue_style( 'layouts' );
		wp_enqueue_script( 'hovercards' );
		wp_enqueue_script( 'ui' );
		wp_enqueue_script( 'prettyPhoto' );
		wp_enqueue_script( 'affilo' );
	}

	// Install Affilo for the first time
	public function install() {
		global $affilo_upgrade;

		// Setup the main theme options and store them to a variable
		add_option( THEME_OPTIONS );

		// Set the current Affilo version
		add_option( 'affilo_version', AFFILO_VERSION);

		// Included hook for other things to do during install
		do_action( 'affilo_install' );

		$affilo_upgrade->checkForUpdates();
	}

	// Install Child Theme for the first time
	public function child_install() {
		global $affilo_settings_factory;
		$defaults = get_option( THEME_OPTIONS );

		$settings = $affilo_settings_factory->settings;
		$exclude = $affilo_settings_factory->defaults;

		foreach($settings as $setting) {
			if ( !in_array( $setting->slug, $exclude ) ) {
				$options = $setting->options;
				foreach( $options as $option_id => $option ) {
					if ( isset( $option['default'] ) ) $defaults[$option_id] = $option['default'];
				}
			}
		}

		// Save the options to the database
		update_option( THEME_OPTIONS, apply_filters( 'affilo_child_option_defaults', $defaults ) );

		// Included hook for other things to do during Child theme install
		do_action('affilo_child_install');

		// Store an option that the child theme has been installed
	    add_option('affilo_child_install', true);
	}

	// Uninstall Affilo
	public function uninstall() {

		// Delete options stored to the database
		delete_option( THEME_OPTIONS );
		delete_option( 'affilo_version' );
		delete_option( 'affilo_child_install' );

		// Included hook for other things to do during uninstall
		do_action( 'affilo_uninstall' );
	}

	// Child Uninstall
	public function child_uninstall($theme) {
		delete_option( 'affilo_child_install' );
		if ($theme === AFFILO_THEME) {
			$defaults = get_option( THEME_OPTIONS );
			update_option( THEME_OPTIONS, apply_filters( 'affilo_base_option_defaults', $defaults ) );
		}
		do_action('affilo_child_uninstall');
	}

	function register_required_plugins() {
		$plugins = array(
			array(
				'name' => 'Google XML Sitemaps',
				'slug' => 'google-sitemap-generator',
				'required' => false
			),
			array(
				'name' => 'TinyMCE Advanced',
				'slug' => 'tinymce-advanced',
				'required' => false
			),
			array(
				'name' => 'Fast Secure Contact Form',
				'slug' => 'si-contact-form',
				'required' => false
			),
			array(
				'name' => 'Akismet',
				'slug' => 'akismet',
				'required' => false
			),
			array(
				'name' => 'WP No Category Base - WPML compatible',
				'slug' => 'no-category-base-wpml',
				'required' => false
			)
		);
		$config = array(
			'parent_slug' 		=> 'affilo_admin',
			'parent_admin_url'	=> 'admin.php?page=affilo_navigation_settings',
			'strings'      => array(
				'instructions_install' 				=> __( 'The %1$s plugin is required for Affilotheme. Click on the big blue button below to install and activate %1$s.'),
				'instructions_install_recommended' 	=> __( 'The %1$s plugin is recommended for Affilotheme. Click on the big blue button below to install and activate %1$s.'),
				'notice_can_install_required' 		=> __( 'Affilotheme requires the following plugins: %1$s.'),
				'notice_can_install_recommended' 	=> __( 'Affilotheme recommends the following plugins: %1$s.')
			)
		);
		tgmpa($plugins,$config);
	}

	function theme_init_population() {
		// Update several wordpress options
		// http://codex.wordpress.org/Function_Reference/update_option
		$options = array(
			'default_comment_status' => 'closed',
			'default_ping_status' => 'closed',
			'permalink_structure' => '/%postname%/',
			'ddm_theme_version' => '2.0',
			);
		foreach ($options as $option => $value) {
			update_option($option, $value);
		}

		// Get all the pages and posts for removal, this code uses query found via the below function
		// which was limited to page ids
		// http://codex.wordpress.org/Function_Reference/get_all_page_ids
		global $wpdb;
		$post_ids  = $wpdb->get_col("SELECT ID FROM $wpdb->posts");
		foreach ($post_ids as $post_id) {
			// Remove old posts from Worpdress install
			// http://codex.wordpress.org/Function_Reference/wp_delete_post
			wp_delete_post($post_id, true);
		}

		foreach(get_all_category_ids() as $catID) {
			wp_delete_category($catID);
		}


		// Insert our new posts and pags we want to show the user by default
		// http://codex.wordpress.org/Function_Reference/wp_insert_post
		$pages = self::get_new_pages();
		foreach ($pages as $page) {
			$wp_error = '';
			wp_insert_post($page, $wp_error);
			if (!empty($wp_error)) {
				echo "Insert failed with page {$page['post_title']} - {$wp_error}<br />\n";
			}
		}


		require_once(ABSPATH . 'wp-admin/includes/taxonomy.php');

		$_cat_IDs = array();
		foreach(self::get_new_categories() as $cat) {
			$_cat_IDs[] = wp_insert_category($cat);
		}
		shuffle($_cat_IDs);

		foreach(self::get_new_posts() as $post) {
			$post['post_category'] = array(array_shift($_cat_IDs));
			wp_insert_post($post);
		}

		$all_post_ids = $wpdb->get_col("SELECT ID FROM $wpdb->posts WHERE post_type='post'");
		$all_images = glob(IMAGES_PATH."/theme_assets/photos/*");
		shuffle($all_images);

		require_once(ABSPATH . 'wp-admin/includes/image.php');

		$wp_upload_dir = wp_upload_dir();
		$target_dir = $wp_upload_dir['path'].DIRECTORY_SEPARATOR;

		foreach($all_post_ids as $post_id) {

			$tmp_file = array_pop($all_images);
			$filename = $target_dir.basename($tmp_file);
			if(!copy($tmp_file, $filename)) {
				continue;
			}

			$wp_filetype = wp_check_filetype(basename($filename), null );
			$attachment = array(
			   'post_mime_type' => $wp_filetype['type'],
			   'post_title' => preg_replace('/\.[^.]+$/', '', basename($filename)),
			   'post_content' => '',
			   'post_status' => 'inherit'
			);
			$attach_id = wp_insert_attachment( $attachment, $filename, 37 );
			$attach_data = wp_generate_attachment_metadata( $attach_id, $filename );
			wp_update_attachment_metadata( $attach_id, $attach_data );
			add_post_meta($post_id, '_thumbnail_id', $attach_id);
		}


		if($slide_id = wp_insert_post(self::get_new_slideshow())) {
			foreach(self::get_new_slideshow_meta() as $key => $val) {
				if(!is_array($val)) {
					add_post_meta($slide_id, $key, $val);
				} else {
					foreach($val as $subval) {
						add_post_meta($slide_id, $key, $subval);
					}
				}
			}
		}

		# We want to always show the home page at this time. If this changes then use the rand from below instead
		#if(rand(0,2) != 1) {
		if (true) {
			//add homepage randomly
			$homepage = self::get_homepage();
			$homepage['post_content'] = "[slideshow id=\"{$slide_id}\"]\n".$homepage['post_content'];
			if($hp_id = wp_insert_post($homepage)) {
				update_option('show_on_front', 'page');
				update_option('page_on_front', $hp_id);
				update_option('ddm_static_pages', $hp_id);
			}
		}


		$comment_ids = $wpdb->get_col("SELECT comment_ID FROM $wpdb->comments");
		foreach ($comment_ids as $comment_id) {
			wp_delete_comment($comment_id, true);
		}


		foreach(self::get_new_comments()as $comment) {
			$comment['comment_post_ID'] = $all_post_ids[array_rand($all_post_ids)];
			wp_insert_comment($comment);
		}


		//Randomly pick a child theme and color variation
		$child_theme = get_child_theme();
		switch_theme('affilotheme_2', $child_theme['stylesheet']);

		// Set the color variation
		$affilo_options = get_option('affilo');
		$affilo_options['theme-variant'] = $child_theme['variation'];

		// Set the blog name and description at the top of the page
		$affilo_options['logo-text'] = get_option('blogname');
		$affilo_options['blogdescription'] = get_option('blogdescription');
		$affilo_options['tagline'] = 1;

		update_option('affilo', $affilo_options);

		include(AFFILO_PATH."/header_creator/functions.php");

		$hc_settings = affilo_hc_load_settings();
		$hc_settings['top_text'] = get_option('blogname');
		$hc_settings['bottom_text'] = get_option('blogdescription');

		update_option(affilo_hc_settings_option_key(), $hc_settings);

	}



	static function populate_sidebars_widgets($new_sidebars_widgets) {
		$sidebars_widgets = wp_get_sidebars_widgets();

		foreach($new_sidebars_widgets as $sidebar => $new_widgets){
			$sidebars_widgets[$sidebar] = array();
			foreach($new_widgets as $new_widget_id => $new_widget_details) {
				if(is_numeric($new_widget_id)) {
					$new_widget_id = $new_widget_details;
					unset($new_widget_details);
				}
				if(array_search($new_widget_id, $sidebars_widgets[$sidebar]) === false) {
					array_unshift($sidebars_widgets[$sidebar], $new_widget_id);
					if($new_widget_details) {
						foreach($new_widget_details as $new_widget_key => $new_widget) {
							if($existing_widget = get_option($new_widget_key)) {
								array_push($existing_widget, array_shift($new_widget));
								$new_widget = $existing_widget;
							}
							update_option($new_widget_key, $new_widget);
						}
					}
					wp_set_sidebars_widgets($sidebars_widgets);
				}
			}
		}
	}

	static function get_new_comments() {
		$time = current_time('mysql');
		return array(
			array(
				'comment_post_ID' 		=> 15,
				'comment_author' 		=> 'John Doe',
				'comment_author_email' 	=> '',
				'comment_author_url' 	=> '',
			    'comment_content' 		=> 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Morbi mollis accumsan mattis. '.
'Integer venenatis hendrerit ultrices. Nullam blandit neque imperdiet nunc vestibulum ullamcorper. Nulla a sapien aliquet erat adipiscing '.
'imperdiet. Sed ligula magna, imperdiet quis ullamcorper et, interdum id quam. Fusce dictum lacus hendrerit justo varius rutrum. Aenean '.
'gravida condimentum dolor eget vulputate. Donec gravida dapibus tortor, sed varius dolor varius a. Integer nisi nisl, fermentum at mattis '.
'ac, facilisis at erat. Vivamus id massa ac lectus venenatis hendrerit. Duis lacinia pharetra dignissim. Nulla mattis orci nec sem eleifend '.
'elementum faucibus quam auctor. Nullam vestibulum nibh id enim congue faucibus. Etiam vel velit in enim iaculis tempus ornare ut sem. '.
'Curabitur et tellus ac orci sagittis volutpat. Aliquam ultricies enim sed tortor pellentesque sollicitudin.',
			    'comment_type' 			=> '',
			    'comment_parent' 		=> 0,
				'user_id' 				=> 1,
				'comment_author_IP' 	=> '127.0.0.1',
				'comment_agent' 		=> 'Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.10) Gecko/2009042316 '.
'Firefox/3.0.10 (.NET CLR 3.5.30729)',
				'comment_date' 			=> $time,
				'comment_approved' 		=> 1,
			),
			array(
				'comment_post_ID' 		=> 15,
				'comment_author' 		=> 'Shaun Dough',
				'comment_author_email' 	=> '',
				'comment_author_url'	=> '',
			    'comment_content' 		=> 'Integer venenatis hendrerit ultrices. Nullam blandit neque imperdiet nunc ullamcorper. '.
'Nulla a sapien aliquet erat adipiscing imperdiet. Sed ligula magna, imperdiet quis ullamcorper et, interdum id quam. Fusce dictum '.
'lacus hendrerit justo varius rutrum. Aenean gravida condimentum dolor eget vulputate. Donec gravida dapibus tortor, sed varius dolor '.
'varius a. Integer nisi nisl, fermentum at mattis ac, facilisis at erat. Vivamus id massa ac lectus venenatis hendrerit. Duis lacinia '.
'pharetra dignissim. Nulla mattis orci nec sem eleifend elementum faucibus quam auctor. Nullam vestibulum nibh id enim congue faucibus. '.
'Etiam vel velit in enim iaculis tempus ornare ut sem. Curabitur et tellus ac orci sagittis volutpat. Aliquam ultricies enim sed tortor '.
'pellentesque sollicitudin.',
			    'comment_type' 			=> '',
			    'comment_parent' 		=> 0,
				'user_id' 				=> 1,
				'comment_author_IP' 	=> '127.0.0.1',
				'comment_agent' 		=> 'Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.10) Gecko/2009042316 '.
'Firefox/3.0.10 (.NET CLR 3.5.30729)',
				'comment_date' 			=> $time,
				'comment_approved' 		=> 1,
			)
		);

	}

	/**
	 * All the HTML and settings required for each page and post added automatically to the system
	 * NOTE:: The LAST item in the array must be the home page!
	 */
	static function get_new_pages(){
		return array(
			array(
				'post_title' => 'About Us',
				'post_status' => 'publish',
				'post_type' => 'page',
				'post_name' => 'about-us',
				'comment_status' => 'closed',
				'ping_status ' => 'closed',
				'post_content' => '<p>This is a little bit about [website] and explains what we have  available for you here.</p>
					<p>Have a browse around and if you have any questions <a href="/contact-us/">contact  us</a>.</p>'
			),
			array(
				'post_title' => 'Contact Us',
				'post_status' => 'publish',
				'post_type' => 'page',
				'post_name' => 'contact-us',
				'comment_status' => 'closed',
				'ping_status ' => 'closed',
				'post_content' => '<p>Please use the following address to direct any queries to our team. We will endeavor to reply within 72 hours.</p>
					<p>Your privacy is important to us, and your email address will never be used for anything other that responding to your questions. Your email address will be never be given out to any third party.</p>
					<p>If you have questions or would like more information about a specific product we suggest contacting the website owner.</p>
					<p>Contact [website]: [email]</p>',
			),
			array(
				'post_title' => 'Privacy Policy',
				'post_status' => 'publish',
				'post_type' => 'page',
				'post_name' => 'privacy-policy',
				'comment_status' => 'closed',
				'ping_status ' => 'closed',
				'post_content' => '<ol>
					<li>Introduction: [website] (this website) is owned and operated by [website] (we, us, our). We respect the privacy of our website users (you, your). This privacy policy explains how we may collect, store, use, and disclose personal information that you provide to us. By accessing and using this website you confirm your unconditional consent to us collecting, storing, using, and disclosing your personal information in the manner set out in this privacy policy.</li>
					<li>Terms of use: Your use of this website is governed by our terms of use. Accordingly, this privacy policy must be read in conjunction with our terms of use.</li>
					<li>Collecting your personal information: We may collect personal information	from you (including, without limit ation, your name, email address, phone number, and postal address) when you use this website. You may decide not to provide your personal information to us. However, if you do not provide it, we may not be able to provide you with access to certain information or products.</li>
					<li>Automated collection: When you visit this website, we may use automated tools and methods (such as cookies, sessions, and usage monitoring software) to collect certain information about your visit, including (without limitation). This information will be used in aggregate form to analyse how this website is being used (for example: to analyse usage patterns in order to improve this website). Except as set out in this privacy policy, we will not disclose any such information except in aggregate form.</li>
					<li>Cookies: This website may use cookies and sessions to provide you with certain services or functionality. Cookies and sessions may be used to identify you as an individual user of this website. We use this technology to, amongst other things. Accepting a cookie will not give us access to any data on your computer other than the data stored in the cookie. Although you may configure your web browser to not accept cookies, you may experience a loss of functionality as a result.</li>
					<li>Additional collection: We may gather more extensive information if we are concerned, for example, about abnormal website usage patterns or website security breaches.</li>
					<li>Use: We may use your personal information to:  provide you with services and information that you have requested; provide you with important notices and information about this website and our services; provide you with other information (including promotional material, news, and event information) where you agree to receive such information; verify your identity and to assist you if you forget your username or password;  improve or update this website and our products;  respond to your enquiries and communicate with you; and personalise this website in accordance with your preferences.</li>
					<li>Other use and disclosure: We will not sell, rent, or lease your personal information to third parties. We may disclose your personal information to our professional advisors, contractors, business associates, related companies, and others who have agreed to treat your personal information in accordance with this privacy policy. We will not otherwise use or disclose your personal information except:  for any purpose set out in clause 6; where you have otherwise authorised us to do so; where we have given you notification of the intended use or disclosure and you have not objected to that use or disclosure; where we believe that such use or disclosure is reasonably necessary to assist a law enforcement agency or an agency responsible for national security in the performance of their functions; where we believe that such use or disclosure is reasonably necessary to enforce any legal rights we may have, or is reasonably necessary to protect the rights, property and safety of us, our users, or others; or as otherwiserequired or permitted by law.</li>
					<li>Third party websites: This website may contain hyperlinks to websites operated by third parties. We are not responsible for the content of such websites, or the manner in which those websites collect, store, use, and distribute any personal information you provide. When you visit third party websites from hyperlinks displayed on this website, we encourage you to review the privacy statements of those websites so that you can understand how the personal information you provide may be collected, stored, used and distributed.</li>
					<li>Right to access and request correction: It is important to us that the personal information we hold about you is accurate, complete and up to date. If you are aware that this is not case and would like your personal information corrected, or simply desire access to your personal information, please contact our Privacy Officer. You may request access to your personal information that we (or our contractors) hold. Where you make any such request:  we may ask you to put your request in writing; in some circumstances permitted by law, we may not provide such information to you (and we may not be able to require our contractors provide such information to you); we decide not to correct or provide you with access to your personal information, we will give you our reasons for our decision; where we provide the requested information or carry out the requested correction (or where we attach to that information a statement of any correction sought but not made), we may require you to pay a reasonable fee determined by us.</li>
					<li>Changes to our privacy policy: We reserve the right to change this privacy policy from time to time by publishing the revised privacy policy on our website. If you continue to use this website or if you provide any personal information after we post changes to this privacy policy, this will deemed your conclusive acceptance of any such changes.</li>' .
					'</ol>',
			)
		);
	}


	static function get_homepage() {
		return array(
			'post_title' => 'Welcome to [website]',
			'post_status' => 'publish',
			'post_type' => 'page',
			'post_name' => 'welcome-to-website',
			'comment_status' => 'closed',
			'ping_status ' => 'closed',
			'post_content' => '<p>Welcome to [website], feel free to check out some the great content and resources I have on this topic.</p>
				<p><strong>This is just dummy text, you can either delete or edit this post inside the admin area</strong></p>
				<p>Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industrys standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting, remaining essentially unchanged. It was popularised in the 1960s with the release of Letraset sheets containing Lorem Ipsum passages, and more recently with desktop publishing software like Aldus PageMaker including versions of Lorem Ipsum.</p>
				<p>Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industrys standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting, remaining essentially unchanged. It was popularised in the 1960s with the release of Letraset sheets containing Lorem Ipsum passages, and more recently with desktop publishing software like Aldus PageMaker including versions of Lorem Ipsum.</p>'
		);
	}


	static function get_new_posts() {
		return array(
			array(
				'post_author' => 1,
				'post_date' => date("Y-m-d H:i:s", strtotime("-2 months")),
				'post_date_gmt' => date("Y-m-d H:i:s", strtotime("-2 months")),
				'post_title' => 'Article 1',
				'post_status' => 'publish',
				'post_type' => 'post',
				'post_name' => 'article-1',
				'comment_status' => 'closed',
				'ping_status ' => 'closed',
				'post_content' => '<strong>This is just dummy text, you can either delete or edit this post inside the admin area</strong>
					<strong>Lorem Ipsum</strong> is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industrys standard dummy  text ever since the 1500s, when an unknown printer took a galley of  type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting,  remaining essentially unchanged. It was popularised in the 1960s with  the release of Letraset sheets containing Lorem Ipsum passages, and more  recently with desktop publishing software like Aldus PageMaker including versions of Lorem Ipsum.
					<strong>Lorem Ipsum</strong> is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industrys standard dummy  text ever since the 1500s, when an unknown printer took a galley of  type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting,  remaining essentially unchanged. It was popularised in the 1960s with  the release of Letraset sheets containing Lorem Ipsum passages, and more  recently with desktop publishing software like Aldus PageMaker including versions of Lorem Ipsum.
					<strong>Lorem Ipsum</strong> is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industrys standard dummy  text ever since the 1500s, when an unknown printer took a galley of  type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting,  remaining essentially unchanged. It was popularised in the 1960s with  the release of Letraset sheets containing Lorem Ipsum passages, and more  recently with desktop publishing software like Aldus PageMaker including versions of Lorem Ipsum.'
			),
			array(
				'post_author' => 1,
				'post_date' => date("Y-m-d H:i:s", strtotime("-1 month")),
				'post_date_gmt' => date("Y-m-d H:i:s", strtotime("-1 month")),
				'post_title' => 'Article 2',
				'post_status' => 'publish',
				'post_type' => 'post',
				'post_name' => 'article-2',
				'comment_status' => 'closed',
				'ping_status ' => 'closed',
				'post_content' => '<strong>This is just dummy text, you can either delete or edit this post inside the admin area</strong>
					<strong>Lorem Ipsum</strong> is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industrys standard dummy  text ever since the 1500s, when an unknown printer took a galley of  type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting,  remaining essentially unchanged. It was popularised in the 1960s with  the release of Letraset sheets containing Lorem Ipsum passages, and more  recently with desktop publishing software like Aldus PageMaker including versions of Lorem Ipsum.
					<strong>Lorem Ipsum</strong> is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industrys standard dummy  text ever since the 1500s, when an unknown printer took a galley of  type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting,  remaining essentially unchanged. It was popularised in the 1960s with  the release of Letraset sheets containing Lorem Ipsum passages, and more  recently with desktop publishing software like Aldus PageMaker including versions of Lorem Ipsum.
					<strong>Lorem Ipsum</strong> is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industrys standard dummy  text ever since the 1500s, when an unknown printer took a galley of  type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting,  remaining essentially unchanged. It was popularised in the 1960s with  the release of Letraset sheets containing Lorem Ipsum passages, and more  recently with desktop publishing software like Aldus PageMaker including versions of Lorem Ipsum.'
				),
			array(
				'post_author' => 1,
				'post_title' => 'Article 3',
				'post_status' => 'publish',
				'post_type' => 'post',
				'post_name' => 'article-3',
				'comment_status' => 'closed',
				'ping_status ' => 'closed',
				'post_content' => <<<CONTENT
<strong>This is just dummy text, you can either delete or edit this post inside the admin area</strong>
<strong>Lorem Ipsum</strong> is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industrys standard dummy  text ever since the 1500s, when an unknown printer took a galley of  type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting,  remaining essentially unchanged. It was popularised in the 1960s with  the release of Letraset sheets containing Lorem Ipsum passages, and more  recently with desktop publishing software like Aldus PageMaker including versions of Lorem Ipsum.
[tabs "TabOne" "Tab Two" "Tab Three"]
[tab]
Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industrys standard dummy text ever since the 1500s
[/tab]
[tab]
Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industrys standard dummy text ever since the 1500s
[/tab]
[tab]
Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industrys standard dummy text ever since the 1500s
[/tab]
[/tabs]
<p><strong>Lorem Ipsum</strong> is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industrys standard dummy  text ever since the 1500s, when an unknown printer took a galley of  type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting,  remaining essentially unchanged. It was popularised in the 1960s with  the release of Letraset sheets containing Lorem Ipsum passages, and more  recently with desktop publishing software like Aldus PageMaker including versions of Lorem Ipsum.</p>
<p><strong>Lorem Ipsum</strong> is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industrys standard dummy  text ever since the 1500s, when an unknown printer took a galley of  type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting,  remaining essentially unchanged. It was popularised in the 1960s with  the release of Letraset sheets containing Lorem Ipsum passages, and more  recently with desktop publishing software like Aldus PageMaker including versions of Lorem Ipsum</p>
CONTENT
			)
		);
	}

	static function get_new_categories() {
		return array(
			array(
				'cat_name' => "Category 1"
			),
			array(
				'cat_name' => "Category 2"
			),
			array(
				'cat_name' => "Category 3"
			),
		);
	}

	static function get_new_slideshow() {
		return array(
			'post_author' => 1,
			'post_title' => 'Demo Slideshow',
			'post_status' => 'publish',
			'post_type' => 'slideshow',
			'post_name' => 'demo-slideshow',
			'comment_status' => 'closed',
			'ping_status ' => 'closed',
			'post_content' => ''
		);
	}

	static function get_new_slideshow_meta() {
		$att_arr = array();
		foreach(get_posts(array('post_type'=>'attachment')) as $key => $att) {
			$att_arr[] = array(
				"attachment_id" => $att->ID,
				"order" => $key
			);
		}

		return array(
			"slide" => $att_arr,
			"ssorri" => "slideshow_on",
			"effect" => "",
			"control" => array(
				array(
					"arrows",
					"navigation"
				)
			),
			"pause" => 3000,
			"opacity" => 0.8,
			"size" => "custom",
			"size_custom" => array(
				array(
					"width" => "500",
					"height" => "350"
				)
			),
			"size_min" => array(
				array(
					"width" => "400",
					"height" => "300"
				)
			),
			"size_max" => array(
				array(
					"width" => "400",
					"height" => "300"
				)
			)
		);
	}
}


function get_child_theme() {
	$result = array('stylesheet' =>'', 'variation' => '');
	// We only allow a sub set of themes to be auto enabled, as some are still in development
	$child_themes = array(
		'AffiloTheme - SuperMassive',
		'AffiloTheme - Seventeen',
		'AffiloTheme - Glide',
		'AffiloTheme - Avenue',
		'AffiloTheme - Peak',
		'AffiloTheme - Class'
	);
	$child_theme = $child_themes[array_rand($child_themes)];

	// All of the affilotheme child themes, excluding the main affilotheme_2
	$affilo_themes = affilo_get_themes(False, True);

	// The variations of the random child theme
	$variations = $affilo_themes[$child_theme]->Variations;

	$result['stylesheet'] = $affilo_themes[$child_theme]['Stylesheet'];
	$result['variation'] = $variations[array_rand($variations)]['Name'];

	return $result;
}

?>
