<?php
require_once(get_theme_root().'/affilotheme_2/includes/functions/affilo.php');
if( !did_action( 'affilo_init' ) ) {
	Affilo::init();
}

function affilo_needs_to_setup_theme() {
	global $wp_version;
	if (version_compare($wp_version, '3.4' ,'>=')) {
	    $theme = wp_get_theme();
	    $theme_file = $theme->stylesheet . '/style.css';
	    if( ! file_exists( $theme->theme_root . '/' . $theme_file ) ) {
	    	return true;
	    }
	} else {
		//check for Wordpress lower than 3.4
		$stylesheet = affilo_get_stylesheet_template();
		if (! file_exists(  get_theme_root() . $stylesheet)) {
			return true;
		}
	}
	return false;
}


function affilo_after_setup_theme()
{
	global $wp_version;
	if (version_compare($wp_version, '3.4' ,'>=')) {
		//get theme and delete cache , so that the error in dashboard should not get display even after the theme has been setup properly.
		$theme = wp_get_theme();
		$theme->cache_delete();
	}
}


function affilo_setup_theme() {
 	affilo_restructure();

 	affilo_change_image_paths();

	$stylesheet = affilo_get_stylesheet_template();
	$current_stylesheet = get_option('stylesheet');

	if ($stylesheet != $current_stylesheet) {
		affilo_activate_theme($stylesheet);
	}

	update_option('copy_child' . AFFILO_VERSION , 1);
	affilo_after_setup_theme();
}

function affilo_restructure() {
	if (!affilo_old_structure_exists()) {
		return false;
	}


	//check if we have child theme folder inside affilotheme_2, if we have
	//these then this means that new install or upgrade is called
	$start_dir = affilo_old_child_paths();
	$destination_dir= array(
			  get_theme_root()."/affilotheme_avenue" ,
			  get_theme_root()."/affilotheme_class",
			  get_theme_root()."/affilotheme_glide",
			  get_theme_root()."/affilotheme_peak",
			  get_theme_root()."/affilotheme_seventeen",
			  get_theme_root()."/affilotheme_supermassive",
			);

	$childThemes = false;

	foreach ($start_dir as $single_start_dir) {
		if ( is_dir($single_start_dir) ) {
			if (file_exists($single_start_dir)) {
				$childThemes = true;
				break;
			}
		}
	}

	//if themes folder do not have writable permission
	if ($childThemes && !is_writable(get_theme_root())) {
		add_action('admin_notices', 'affilo_dir_permission_issue');
		return false;
	}

	foreach ($destination_dir as $i => $single_destination_dir){
		$remote_source = $start_dir[$i];

		if (file_exists($start_dir[$i])) {
			if (file_exists($single_destination_dir)) {
		 		@delete_recursive($single_destination_dir);
			}
			@mkdir($single_destination_dir);
			@rename_recursive($start_dir[$i], $single_destination_dir);
			@copy_recursive($start_dir[$i], $single_destination_dir);
		}
	}

	return true;
}


function affilo_dir_permission_issue() {
	echo '<div id="message" class="error">';
	$message = "Web server user should have writable permissions to your themes folder to create child themes for Affilotheme. ";
	echo "<p><strong>$message</strong></p></div>";
}

function affilo_activate_theme($stylesheet) {
 	$file = get_theme_root()."/".$stylesheet."/style.css";

 	if (file_exists($file)) {
		if (function_exists('wp_get_theme')) {
			/* Wordpress 3.4 and above */
 			$theme = wp_get_theme($stylesheet);
			if ( ! $theme->exists() || ! $theme->is_allowed() )
				wp_die( __( 'Cheatin&#8217; uh?' ) );
			switch_theme( $theme->get_template(), $theme->get_stylesheet() );
		} else {
			/* Wordpress below 3.4 */
 			$themes = get_themes();
			foreach ($themes as $theme) {
				if ($theme['Stylesheet'] == $stylesheet) {
					return switch_theme( $theme['Template'], $theme['Stylesheet'] );
				}
			}
			wp_die( __( 'No theme found to activate' ) );
		}
 	}
}

function rename_recursive($start_dir, $destination_dir) {
    $str = "";
    $files = array();
    if (is_dir($start_dir)) {
        $fh = opendir($start_dir);
        while (($file = readdir($fh)) !== false) {
            if (strpos($file, '.')=== 0) continue;
	    $filepath = $start_dir . '/' . $file;
            $filepath2 = $destination_dir . '/' . $file;
            if ( is_dir($filepath) ) {
                rename($filepath, $filepath2);
                rename_recursive($filepath, $filepath2);
            } else {
                rename($filepath, $filepath2);
            }
        }
        closedir($fh);
	rmdir($start_dir);
    }
}

function copy_recursive($start_dir, $destination_dir) {
    $str = "";
    $files = array();
    if (is_dir($start_dir)) {
        $fh = opendir($start_dir);
        while (($file = readdir($fh)) !== false) {
            if (strpos($file, '.')=== 0) continue;
	    $filepath = $start_dir . '/' . $file;
            $filepath2 = $destination_dir . '/' . $file;
            if ( is_dir($filepath) ) {
                mkdir($filepath2);
                copy_recursive($filepath, $filepath2);
            } else {
                copy($filepath, $filepath2);
            }
        }
        closedir($fh);
	}
}

function delete_recursive($dir, $virtual = false) {
	if (strpos($dir, get_theme_root() . '/affilotheme_') !== 0) {
		// We only want to delete folders which are in the themes folder, and start with affilotheme_
		return false;
	}
	$ds = DIRECTORY_SEPARATOR;
	$dir = $virtual ? realpath($dir) : $dir;
	$dir = substr($dir, -1) == $ds ? substr($dir, 0, -1) : $dir;
	if (is_dir($dir) && $handle = opendir($dir)) {
		while ($file = readdir($handle)){
			if ($file == '.' || $file == '..'){
				continue;
			}
			elseif (is_dir($dir.$ds.$file)) {
				delete_recursive($dir.$ds.$file);
			}
			else {
				unlink($dir.$ds.$file);
			}
		}
		closedir($handle);
		rmdir($dir);
		return true;
	}
	else {
		return false;
	}
}

function affilo_old_structure_exists() {
	$child_themes = affilo_old_child_paths();
	foreach ($child_themes as $dir) {
		if (file_exists($dir)) {
			return true;
		}
	}
	return false;
}

function affilo_old_child_paths() {
	return array(
				get_theme_root()."/affilotheme_2/affilotheme_avenue",
				get_theme_root()."/affilotheme_2/affilotheme_class",
				get_theme_root()."/affilotheme_2/affilotheme_glide",
				get_theme_root()."/affilotheme_2/affilotheme_peak",
				get_theme_root()."/affilotheme_2/affilotheme_seventeen",
				get_theme_root()."/affilotheme_2/affilotheme_supermassive",
			);
}

function affilo_get_stylesheet_template() {
	list($parent, $template) = explode('/',get_stylesheet());

	if (!isset($template) || empty($template) ) {
		$template = $parent;
	}

	return $template;
}

/**
 * Replace all instances of the old /affilotheme_2/affilotheme_2/ paths with just /affilotheme_2/
 */
function affilo_change_image_paths() {
	global $wpdb;

	$replacements = array(
		'/themes/affilotheme_2/affilotheme_2/' => '/themes/affilotheme_2/',
		'%2Fthemes%2Faffilotheme_2%2Faffilotheme_2%2F' => '%2Fthemes%2Faffilotheme_2%2F',
	);

	foreach ($replacements as $find=>$replace) {
		$sql = $wpdb->prepare("UPDATE $wpdb->posts SET `post_content`=REPLACE(post_content, %s, %s)", $find, $replace);
		$wpdb->query($sql);
	}

	//-- Post meta!
	$rows = $wpdb->get_results("SELECT meta_id, meta_value FROM $wpdb->postmeta WHERE `meta_key`='sqz-fields' AND `meta_value` LIKE '%affilotheme_2/affilotheme_2%'", ARRAY_A);
	foreach ($rows as $row) {
		$page_meta = unserialize($row['meta_value']);
		foreach ($page_meta as $k=>&$v) {
			if (!is_array($v)) {
				$v = str_replace(array_keys($replacements), array_values($replacements), $v);
			}
		}
		$page_meta = serialize($page_meta);
		$wpdb->update($wpdb->postmeta, array('meta_value' => $page_meta), array('meta_id' => $row['meta_id']));
	}

	//-- Widget text!
	// These guys are tricky, could be /themes/affilotheme_2/affilotheme_2
	// or /themes/affilotheme_2/affilotheme_seventeen...
	$widget_text = get_option('widget_text');
	if ($widget_text) {
		foreach ($widget_text as $title=>&$text) {
			$text = str_replace('/themes/affilotheme_2/affilotheme_', '/themes/affilotheme_', $text);
		}
		update_option('widget_text', $widget_text);
	}
}