<?php
/**
 * Affilo Hooks and Filters
 *
 * A collection of many of Affilo's default hooks, as well as some default filtration.
 *
 * @package Affilo
 * @subpackage Functions
 */

// Located in header.php
function affilo_title() { do_action('affilo_title'); } // The site title
function affilo_before() { do_action('affilo_before'); } // the very first thing inside <body>
function affilo_before_header() { do_action('affilo_before_header'); } // inside div#wrap, before div#header
function affilo_header() { do_action('affilo_header'); } // inside div#header, before any content
function affilo_header_enabled() {
	return apply_filters('affilo_header_enabled', true);
}
function affilo_after_header() { do_action('affilo_after_header'); } // inside div#wrap, after div#header
function affilo_before_container() { do_action('affilo_before_container'); } // inside div#container_wrap, before div#container

// Located in front-page.php
function affilo_before_featured() { do_action('affilo_before_featured'); } // Located just after affilo_before_content
function affilo_featured() { do_action('affilo_featured'); } // Located just after affilo_before_featured
function affilo_after_featured() { do_action('affilo_after_featured'); } // Located just after affilo_featured
function affilo_home() { do_action('affilo_home'); } // Located just after affilo_after_featured

// Located in 404.php, archive.php, attachment.php, author.php, category.php, index.php, page.php and all other page templates, search.php, single.php, tag.php
function affilo_before_content() { do_action('affilo_before_content'); } // Just before the content
function affilo_page_title() { do_action('affilo_page_title'); } // The Page Title, appears immediately after affilo_before_content
function affilo_after_content() { do_action('affilo_after_content');} // Just after the content

// Located in loop.php
function affilo_before_post() { do_action('affilo_before_post'); global $firstpost; if ( !isset( $firstpost ) ) { do_action('affilo_before_first_post'); } } // Just before the post
function affilo_after_post() { do_action('affilo_after_post'); global $firstpost; if ( !isset( $firstpost ) ) { do_action('affilo_after_first_post'); $firstpost = 1; } } // Just after the post

// Located in loop.php and single.php
function affilo_before_post_content() { do_action('affilo_before_post_content'); } // Inside div.post, after .entry-header, before .entry-content
function affilo_post_header() { do_action('affilo_post_header' ); } // Inside div.entry-meta
function affilo_post_footer() { do_action('affilo_post_footer' ); } // Inside div.entry-footer
function affilo_after_post_content() { do_action('affilo_after_post_content'); } // Inside div.post, after .entry-content, before .entry-footer

// Located in 404.php
function affilo_404() { do_action('affilo_404'); } // Inside div.post, only on 404 page

// Located in sidebar.php
function affilo_no_widgets() { do_action('affilo_no_widgets'); } // This is hooked into all affilo_no_*_widget hooks

// Located in sidebar-tertiary.php
function affilo_before_tertiary_widgets() { do_action('affilo_before_tertiary_widgets'); } // Inside div#container, after div#content, before div#tertiary
function affilo_after_tertiary_widgets() { do_action('affilo_after_tertiary_widgets'); } // Inside div#container, after div#tertiary

// Located in sidebar-footer.php
function affilo_before_footer_widgets() { do_action('affilo_before_footer_widgets'); } // inside div#footer, before div#footer_sidebar
function affilo_between_footer_widgets() { do_action('affilo_between_footer_widgets'); } // inside div#footer_sidebar, between each div.aside
add_action( 'affilo_before_footer_widget_area_2_widgets', 'affilo_between_footer_widgets' );
add_action( 'affilo_before_footer_widget_area_3_widgets', 'affilo_between_footer_widgets' );
add_action( 'affilo_before_footer_widget_area_4_widgets', 'affilo_between_footer_widgets' );
function affilo_after_footer_widgets() { do_action('affilo_after_footer_widgets'); } // inside div#footer, after div#footer_sidebar

// Located in footer.php
function affilo_after_container() { do_action('affilo_after_container'); } // inside div#container_wrap, after div#container
function affilo_between_content_and_footer() { do_action('affilo_between_content_and_footer'); } // after div#wrap, before div#footer_wrap
function affilo_before_footer() { do_action('affilo_before_footer'); } // inside div#footer_wrap, before div#footer
function affilo_footer() { do_action('affilo_footer'); } // inside div#footer after div#footer_sidebar
function affilo_footer_enabled() {
	return apply_filters('affilo_footer_enabled', true);
}
function affilo_after_footer() { do_action('affilo_after_footer'); } // inside dive#footer_wrap, after div#footer
function affilo_after() { do_action('affilo_after'); } // the very last thing before </body>

////////////////////////////////////////////////// Items To Hook into Header //////////////////////////////////////////////////

// The default site title
function affilo_default_title( $title, $sep, $seplocation) {
	$site_name = get_bloginfo('name');
	$sep = ' | ';

	if ( is_home() || is_front_page() ) { $title = get_bloginfo('description'); }
	elseif ( is_singular() || is_page() ) { $title = single_post_title( '', false ); }
	elseif ( is_search() ) { $title = sprintf( __('Search Results for: %s', 'affilo'), esc_html(stripslashes(get_search_query())) ); }
    elseif ( is_category() ) { $title = sprintf( __('Category Archives: %s', 'affilo'), single_cat_title( '', false )); }
    elseif ( is_tag() ) { $title = sprintf( __('Tag Archives: %s', 'affilo'), affilo_tag_query() ); }
	elseif ( is_404() ) { $title = __( 'Not Found', 'affilo' ); }
	else { $title = get_bloginfo('description'); }
	
	// Appends current page number (if on page 2 or greater)
    if ( get_query_var('paged') ) { $title .= $sep . sprintf( __( 'Page %s', 'affilo' ), get_query_var('paged') ); }

	if ( is_home() || is_front_page() ) {
		$title = array(
			'site_name' => $site_name,
			'separator' => $sep,
			'title' => $title
		);
	} else {
		$title = array(
			'title' => $title,
			'separator' => $sep,
			'site_name' => $site_name
		);
	}

    // Filters should return an array
    $title = apply_filters('affilo_doctitle', $title);

	if( is_array( $title ) )
		$title = implode('', $title);

	return $title;
}
add_filter( 'wp_title', 'affilo_default_title', 10, 3 );
add_action( 'affilo_title', 'wp_title' );

// Filter the RSS title to return nothing, otherwise RSS shows dupilicate title
add_filter( 'wp_title_rss', create_function( '$a', 'return "";' ) );

// The default stylesheet
function affilo_default_stylesheet() {
	if (!is_admin())
	wp_enqueue_style( 'style', get_stylesheet_uri(), null, null, 'screen' );
}
add_action( 'wp_enqueue_scripts', 'affilo_default_stylesheet', 15 );

// Insert Top anchor
function affilo_topofpage() {
	echo '<a name="top"></a>'."\n";
}
// add_action('affilo_before', 'affilo_topofpage', 1);

// Insert skip-to-content link
function affilo_skip_to_content() {
	echo '<a href="#content" title="Skip to content" class="skip-to-content">' . __( 'Skip to content', 'affilo' ) . '</a>'."\n";
}
// add_action('affilo_before','affilo_skip_to_content');

function affilo_breadcrumbs() {
	//Use yoast breadcrumbs in available
	if ( function_exists( 'yoast_breadcrumb' ) ) { 
		yoast_breadcrumb('<div id="yoastbreadcrumb">','</div>'); 
	} else {
		affilo_breadcrumb_output();
	}
}

function affilo_breadcrumb_output() {
	$seperator = '&rsaquo;';
	$delimiter = '<span class="sep">&nbsp;__seperator__&nbsp;</span>';
	$home = 'Home'; //text for the 'Home' link
	$currentBefore = '<span class="current">';
	$currentAfter = '</span>';
	
	extract( apply_filters('affilo_breadcrumb_params', compact('seperator', 'delimiter', 'home', 'currentBefore', 'currentAfter')) );
	
	$delimiter = str_replace('__seperator__', $seperator, $delimiter);
	$output = '';
	if (!is_front_page() || is_paged() ) {
		$output.= '<div id="crumbs">';
		global $post;
		$output.= '<a href="' .  home_url() . '">' . $home . '</a> ' . $delimiter . ' ';
		if (is_home()){
			$output.= $currentBefore;
			$output.= wp_title('', false);
			$output.= $currentAfter;
		} elseif ( is_category() ) {
			global $wp_query;
			$cat_obj = $wp_query->get_queried_object();
			$thisCat = $cat_obj->term_id;
			$thisCat = get_category($thisCat);
			$parentCat = get_category($thisCat->parent);
			if ($thisCat->parent != 0) echo(get_category_parents($parentCat, TRUE, ' ' . $delimiter . ' '));
			$output.= $currentBefore . 'Viewing Category &#39;';
			$output.= single_cat_title('', false);
			$output.= '&#39;' . $currentAfter;

		} elseif ( is_day() ) {
			$output.= '<a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a> ' . $delimiter . ' ';
			$output.= '<a href="' . get_month_link(get_the_time('Y'),get_the_time('m')) . '">' . get_the_time('F') . '</a> ' . $delimiter . ' ';
			$output.= $currentBefore . get_the_time('d') . $currentAfter;

		} elseif ( is_month() ) {
			$output.= '<a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a> ' . $delimiter . ' ';
			$output.= $currentBefore . get_the_time('F') . $currentAfter;

		} elseif ( is_year() ) {
			$output.= $currentBefore . get_the_time('Y') . $currentAfter;

		} elseif ( is_single() && !is_attachment() ) {
			$cat = get_the_category();

			if ($cat) {
				$cat = $cat[0];
				if( get_post_type() != 'vp_portfolio' ) {
					$output.= get_category_parents($cat, TRUE, ' ' . $delimiter . ' ');
				}
			}
			$output.= $currentBefore;
			$output.= the_title('', '', false);
			$output.= $currentAfter;

		} elseif ( is_attachment() ) {
			$parent = get_post($post->post_parent);
			$cat = get_the_category($parent->ID); $cat = $cat[0];
			$output.= get_category_parents($cat, TRUE, ' ' . $delimiter . ' ');
			$output.= '<a href="' . get_permalink($parent) . '">' . $parent->post_title . '</a> ' . $delimiter . ' ';
			$output.= $currentBefore;
			$output.= the_title('', '', false);
			$output.= $currentAfter;

		} elseif ( is_page() && !$post->post_parent ) {
			$output.= $currentBefore;
			$output.= the_title('', '', false);
			$output.= $currentAfter;

		} elseif ( is_page() && $post->post_parent ) {
			$parent_id  = $post->post_parent;
			$breadcrumbs = array();
			while ($parent_id) {
				$page = get_page($parent_id);
				$breadcrumbs[] = '<a href="' . get_permalink($page->ID) . '">' . get_the_title($page->ID) . '</a>';
				$parent_id  = $page->post_parent;
			}
			$breadcrumbs = array_reverse($breadcrumbs);
			foreach ($breadcrumbs as $crumb) $output.= $crumb . ' ' . $delimiter . ' ';
			$output.= $currentBefore;
			$output.= the_title('', '', false);
			$output.= $currentAfter;

		} elseif ( is_search() ) {
			$output.= $currentBefore . 'Search results for &#39;' . get_search_query() . '&#39;' . $currentAfter;

		} elseif ( is_tag() ) {
			$output.= $currentBefore . 'Posts tagged &#39;';
			$output.= single_tag_title('', false);
			$output.= '&#39;' . $currentAfter;

		} elseif ( is_author() ) {
			global $author;
			$userdata = get_userdata($author);
			$output.= $currentBefore . 'Articles posted by ' . $userdata->display_name . $currentAfter;

		} elseif ( is_404() ) {
			$output.= $currentBefore . 'Error 404' . $currentAfter;
		}

		if ( get_query_var('paged') ) {
			if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) $output.= ' (';
			$output.= ' '.$delimiter.$currentBefore . __(' Page', 'versopress') . ' ' . get_query_var('paged') . $currentAfter;
			if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) $output.= ')';
		}
		$output.= '</div><div class="clear"></div>';
	}
	
	
	echo apply_filters('affilo_breadcrumb_output', $output);
}

add_action( 'affilo_before_content', 'affilo_breadcrumbs', 15 );


////////////////////////////////////////////////// Items To Hook into home page //////////////////////////////////////////////////

function affilo_home_featured_sidebar() {
	affilo_do_sidebar( 'featured_aside', 'home_featured', 'featured-aside' );
}
add_action('affilo_featured','affilo_home_featured_sidebar');

function affilo_home_content() {
	while ( have_posts() ) : the_post();
		if (is_page()) { ?>
			<h2 class="page-title"><?php the_title(); ?></h2>
				<div class="entry-content">
					<?php the_content() ?>
					<?php edit_post_link(__('Edit', 'affilo'),'<span class="edit-link">','</span>') ?>
				</div><!-- .entry-content -->
		<?php }
		else { get_template_part( 'loop', 'home' ); }
	endwhile;
}
add_action('affilo_home','affilo_home_content');

////////////////////////////////////////////////// Items To Hook into content areas //////////////////////////////////////////////////

// Filter the page title (credit: Ian Stewart)
function affilo_default_page_title() {
	global $post;
	$container = apply_filters( 'affilo_page_title_container', 'h1' );
	
	$content = '<' . $container . ' class="page-title">';
	if (is_attachment()) {
		$content .= '<a href="';
		$content .= get_permalink($post->post_parent);
		$content .= '" rev="attachment"><span class="meta-nav">&laquo; </span>';
		$content .= get_the_title($post->post_parent);
		$content .= '</a>';
	} elseif ( is_singular() ) {
		$content .= get_the_title();
	} elseif (is_author()) {
		$content .= '<span>';
		$content .= __('Author Archives: ', 'affilo');
		$content .= '</span> ';
		$content .= get_the_author();
	} elseif (is_category()) {
		$content .= '<span>';
		$content .= __('Category Archives:', 'affilo');
		$content .= '</span> ';
		$content .= single_cat_title('', FALSE);
	} elseif (is_search()) {
		$content .= '<span>';
		$content .= __('Search Results for:', 'affilo');
		$content .= '</span> <span id="search-terms">';
		$content .= esc_html(stripslashes($_GET['s']), true);
		$content .= '</span>';
	} elseif (is_tag()) {
		$content .= '<span>' . __('Tag Archives:', 'affilo') . '</span> ' . affilo_tag_query();
	} elseif (is_tax()) {
		$term = get_term_by('slug', get_query_var( 'term' ), get_query_var( 'taxonomy' ) );
		$content .= '<span>' . __('Archives:', 'affilo') . '</span> ' . $term->name;
	} elseif (is_day()) {
		$content .= sprintf(__('<span>Daily Archives:</span> %s', 'affilo'), get_the_time(get_option('date_format')));
	} elseif (is_month()) {
		$content .= sprintf(__('<span>Monthly Archives:</span> %s', 'affilo'), get_the_time('F Y'));
	} elseif (is_year()) {
		$content .= sprintf(__('<span>Yearly Archives:</span> %s', 'affilo'), get_the_time('Y'));
	} elseif (is_404()) {
		$content .= __('404 - File Not Found', 'affilo');
	} elseif (is_post_type_archive()) {
		$content .= '<span>' . __('Content Archives:', 'affilo') . '</span> ' . post_type_archive_title( '', false );
	} elseif (isset($_GET['paged']) && !empty($_GET['paged'])) {
		$content .= __('Blog Archives', 'affilo');
	}
	$content .= '</' . $container . '>';
	$content .= "\n";
	
	echo apply_filters('affilo_default_page_title', $content, $container, $post );
}
add_action( 'affilo_page_title', 'affilo_default_page_title' );

function affilo_archive_meta() {
	global $post;
	if ( is_category() || is_tag() && !( category_description() == '' || tag_description() == '' ) ) {
		$content = '<div class="archive-meta">';
		if ( !( category_description() == '' ) ) { $content .= apply_filters('affilo_archive_meta', category_description()); }
		elseif ( !( tag_description() == '' ) ) { $content .= apply_filters('affilo_archive_meta', tag_description()); }
		$content .= '</div>';
		echo $content;
	}
}
add_action( 'affilo_page_title', 'affilo_archive_meta' );

// Default 404 Page
function affilo_404_content() { 
	echo '<p>' . sprintf( __('Sorry, but we were unable to find what you were looking for. Try searching our content below. If you still can\'t find it, %sContact Us%s and we\'ll try to&nbsp;help!', 'affilo' ), '<a href="' . apply_filters( 'affilo_404_contact', home_url() . '/contact/' ) . '">', '</a>' ) . '</p>';
	get_template_part( 'searchform' );
	echo '<br/>';
	$back = 'javascript:window.history.back();';
	if (!empty($_SERVER['HTTP_REFERER'])) {
		$back = $_SERVER['HTTP_REFERER'];
	}
	echo '<p><a href="' . $back . '">&larr; ' . __('Go Back', 'affilo'). '</a></p>';
}
add_action( 'affilo_404', 'affilo_404_content' );

////////////////////////////////////////////////// Items To Hook into Sidebars //////////////////////////////////////////////////

function affilo_do_primary_widgets() {
	if ( is_sidebar_active('primary_widget_area') || has_action('affilo_no_primary_widgets') ) { ?>
	<div id="primary" class="aside primary-aside">
		<ul class="xoxo">
			
			<?php if ( !dynamic_sidebar('primary-aside') ) { affilo_no_primary_widgets(); } ?>
			
		</ul>
	</div><!-- #primary .aside -->
<?php }
}
add_action( 'affilo_primary_widgets', 'affilo_do_primary_widgets' );

function affilo_do_secondary_widgets() {
	if ( is_sidebar_active('secondary_widget_area') || has_action('affilo_no_secondary_widgets') ) { ?>
		<div id="secondary" class="aside secondary-aside">
			<ul class="xoxo">

				<?php if ( !dynamic_sidebar('secondary-aside') ) { affilo_no_secondary_widgets(); } ?>

			</ul>
		</div><!-- #secondary .aside -->
	<?php }
}
add_action( 'affilo_secondary_widgets', 'affilo_do_secondary_widgets' );

// Hook affilo_no_widgets to all default widget areas, but only if it's active
function affilo_no_widgets_active() {
	if ( has_action( 'affilo_no_widgets' ) ) {
		add_action( 'affilo_no_primary_widgets', 'affilo_no_widgets' );
		add_action( 'affilo_no_secondary_widgets', 'affilo_no_widgets' );
		add_action( 'affilo_no_featured_widgets', 'affilo_no_widgets' );
		add_action( 'affilo_no_footer_aside_widgets', 'affilo_no_widgets' );
		add_action( 'affilo_no_footer_aside_2_widgets', 'affilo_no_widgets' );
		add_action( 'affilo_no_footer_aside_3_widgets', 'affilo_no_widgets' );
		add_action( 'affilo_no_footer_aside_4_widgets', 'affilo_no_widgets' );
	}
}
add_action( 'init', 'affilo_no_widgets_active' );

////////////////////////////////////////////////// Items To Hook into Footer //////////////////////////////////////////////////

// Auto-hide the address bar in mobile Safari (iPhone)
function affilo_iphone() { echo '<script type="text/javascript">window.scrollTo(0, 1);</script>'; }
add_action('affilo_after','affilo_iphone');

// Add left/right hooks
function affilo_footer_left_right() {
	if ( has_action( 'affilo_footer_left' ) ) { echo '<div id="footer_left" class="left">'; do_action( 'affilo_footer_left' ); echo '</div><!-- #footer_left -->'; }
	if ( has_action( 'affilo_footer_right' ) ) { echo '<div id="footer_right" class="right">'; do_action( 'affilo_footer_right' ); echo '</div><!-- #footer_right -->'; }
}
add_action( 'affilo_footer', 'affilo_footer_left_right', 15 );

function affilo_feedback_link() {
	// This is disabled for the launch
	// And will be changed to use the UserVoice feedback form once the launch is complete
	// And all / any issues are sorted
	return;
	if (!is_admin()) {
		$admin = current_user_can( 'edit_posts' ) && current_user_can( 'edit_pages' );
		if (!$admin) {
			return;
		}
		wp_enqueue_script('thickbox', null, array('jquery'), '3.1-20111117');
		wp_enqueue_style('thickbox.css', '/'.WPINC.'/js/thickbox/thickbox.css', null, '1.0');	
	}
	$output = '<script type="text/javascript">';
	$output.= "
	(function($) {
		$(document).ready(function(){
			var admin = ".(is_admin()?'true':'false').";
			var feedBackWindowLink = $(document.createElement('a')).attr('id', 'feedBackWindowLink').css({
				display: 'block',
				background: '#0F5881 url(http://www.affilorama.com/img/feedback.png) top left no-repeat',
				width:'24px',
				height:'95px',
				'margin-top': '-47px',
				position: 'fixed',
				right: 0,
				top: '50%',
				cursor: 'pointer',
				'z-index': 99997
			}).attr('title', 'Submit feedback on AffiloTheme.');
			$(document.body).prepend(feedBackWindowLink);
			feedBackWindowLink.click(function(e){
				e.preventDefault();
				var W = 550, H = 550;
				var fburl = 'http://www.doubledotmedia.com/userfeedback/affilotheme?c=blue&TB_iframe=true&width='+W+'&height='+H;
				tb_show('', fburl);
				$('#TB_iframeContent').width('100%');
				var tbWindow = $('#TB_window'), w, h;
				if ( tbWindow.size() ) {
					console.log(tbWindow.width(), tbWindow.height());
					tbWindow.width(W).height(H);
					$('#TB_iframeContent').width(W).height(H - 27);
					$('#TB_iframeContent').css('padding', 0);
					tbWindow.css({'margin-left': '-' + parseInt((W / 2),10) + 'px'});
					if ( typeof document.body.style.maxWidth != 'undefined' )
						tbWindow.css({'top':'30px','margin-top':'0'});
				}				
			}).mouseenter(function(){
		      $(this).css('padding-right', '5px');
		    }).mouseleave(function(){
		       $(this).css('padding-right', '0');
		    });
			
		});
	})(jQuery);
	";
	$output.= '</script>';
	echo $output;
}

add_action('wp_head', 'affilo_feedback_link');
add_action('admin_head', 'affilo_feedback_link');


function affilo_admin_bar_render() {
    global $wp_admin_bar;
    if (current_user_can('edit_themes')) {
	    $wp_admin_bar->add_menu( array(
			'id' => 'affilo_help',
	    	'parent' => 'top-secondary',
			'title' => __( 'AffiloTheme Help'),
			'href' =>  admin_url('admin.php?page=affilo_help')
	    ));
	}
}
// and we hook our function via
add_action( 'wp_before_admin_bar_render', 'affilo_admin_bar_render' );


/**
 * Check and redirect to welcome page if just landed here!
 * Includes on theme activation, or after they've been setup by the shared hosting script
 */
function affilo_admin_welcome() {
	if (is_admin() && $user = wp_get_current_user() && current_user_can('edit_themes')) {
		if ($user->ID && !get_user_meta($user->ID, 'affilo_welcome', true) && isset($_SERVER['REQUEST_URI']) && strpos($_SERVER['REQUEST_URI'], '/wp-admin') === 0) {
			if (!isset($_GET['page']) || !in_array($_GET['page'], array('affilo_help', 'affilo_migrate'))) {
				header( 'Location: '.admin_url().'admin.php?page=affilo_help') ;
				return;
			}
		}
	}
}

add_action('affilo_init', 'affilo_admin_welcome');

/**
 * Check that the upload folder is setup for timthumb
 *
*/
function affilo_upload_folder_ok() {
	$upload_folder = wp_upload_dir();
	if (!empty($upload_folder['error']) && !isset($upload_folder['base_dir'])) {
		add_settings_error('tgmpa', 'upload_folder_not_set', 'You need to create the <i>uploads</i> folder in your /wp-content/ folder, otherwise the header creator, and certain image widgets will not work correctly. <a href="http://www.affilorama.com/u/BF2Hr" target="_blank">Read more</a>');
	}
}
add_action('admin_notices', 'affilo_upload_folder_ok');
?>
