<?php
/**
 * Migration from previous Affilotheme 1 series theme.
 *
 */
global $affilo_migration;

/**
 * Affilo Migration
 */
class AffiloMigration {
	
	var $tasks = array(
		'HomePage',
		'Redirects',
		'Theme',
		'Menu',
		'Header',
		'Styles',
		'Squeeze'
	);
	
	var $_options = array();
	
	static function startup() {
		add_action('affilo_init', array(__CLASS__, 'check'));
	}
	
	/**
	 * Run on startup to check if migration is required
	 */
	static function check() {
		global $pagenow;
		$migrate = affilo_get_option('migrate');
		if (!$migrate) {
			if (self::_legacyCheck()) {
				$migrate = true;
				affilo_add_option('migrate', true);
			} else {
				affilo_add_option('migrated', 'na');
			}
		}	
		
		if ($migrate) {
			$allowPages = array(
				'index.php',
				'update-core.php',
				'themes.php'
			);
			if ($migrate !== 'soft' && !in_array($pagenow, $allowPages) && (!isset($_GET['page']) || $_GET['page'] !== 'affilo_migrate')) {
				header( 'Location: '.admin_url().'admin.php?page=affilo_migrate') ;
				return;
			}
			add_action('admin_menu', array('AffiloMigration', 'activate'), 20);
		}
		//Hide the plugin upgrade notices, they are distracting and not required at this point in the process.
		TGM_Plugin_Activation::$instance->notices = false;
	}	
	
	/**
	 * Activate the migration process
	 */
	static function activate() {
		global $affilo_migration;
		add_submenu_page( 'affilo_admin', __('Migrate', 'affilotheme'), __('Migrate', 'affilotheme'), 'manage_options', 'affilo_migrate', 'affilo_migrate');
		$affilo_migration = new AffiloMigration();
	}
	
	/**
	 * Check that a previous version of AffiloTheme exists, and that it has
	 * been previously activated.
	 */
	static function _legacyCheck() {
		if ($theme = get_theme('AffiloTheme') && $version = get_option( 'ddm_theme_version' )) {
			return true;
		}
	}
	
	/**
	 * Load tasks
	 */
	function __construct() {
		foreach ($this->tasks as &$task) {
			$class = "{$task}MigrationTask";
			$task = new $class();
		}
	}
	
	/**
	 * Start migration
	 */
	function startTasks() {
		do_action('affilo_start_migration');
		delete_option('affilo_migration');
	}
	
	/**
	 * Store options to be set to theme after all tasks are run
	 * 
	 * @param array $options
	 */
	function migrate($options = array()) {
		$this->_options = (array) $options + $this->_options;
	}
	
	/**
	 * End migration, set options directly, or store to be applied after child install
	 */
	function endTasks() {
		do_action('affilo_end_migration');
		if (!empty($this->_options)) {
			add_option('affilo_migration', $this->_options);
		}	
	}
	
	function result($result = null) {
		$option = 'affilo_migration_result';
		if (is_string($result)) {
			update_option($option, $result);
		} else {
			$stored = get_option($option);
			if ($result) {
				delete_option($option);
			}
			$result = $stored;
		}
		return $result;
	}
	
	/**
	 * Complete migration by overwriting required options
	 */
	function complete() {
		if ($migration = get_option('affilo_migration')) {	
			$options =  get_option(THEME_OPTIONS);
			$options = $migration + $options;
			update_option(THEME_OPTIONS, $options);
			delete_option('affilo_migration');
		}
		affilo_add_option('migrated', true);
		affilo_delete_option('migrate');
	}
	
	/**
	 * Skip migration
	 */
	function skip() {
		affilo_add_option('migrated', 'no');
		affilo_delete_option('migrate');
	}
}

//Run startup processes & hooks
AffiloMigration::startup();

/**
 * Migration Base task
 *
 */
class AffiloMigrationTask {
	
	var $title = '';
	
	var $desc = '';
	
	function run() {}
	
	function _migrate($options) {
		global $affilo_migration;
		$affilo_migration->migrate($options);
	}
}

/**
 * 
 * Home Page migration task
 *
 */
class HomePageMigrationTask extends AffiloMigrationTask {
	
	var $title = 'Home Page';
	
	var $desc = 'Check & migrate your home page format if required.';
	
	function run() {
		$home = get_option('ddm_static_pages');
		if (!$home || !($post = get_post($home))) {
			return '<p>Home page update not required.</p>';
		}
		wp_update_post(array('ID' => $post->ID, 'post_type' => 'page' ));
		update_option('show_on_front', 'page');
		update_option('page_on_front', $post->ID);
		return '<p><i>`'.$post->post_title.'`</i> has been moved to `<i>Pages</i>` and set as your home page.</p>';
	}
}

/**
 * Affiliate Redirects Migration task
 *
 */
class RedirectsMigrationTask extends AffiloMigrationTask {
	
	var $title = 'Affiliate Redirects';
	
	var $desc = 'Copy over existing affiliate redirects.';
	
	function run() {
		global $wpdb;  
		$output = ''; 	
    	$settings = affilo_redirect_settings();
		extract($settings);
		$_dbVersion = get_option('ddm_redirect_db_version');
		if ($_dbVersion && $dbVersion > $_dbVersion) {
			affilo_redirects_upgrade();
		}
		$count = $wpdb->get_results("SELECT count(`id`) c FROM $tableName;", ARRAY_A);
		if (!$count || empty($count[0]['c'])) {
			$output.= "<p>No affiliate redirects found.</p>";
		} else {
			$output.= "<p>Updating {$count[0]['c']} affiliate redirects.</p>";
		}
		return $output;
	}
}

/**
 * Theme Migration task
 *
 */
class ThemeMigrationTask extends AffiloMigrationTask {
	
	var $title = 'Theme & Layout';
	
	var $desc = 'Migrate to an updated theme variation, and update page layout to best match existing layout options.';
	
	function run() {
		$output = '';
		$import = $this->_theme($output);
		$import+= $this->_layout($output);
		$this->_migrate($import);
		return $output;
	}
	
	function _theme(&$output) {
		global $affilo_settings_factory;
		$import = array();
		//only chnage the theme if they have selected the base theme
		if (AFFILO_PATH == THEME_PATH) {
			//select random theme & variation from subset of full width header themes
			$themes = array(
				'AffiloTheme - Avenue',
				'AffiloTheme - Glide',
				'AffiloTheme - SuperMassive'
			);
			$theme = $themes[array_rand($themes)];
			$settings = affilo_get_theme($theme);
			$settings['Variations'] = affilo_get_theme_variations($theme);
			$variation = !empty($settings['Variations']) ? array_rand($settings['Variations']) : '';
			//pass the new theme & variant through the theme settings class to configure & select theme
			$import = array('theme' => $theme, 'theme-variant' => $variation);
			$import = $affilo_settings_factory->settings['affilo_theme_settings']->format_options($import, array());
			$output.= "<p>Selected theme `<i>{$variation}</i>`.</p>";
		}
		return $import;
	}
	
	function _layout(&$output) {
		$previous = get_option('ddm_sidebar_location');
		$layout = $previous == 'Left' ? 'two-col-left' : 'two-col-right';
		$import = array('layout' => $layout, 'home_layout' => $layout);
		$side = str_replace('two-col-', '', $layout);
		$output.= "<p>Selected `<i>{$side}</i>` sidebar layout.</p>";
		return $import;
	}
}

/**
 * Header Settings Migration task
 *
 */
class HeaderMigrationTask extends AffiloMigrationTask {
	
	var $title = 'Header Settings';
	
	var $desc = 'Copy over existing header creator settings & header styles.';
	
	function run() {
		$output = '';
		$map = array(
			'ddm_title' => 'logo-text',
			'ddm_title_font' => 'style_headline_font-family',
			'ddm_title_font_size' => 'style_headline_font-size',
			'ddm_title_color' => 'style_headline_font-color',
			'ddm_tagline' => 'blogdescription',
			'ddm_tagline_font' => 'style_tagline_font-family',
			'ddm_tagline_font_size' => 'style_tagline_font-size',
			'ddm_tagline_color' => 'style_tagline_font-color',
			'ddm_title_link' => 'logo-link',
			'ddm_title_hide' => 'tagline',
			'ddm_header_bg_image' => 'logo-image',
			'ddm_header_height' => 'logo-height',
			'ddm_header_bg_repeat' => 'logo-repeat'
		);
		$import = array();		
		foreach ($map as $from => $to) {
			$existing = get_option($from);
			if ($to == 'tagline') {
				$existing = $existing == 'Hide' ? 0 : 1;
			} elseif (strpos($to, 'font-color') && empty($existing)) {
				continue;
			}
			$import[$to] = $existing;
		}
		
		$this->_migrate($import);
		$output.= "<p>Updated header title & header image settings.</p>";
		if ($hc = get_option('ddm_header_creator_settings')) {
			update_option('affilo_header_creator_settings', $hc);
			$output.= "<p>Updated header creator default settings.</p>";
		}
		return $output;
	}
}

/**
 * Style Settings Migration task
 *
 */
class StylesMigrationTask extends AffiloMigrationTask {
	
	var $title = 'Font & Style Settings';
	
	var $desc = 'Migrate compatable font & styling options.';
	
	function run() {
		$output = '';
		$map = array(
			'ddm_body_font' => array('style_body_font-family', 'style_post_content-family'),
			'ddm_body_font_size' => array('style_body_font-size', 'style_post_content-family'),
			'ddm_heading_font' => array('style_post_title-family', 'style_post_content_headings-family'),
			'ddm_h1_font_size' => 'style_post_content_h1-size',
			'ddm_h2_font_size' => array('style_post_content_h2-size', 'style_post_title-size'),
			'ddm_h3_font_size' => 'style_post_content_h2-size'
		);
		$import = array();		
		foreach ($map as $from => $to) {
			$existing = get_option($from);
			foreach ((array) $to as $t) {
				$import[$t] = $existing;
			}
		}
		$this->_migrate($import);
		$output.= "<p>Updated content font & style settings.</p>";
		return $output;
	}
}

/**
 * Menu Migration task
 *
 */
class MenuMigrationTask extends AffiloMigrationTask {
	
	var $title = 'Menu & Navigation';
	
	var $desc = 'Migrate sidebar menu and setup navigation.';
	
	function run() {
		//current widgets
		$widgets = wp_get_sidebars_widgets(); 
		
		$output = '';
		//create the sidebar menu based on sidebar settings from legacy theme
		//get content
		switch($type) {
			case 'Silo': //categories
				$scope = array();
			case 'Split': //just 2 categories
				if (!isset($scope)) {
					$scope = array(get_option('ddm_sidebar_category_1'), get_option('ddm_sidebar_category_2'));
					$scope = array_unique(array_filter($scope));
				}
				if (empty($scope)) {
					$menuList =& get_categories();
				} else {
					$menuList = array();
					foreach ($scope as $cid) {
						$menuList[$cid] =& get_category($cid);
					}
				}
				break;	
			case 'List All': //all posts
			default:
				$postOptions = array(
					'exclude' => get_option('ddm_sidebar_post_hide'),
					'numberposts' => get_option('ddm_sidebar_length_limit')
				);
				if (get_option('ddm_sidebar_sort_order') == 'Title') {
					$postOptions['orderby'] = 'title';
					$postOptions['order'] = 'ASC';
				} else {
					$postOptions['orderby'] = 'date';
					$postOptions['order'] = 'DESC';
				}
				$menuList = get_posts($postOptions);
			break;
		}
		//add menu
		$menuID = $this->_addMenu('Sidebar Menu', $menuList);
		
		if (!isset($widgets['primary_widget_area'])) {
			$widgets['primary_widget_area'] = array();
		}
		//bottom custom text widget
		$text = get_option('ddm_sidebar_content_bottom');
		if (is_string($text) && trim($text) != '') {
			array_unshift($widgets['primary_widget_area'], $this->_addWidget('text',  array(
				'title' => '',
	      		'text' => $text
			)));
			$output.= "<p>Created new sidebar widget for your custom bottom sidebar content.</p>";
		}
		
		//new menu widget
		$output.= "<p>Created new sidebar menu widget.</p>";
		array_unshift($widgets['primary_widget_area'], $this->_addWidget('nav_menu',  array(
			'title' => '',
      		'nav_menu' => $menuID
		)));
		
		//top custom text widget
		$text = get_option('ddm_sidebar_content_top');
		if (is_string($text) && trim($text) != '') {
			array_unshift($widgets['primary_widget_area'], $this->_addWidget('text',  array(
				'title' => '',
	      		'text' => $text
			)));
			$output.= "<p>Created new sidebar widget for your custom top sidebar content.</p>";
		}
			
		//disable main nav - old theme didn't support it, and there isn't 
		//a clearly defined list of content that we can setup for it
		$output.= "<p>Disabled primary navigation menus.</p>";
		$this->_migrate(array('primary_nav' => 'none', 'secondary_nav' => 'none'));
		
		//create footer nav
		$footerList = array();
		$footerPages = get_option('ddm_footer_pages');
		$footerPosts = get_option('ddm_footer_posts');
		$misc = get_option('ddm_footer_misc_links');
		if (($footerPages && is_array($footerPages)) || ($footerPosts && is_array($footerPosts)) || (is_array($misc) && !empty($misc))) {
			if ($footerPages) {
				$footerList = get_pages(array('include' => $footerPages));
			}
			if ($footerPosts) {
				$footerList = array_merge($footerList, get_posts(array('include' => $footerPosts)));
			}
			$menuID = $this->_addMenu('Footer Menu', $footerList);
			
			$this->_migrate(array('footer_nav' => $menuID, 'footer_nav-position' => 'affilo_footer'));
			
			if (!empty($misc)) {
				$this->_migrate(array('footer_nav-enable-home' => true));
			}
			$output.= "<p>Created footer menu.</p>";
		}
		
		//footer text
		$text = get_option('ddm_footer_custom_text');
		if (is_string($text) && trim($text) != '') {
			if (!isset($widgets['footer_widget_area_1'])) {
				$widgets['footer_widget_area_1'] = array();
			}
			array_unshift($widgets['footer_widget_area_1'], $this->_addWidget('text',  array(
				'title' => '',
	      		'text' => $text
			)));
			$output.= "<p>Created new footer widget for your custom footer text.</p>";	
		}
		
		//update widgets
		wp_set_sidebars_widgets($widgets);
		
		return $output;
	}
	
	function _addMenu($name, $list) {
		$menuID = wp_create_nav_menu( $name );
		$n = 1;
		while (!is_int($menuID)) {
			$n++;
			$_name =   "{$name} {$n}";
			$menuID = wp_create_nav_menu($_name);
		}
		$menuObj = wp_get_nav_menu_object($menuID);
		
		foreach ($list as $item) {
			$menuItem = array(
				'menu-item-type' => isset($item->post_type) ? 'post_type' : 'taxonomy',
				'menu-item-object-id' => isset($item->post_type) ? $item->ID : $item->term_taxonomy_id,
				'menu-item-object' => isset($item->post_type) ? $item->post_type : $item->taxonomy,
				'menu-item-status' => 'publish'
			);
			wp_update_nav_menu_item($menuID, 0, $menuItem);
		}
		return $menuID;
	}
	
	function _addWidget($type, $data) {
		$string = "widget_{$type}";
		$widgets = get_option($string);		
		$next = count((array) $widgets) + 1;
		array_pop($widgets);		
		$widgets[$next] = $data;
		$widgets += array('_multiwidget' => 1);
		update_option($string, $widgets);
		return "{$type}-{$next}";
	}
}

/**
 * Squeeze Page Settings Migration task
 *
 */
class SqueezeMigrationTask extends AffiloMigrationTask {
	
	var $title = 'Squeeze Pages';
	
	var $desc = 'Copy existing squeeze pages, update to use new theme styles & settings.';
	
	function run() {
		//get all squeeze pages
		
		$output = '';
		
		$pages = get_pages();
		$squeezePages = array();
		if ($pages) {
			foreach ($pages as $page) {
				$layout = get_post_meta($page->ID, '_ddm_squeeze_options_layout', true);
				if ($layout && $layout > 1) {
					$squeezePages[] = $page;
					$page->ddm_squeeze_options_layout = $layout;
					$page->ddm_squeeze_options = $this->_legacyOptions($page);
				}
			}
		}

		if (empty($squeezePages)) {
			return '<p>No squeeze pages found.</p>';
		}
		
		$output .= '<p>Found ' . count($squeezePages) . ' squeeze pages...</p>';
		
		foreach ($squeezePages as $i => &$page) {
			$options = $this->_legacyOptions($page);
			$mapping = $this->_mapLayout($page, $options);
			$data = (array) $page;
			$fields = $this->_applyMapping($page, $options, $mapping);
			$updated = array(
				'ID' => $page->ID,
				'post_type' => 'sqz-page'
			);
			foreach ($data as $key => $value) {
				if ($page->{$key} != $value) {
					$updated[$key] = $page->{$key};
				}
			}
			wp_update_post($updated);
			affilo_sqz_page_save_meta($page->ID, array('affilo' => $fields));
			$output .= '<p>Migrated squeeze page ' . ($i + 1) . ': `<i>' . $page->post_title . '</i>`</p>';
		}
		
		return $output;
	}
	
	/**
	 * Load the legacy squeeze page options for a page
	 * mapping them to the subsets that we'll map them on to
	 */
	function _legacyOptions(&$page, $options = array()) {
		$options = !empty($options) ? $options : array(
			'content' => array(
				'headline' => 'heading',
				'headline_color' =>	'heading_colour',
				'headline_2' => 'subHeading',
				'headline_2_color' => 'subHeading_colour',
				'form_title' =>	'optIn_heading',
				'form_title_color' => 'optIn_heading_colour',
				'button_text' => 'btnText',
			),
			'image' => 'prodImg',
			'video.url' => 'video',
			'form' => array(
				'type' => 'optIn_select',
				'aweber' => array(
					'unit' => 'aw_code',
					'meta_web_form_id' => 'aw_form_id',
					'meta_redirect_onlist' => 'aw_already_url',
					'redirect' => 'aw_thanks_url'
				),
				'custom' => array(
					'form' => 'optIn_custom'
				)
			),
			'footer' => array(//not implemented at present
				'use_custom' => 'use_custom_footer_links',
				'custom' => 'custom_footer_links'
			)
		);
		foreach ($options as &$opt) {
			if (is_array($opt)) {
				$opt = $this->_legacyOptions($page, $opt);
			} else {
				$opt = get_post_meta($page->ID, '_ddm_sp_' . $opt, true);
			}
		}
		return $options;
	}
	
	/**
	 * Map the legacy layout to a new sqz layout
	 */
	function _mapLayout(&$page, $options) {
		$matrix = $this->_squeezeMatrix();
		$legacy = $page->ddm_squeeze_options_layout;
		if (empty($legacy) || !isset($matrix[$legacy])) {
			$legacy = key($matrix);
		}
		return $matrix[$legacy];	
	}
	
	/**
	 * Map the legacy content to the sqz page options, update the page as required
	 */
	function _applyMapping(&$page, $options, $mapping) {
		extract($mapping); //$map (fields), $layouts (template options)
		$meta = array();
		$type = 'squeeze';
		$layout = $layouts[array_rand($layouts)];//pick random layout, needs persistence?
		$layoutOptions = affilo_sqz_page_load_layout($type, $layout);
		$variation = !empty($layoutOptions['variation']) ? array_rand($layoutOptions['variation']) : 'default';
		
		
		$content = affilo_sqz_page_content_defaults($layoutOptions['fields'], true);
		if (in_array('content', $map)) {
			$content = $options['content'] + $content;
			$content['content'] = $page->post_content;
			$page->post_content = '';
		}
		if (in_array('image', $map) && array_key_exists('image', $content) && trim("{$options['image']}") != '') {
			$content['image'] = $options['image'];
		}
		if (in_array('video', $map) && array_key_exists('video.url', $content) && trim("{$options['video.url']}") != '') {
			if ($video = $this->_extractVideoUrl($options['video.url'])) {
				$content = $video + $content; 
			}
		}
		
		$provider = array();
		if (in_array('form', $map)) {
			$aweber = $options['form']['type'] == 'aweber';
			$providerName = $aweber ? 'AweberSignup' : 'CustomSignup';
			$providerConfig = $aweber ? $options['form']['aweber'] : $options['form']['custom'];
			$provider = array(
				'name' => $providerName,
				'config' => array(
					$providerName => $providerConfig
				)
			);
		}
		$meta = array(
			'type' => $type,
			"layout.{$type}" => $layout,
			"variation.{$type}.{$layout}" => $variation,
			"content.{$type}.{$layout}" => $this->_expand($content),
			'provider' => $provider,
			'_sqz-page-template-options' => array('header' => '', 'footer' => '')
		);
		return $this->_expand($meta);
	}
	
	/**
	 * Takes an html video embed and attempts to extract a compatabel video url from it.
	 */
	function _extractVideoUrl($video) {
		//@todo - these patterns are 'first pass', they could definately be consolidated to reduce the number of matches & duplication
		$patterns = array(
			'url' => array(
				'<embed.*?src="http://www.youtube.com/watch\?v=([a-zA-Z0-9]+)' => 'http://www.youtube.com/v/%2$s',
				'<embed.*?src="(http://www.youtube.com/v/([a-zA-Z0-9]+))',
				'<iframe.*?src="http://www.youtube.com/embed/([a-zA-Z0-9]+)' => 'http://www.youtube.com/v/%2$s',
				'<embed.*?src="http://vimeo.com/moogaloop.swf\?clip_id=([a-zA-Z0-9]+)' => 'http://vimeo.com/%2$s',
				'<iframe.*?src="http://player.vimeo.com/video/([a-zA-Z0-9]+)' => 'http://vimeo.com/%2$s',
			), 
			'width' => array(
				'<embed.*?(?<=youtube.com)[^<]*?width="([0-9]+)"',
				'<embed.*?width="([0-9]+)"[^>]*?(?=youtube.com)',
				'<iframe.*?(?<=youtube.com)[^<]*?width="([0-9]+)"',
				'<iframe.*?width="([0-9]+)"[^>]*?(?=youtube.com)',
				'<embed.*?(?<=vimeo.com)[^<]*?width="([0-9]+)"',
				'<embed.*?width="([0-9]+)"[^>]*?(?=vimeo.com)',
				'<iframe.*?(?<=vimeo.com)[^<]*?width="([0-9]+)"',
				'<iframe.*?width="([0-9]+)"[^>]*?(?=vimeo.com)'
			), 
			'height' => array(
				'<embed.*?(?<=youtube.com)[^<]*?height="([0-9]+)"',
				'<embed.*?height="([0-9]+)"[^>]*?(?=youtube.com)',
				'<iframe.*?(?<=youtube.com)[^<]*?height="([0-9]+)"',
				'<iframe.*?height="([0-9]+)"[^>]*?(?=youtube.com)',
				'<embed.*?(?<=vimeo.com)[^<]*?height="([0-9]+)"',
				'<embed.*?height="([0-9]+)"[^>]*?(?=vimeo.com)',
				'<iframe.*?(?<=vimeo.com)[^<]*?height="([0-9]+)"',
				'<iframe.*?height="([0-9]+)"[^>]*?(?=vimeo.com)'
			)
		);
		$fields = array();
		foreach ($patterns as $field => $regex) {
			foreach ((array) $regex as $rx => $format) {
				if (is_int($rx)) {
					$rx = $format;
					$format = '';
				}
				$match = array();
				if (preg_match("@{$rx}@si", $video, $match)) {
					if ($format == '') {
						$fields[$field] = $match[1];
					} else {
						$fields[$field] = vsprintf($format, $match);
					}
					break;
				}
			}
		}
		return $fields;
	}
	
	/**
	 * Accepts a one-dimensional array where the keys are separated by a delimiter.
	 * 
	 * e.g.
	 * $array = array('some.key' => 'some value');
	 * $result = array(
	 * 	'some' => array('key' => 'some value')
	 * );
	 *
	 * @return array Returns a multi-dimensional array expanded from a one dimensional dot-separated array.
	 */
	function _expand($data) {
		$result = array();
		foreach ($data as $key => $val) {
			if (strpos($key, '.') === false) {
				$result[$key] = $val;
				continue;
			}
			list($path, $key) = explode('.', $key, 2);
			$path = is_numeric($path) ? intval($path) : $path;
			$result[$path][$key] = $val;
		}
		foreach ($result as $key => $value) {
			if (is_array($value)) {
				$result[$key] = $this->_expand($value, $options);
			}
		}
		return $result;
	}
	
	/**
	 * Get the legacy layout to new layout mapping matrix
	 */
	function _squeezeMatrix() {
		$matrix = array(
			2 => array( //2 Blank Full Page
				'layouts' => array(
					'theme-1',
					'theme-2',
					'theme-2-3',
					'theme-3',
					'theme-4',
					'theme-4-2',
					'theme-6-3'
				),
				'map' => array(
					'content'
				)
			),
			3 => array( //3 Image right, form bottom
				'layouts' => array(
					'theme-1',
					'theme-2',
					'theme-2-3',
					'theme-3',
					'theme-4',
					'theme-6-3'
				),
				'map' => array(
					'content', 'image', 'form'
				)
			),
			4 => array( //4 Image right, form right
				'layouts' => array(
					'theme-1',
					'theme-2',
					'theme-2-3',
					'theme-3',
					'theme-4',
					'theme-6-3',
					'theme-7-3'
				),
				'map' => array(
					'content', 'image', 'form'
				)
			),
			5 => array( //5 Image right, form right & bottom
				'layouts' => array(
					'theme-1',
					'theme-2',
					'theme-2-3',
					'theme-3',
					'theme-4',
					'theme-5'
				),
				'map' => array(
					'content', 'image', 'form'
				)
			),
			6 => array( //6 Video Left, form right
				'layouts' => array(
					'theme-1-3',
					'theme-2-2',
					'theme-3-3',
					'theme-3-3',
					'theme-4-3',
					'theme-5-2',
					'theme-6',
					'theme-6-2',
					'theme-7'
				),
				'map' => array(
					'content', 'video', 'form'
				)
			),
			7 => array( //7 Form bottom
				'layouts' => array(
					'theme-2',
					'theme-2-3',
					'theme-3',
					'theme-4-2',
					'theme-6-3'
				),
				'map' => array(
					'content', 'form'
				)
			)
		);
		return $matrix;	
	}
}

/**
 * Migration page action
 */
function affilo_migrate() {
	
	global $affilo_migration;
	
	$do = isset($_GET['do']) ? $_GET['do'] : 'start';
	
	switch ($do) {
		case 'skip':
			$affilo_migration->skip();
		break;
		case 'complete':
			$affilo_migration->complete();
		break;
	}
	
	?>
	
	<div class="wrap">
	    <div id="icon-options-general" class="icon32"><br/></div>
	    <h2>
	    	<?php _e( "AffiloTheme Migration", 'affilo'); ?><?php if ($do == 'start'):?>&nbsp;&nbsp;&nbsp;&nbsp;
	   		<a href="<?php echo admin_url().'admin.php?page=affilo_migrate&do=skip'; ?>" class="button-secondary" title="Skip AffiloTheme Migration">Don't import settings</a><?php endif;?>
	   	</h2>
    	<div id="poststuff" class="metabox-holder">
    	
    	<?php switch($do):case 'start';?>
    	
    	<p>It appears you have previously used an earlier version of AffiloTheme. AffiloTheme 2 can import<br>
    	a selection of your settings &amp; content to help you with the migration to the latest version, including:</p>
    	
    	<ul>
    	<?php foreach($affilo_migration->tasks as $i => &$task):?>
    		<li><?php echo $i+1;?>. <strong><?php echo $task->title; ?></strong>: <?php echo $task->desc; ?></li>
    	<?php endforeach;?>
    	</ul>
    	
    	<p>&nbsp;</p>
    	
    	<p><strong>NOTE:</strong> It is strongly recommended that you backup your site before running this migration tool.</p>
    	
    	<p>Migration is optional, if you do not wish to migrate please select <i>'Don't import settings'</i> below and you will not be prompted again.</p>
    	
    	<p>&nbsp;</p>
    	
    	<?php 
    		$confirm = 'NOTE: It is strongly recommended that you backup your site before running this migration tool!\n\nAre you sure you wish to run the migration now?';
    	?>
    	
    	<a href="<?php echo admin_url().'admin.php?page=affilo_migrate&do=run'; ?>" onclick="return confirm('<?php echo $confirm;?>');" class="button-primary" title="Start AffiloTheme Migration">Start Migration</a>
    	&nbsp;&nbsp;&nbsp;|&nbsp;&nbsp;&nbsp;
    	<a href="<?php echo admin_url().'admin.php?page=affilo_migrate&do=skip'; ?>" class="button-secondary" title="Skip AffiloTheme Migration">Don't import settings</a>
    	
    	<?php break;case 'run';?>
    	
    	<h3>Running migration...</h3>
    	
    	<p>&nbsp;</p>
		<?php $affilo_migration->startTasks();?>
		<?php ob_start();?>
    	<?php foreach($affilo_migration->tasks as $i => &$task):?>
    		<p><strong>Migrating <?php echo $task->title; ?>...</strong></p>
    		<?php echo $task->run();?>
    		<p>&nbsp;</p>
    	<?php endforeach;?>
		<?php $affilo_migration->endTasks();?>
    	<?php 
    		$tasks = ob_get_contents();
    		ob_end_clean();
    		echo $tasks;
    		$affilo_migration->result($tasks);
    	?>
    	<p>&nbsp;</p>
    	
    	<p><strong><em>Finalising migration, one moment...</em></strong></p>
    	
    	<script type="text/javascript">
    		var r = function(){
				var loc = window.location.href;
				if (loc.indexOf('&do=') > 0) {
					loc = loc.replace(/\&do=[^&]*/, '&do=complete');
				} else {
					loc += '&do=complete';
				}
				window.location = loc;
        	}
        	setTimeout(r, 5000);
    	</script>
    	
    	<?php break;case 'complete';?>
    	
    	<h3>AffiloTheme Migration Complete!</h3>
    	
    	<p><strong>The upgrade to AffiloTheme 2 is a major one, and during the process we had to <a href="#results">make some decisions for you</a> to keep your site up and running.</strong></p>
    	
    	<p><a href="<?php echo home_url();?>" style="color:red;font-size:150%;font-weight:bold;" target="_blank">We strongly suggest you check your site now!</a></p>
    	
    	<p>&nbsp;</p>
    	
    	<p><strong>What's new in this version:</strong></p>
    	
    	<ul>
    		<li>&bull;&nbsp;&nbsp;All new squeeze page &amp; opt-in management</li>
    		<li>&bull;&nbsp;&nbsp;New high quilty theme variations and layouts to choose from</li>
    	</ul>
    	
    	<p>&nbsp;</p>
    	
    	<p><strong>We recommend you watch this video to see the changes in action:</strong></p>
    	
    	<a style="border:1px solid grey;display:block;width:400px;height:300px;" href="javascript:alert('Video coming soon!');"></a>
    	
    	<p>&nbsp;</p>
    	<p>&nbsp;</p>
    	<a name="results"></a>
    	<div id="poststuff" class="metabox-holder">    	
	    	<div class="postbox">
				<h3 class="hndle"><span>Migration Results</span></h3>
				<div class="inside">
					<?php echo $affilo_migration->result(true);?>
				</div>
			</div>
    	</div>
    	
    	<?php break;case 'skip';?>
    	
    	<p><strong>Disabling Migration</strong></p>
    	
    	<p>You will be redirected shortly...</p>
    	
    	<script type="text/javascript">
	    	var r = function(){
				window.location = '<?php echo admin_url().'admin.php?page=affilo_layout_and_theme_settings'; ?>';
	    	}
	    	setTimeout(r, 1000);
    	</script>
    	
    	<?php endswitch;?>
    	
    	</div>
    </div>
	
	<?php
}
?>