<?php

/**
 * Affilo Shortcodes
 *
 * This file contains all the definitions for the default Affilo shortcodes.
 *
 * @package Affilo
 * @subpackage Shortcodes
 */

global $affilo_shortcodes_index;

function affilo_register_shortcode($code, $method = null, $meta = array()) {
	global $affilo_shortcodes_index;
	if ($method) {
		add_shortcode( $code, $method );
	}
	if ( !(is_user_logged_in()  && current_user_can( 'edit_posts' ) && current_user_can( 'edit_pages' ))) return;
	$meta += array(
		'group' => 'General',
		'name' => ucwords(str_replace(array('-','_'), ' ', $code)),
		'description' => '',
		'format' => "[{$code}]"
	);
	if (!is_array($affilo_shortcodes_index[$meta['group']])) {
		$affilo_shortcodes_index[$meta['group']] = array();
	}
	$affilo_shortcodes_index[$meta['group']][$code] = $meta;
}

add_shortcode ( 'sidebar', 'affilo_sidebar_shortcode' );

add_shortcode( 'rtt', 'affilo_rtt' );
add_shortcode( 'author_bio', 'affilo_author_bio' );
add_shortcode( 'author', 'affilo_entry_author' );
add_shortcode( 'categories', 'affilo_entry_categories' );
add_shortcode( 'comments', 'affilo_entry_comments' );
add_shortcode( 'date', 'affilo_entry_date' );
add_shortcode( 'tags', 'affilo_entry_tags' );
add_shortcode( 'time', 'affilo_entry_time' );
add_shortcode( 'edit', 'affilo_entry_edit' );
add_shortcode( 'more', 'affilo_readmore' );

add_shortcode( 'twitter', 'affilo_twitter' );
add_shortcode( 'facebook', 'affilo_facebook' );
add_shortcode( 'digg', 'affilo_digg' );
add_shortcode( 'stumble', 'affilo_stumble' );

add_shortcode( 'protected', 'affilo_protected' );

include_once(SHORTCODES_PATH . '/shortcode_handler.php');

foreach(glob(SHORTCODES_PATH . '/*/*.php')  as $file) {
	include_once($file);
	$classname = basename($file, '.php');
	if(class_exists($classname)) {
		AffiloShortcode::instance($classname);
	}
}



/**
 * Enable Shortcodes in widget areas
 *
 * @since Affilo 2.4.8
 */
add_filter('widget_text', 'do_shortcode');

/**
 * Increase backtrack limit (see http://core.trac.wordpress.org/ticket/8553)
 *
 * @since Affilo 2.4.8
 */
@ini_set('pcre.backtrack_limit', 500000);

/**
 * Shortcode to display Return To Top link
 *
 * @since Affilo 2.4.3
 */
function affilo_rtt() {
	$link = '<a href="#top" class="rtt cb" title="Return to top of page">' . apply_filters( 'affilo_rtt_text', __( 'Return to Top', 'affilo' ) ) . '</a>';
	return $link;
}

/**
 * Shortcode to display a sidebar virtually anywhere.
 *
 * @since Affilo 2.5
 */
function affilo_sidebar_shortcode ( $atts ) {
	extract ( shortcode_atts ( array (
		'location'	=> 'shortcode',
		'id' 		=> null,
		'classes'	=> null
	), $atts ) );
	
	if ( is_null ( $id ) ) return null;
	
	ob_start();
	affilo_do_sidebar( $location , $id, $classes );
	return ob_get_clean();
}

/**
 * Displays an Edit link for admins
 *
 * @since Affilo 2.4.6
 */
function affilo_entry_edit() {
	if ( current_user_can('edit_posts') )
		return '<span class="meta-sep">|</span> <span class="edit-link"><a href="' . get_edit_post_link() . '">' . __('Edit', 'affilo') . '</a></span>';
}

/**
 * Displays the current post date, if time since is installed, it will use that instead.
 * Formatted for hAtom microformat.
 *
 * @since Affilo 2.4.6
 *
 * @uses affilo_time_since
 *
 */
function affilo_entry_date() {
	return '<span class="published entry-date">' . get_the_time( get_option('date_format') ) . '</span>';
}

/**
 * Displays the current post time
 *
 * @since Affilo 2.4.6
 */
function affilo_entry_time() {
	return '<span class="entry-time">' . get_the_time( get_option('time_format') ) . '</span>';
}

/**
 * Displays the current post categories
 *
 * @since Affilo 2.4.6
 *
 * @uses get_the_category_list
 *
 */
function affilo_entry_categories() {
	return '<span class="entry-categories">' . get_the_category_list(', ') . '</span>';
}

/**
 * Displays a Read More link
 *
 * @since Affilo 2.4.9
 *
 * @uses get_permalink
 *
 */
function affilo_readmore() {
	return '<a href="' . get_permalink() . '" title="' . sprintf(__("Continue Reading %s", "affilo"), esc_html(get_the_title(), 1)) . '" rel="nofollow" class="more-link">' . apply_filters( "affilo_read_more", "Read &amp; Discuss &raquo;" ) . '</a>';
}


/**
 * Displays the current post author.
 * Formatted for hAtom microformat.
 *
 * @since Affilo 2.4.6
 *
 */
function affilo_entry_author() {
	
	$output = '<span class="vcard author entry-author">';
	$output .= '<a href="' . get_author_posts_url( get_the_author_meta('ID') ) . '" class="url fn" title="' . sprintf( __('View all posts by %s', 'affilo'), esc_attr( get_the_author() ) ) .'">';
	$output .= get_the_author();
	$output .= '</a>';
	$output .= '</span>';
	
	return $output;
}


/**
 * Displays the current post tags or blank if none.
 *
 * @since Affilo 2.4.6
 *
 */
function affilo_entry_tags() {
	if ( $tags = get_the_tag_list( '<span>' . __('Tagged: ','affilo') . '</span>', ', ' ) )
		return '<span class="entry-tags">' . $tags . '</span>';
}


/**
 * Displays the number of comments in current post as a link to the comments, wrapped in a <span>.
 *
 * @since Affilo 2.4.6
 *
 */
function affilo_entry_comments() {
	ob_start();
	comments_popup_link(__('No Comments', 'affilo'), __('1 Comment', 'affilo'), __('% Comments', 'affilo'));
	return '<span class="entry-comments">' . ob_get_clean() . '</span>';
}

/**
 * Shortcode to create a content box
 *
 * @since Affilo 2.4.8
 */
function affilo_author_bio( $atts, $content = null ) {
	
	$output = '';
	$output .= '<div id="entry-author-info">';
	$output .= '<h2>' . sprintf( esc_attr__( 'About %s', 'affilo' ), get_the_author() ) . '</h2>';
	$output .= '<div id="author-avatar">' . get_avatar( get_the_author_meta( 'user_email' ), apply_filters( 'affilo_author_article_gavatar_size', 60 ) ) . '</div><!-- #author-avatar -->';
	$output .= '<div id="author-description">' . get_the_author_meta( 'description' ) . '<div id="author-link">';
	$output .= '<a href="' . get_author_posts_url( get_the_author_meta( 'ID' ) ). '">' . sprintf( __( 'View all posts by %s &raquo;', 'affilo' ), get_the_author() ) . '</a>';
	$output .= '</div><!-- #author-link	-->';
	$output .= '</div><!-- #author-description -->';
	$output .= '</div><!-- #entry-author-info -->';
	
	return $output;
}


/**
 * Shortcode to create a content box
 *
 * @since Affilo 2.4.7
 */
function affilo_box( $atts, $content = null ) {
	extract( shortcode_atts( array( 'type' => 'info', 'width' => '' ), $atts ) );
	return '<span class="box ' . $type . ' ' . $width . '">' . do_shortcode($content) . '</span>';
}

/**
 * Twitter button
 *
 * @since Affilo 2.4.8
 * @link http://twitter.com/goodies/tweetbutton
 */
function affilo_twitter( $atts, $content = null ) {
   	extract(shortcode_atts(array(
		'url' => '',
   		'style' => 'horizontal',
		'source' => '',
		'text' => '',
		'related' => '',
		'lang' => '',
		'float' => 'left'), $atts)
	);
	
	$output = '';
	if ( $url ) { $output .= ' data-url="'.$url.'"'; }
	if ( $source ) { $output .= ' data-via="'.$source.'"'; }
	if ( $text ) { $output .= ' data-text="'.$text.'"'; }
	if ( $related ) { $output .= ' data-related="'.$related.'"'; }
	if ( $lang ) { $output .= ' data-lang="'.$lang.'"'; }
	$output = '<div class="twitter ' . $float . '"><a href="http://twitter.com/share" class="twitter-share-button"'.$output.' data-count="'.$style.'">Tweet</a><script type="text/javascript" src="http://platform.twitter.com/widgets.js"></script></div>';	

	return $output;
}

/**
 * Facebook Like button
 *
 * @since Affilo 2.4.8
 * @link http://developers.facebook.com/docs/reference/plugins/like
 */
function affilo_facebook( $atts, $content = null ) {
   	extract(shortcode_atts(array(
		'float' => 'left',
		'send'	=> 'true',
		'style' => 'standard'), $atts)
	);
	
	global $post;
	if ( $style == "button" ) { $style = "button_count"; }
	elseif ( $style == "box" ) { $style = "box_count"; }
	else { $style = "standard";	}

	return '<div class="facebook ' . $float . '"><iframe src="http://www.facebook.com/plugins/like.php?href='. urlencode(get_permalink($post->ID)) . '&amp;send='.$send.'&amp;layout='.$style.'&amp;show_faces=false&amp;width=450&amp;action=like&amp;colorscheme=light" scrolling="no" frameborder="0" allowTransparency="true" style="border:none; overflow:hidden; width:450px; height:40px" allowTransparency="true"></iframe></div>';

}

/**
 * Digg button
 *
 * @since Affilo 2.4.8
 * @link http://about.digg.com/downloads/button/smart
 */
function affilo_digg( $atts, $content = null ) {
   	extract( shortcode_atts( array(
		'link' => '',
		'title' => '',
		'style' => 'Medium',
		'float' => 'left'), $atts)
	);
	
	$output = "		
	<script type=\"text/javascript\">
	(function() {
	var s = document.createElement('SCRIPT'), s1 = document.getElementsByTagName('SCRIPT')[0];
	s.type = 'text/javascript';
	s.async = true;
	s.src = 'http://widgets.digg.com/buttons.js';
	s1.parentNode.insertBefore(s, s1);
	})();
	</script>		
	";
	
	// Add custom URL
	if ( $link ) {
		// Add custom title
		if ( $title ) { $title = '&amp;title='.urlencode( $title ); }
		$link = ' href="http://digg.com/submit?url='.urlencode( $link ).$title.'"';
	}
	
	if ( $style == "large" ) { $style = "Large"; }
	elseif ( $style == "compact" ) { $style = "Compact"; }
	elseif ( $style == "icon" ) { $style = "Icon"; }
	else { $style = "Medium"; }
		
	$output .= '<div class="digg ' . $float . '"><a class="DiggThisButton Digg'.$style.'"'.$link.'></a></div>';
	return $output;

}

/**
 * Stumble Upon button
 *
 * @since Affilo 2.4.8
 * @link http://www.stumbleupon.com/badges/
 */
function affilo_stumble( $atts, $content = null ) {
	extract( shortcode_atts( array(
		'link' => '',
		'style' => 'box',
		'float' => 'left'), $atts)
	);

	if ( $style == 'compact' ) { $s = 1; }
	elseif ($style == 'box' ) { $s = 5; }
	elseif ($style == 'icon' ) { $s = 4; }
	else { $s = $style; }
	if ( $link ) { $link = ' &r=' . $link; }
		
	return '<div class="stumble ' . $float . '"><script src="http://www.stumbleupon.com/hostedbadge.php?s=' . $s . $link . '"></script></div>';
}


/**
 * Protect member-only content
 *
 * @since Affilo 2.4.8
 *
 */
function affilo_protected( $atts, $content = null) {
	extract( shortcode_atts( array(
		'show_login' => 'false',
		'class' => ''), $atts)
	);
	
	if (is_user_logged_in()) { return do_shortcode( $content ); }
	else {
		$output = '<div class="protected ' . $class . '">';
		$output .= apply_filters( 'affilo_protected_text', __( 'Sorry, you must be logged in to view this content.', 'affilo' ) );
		if ($show_login == 'true') { $output .= wp_login_form( array( 'echo' => 0 ) ); }
		$output .= '</div>';
		
		return apply_filters( 'affilo_protected', $output );
	}
}
?>