<?php

class ContentShortcode extends AffiloShortcode {
	
	var $_code = array(
		'tabs' => array(
			'name' => 'Tabs Widget',
			'description' => 'The tabs widget displays a set of tabs over content panels that are toggled on and off as the tabs are clicked.',
			'format' => '[tabs tab1="Tab 1 Title" tab2="Tab 2 Title"]\n
				\t[tab]content here...[/tab]\n
				\t[tab]content here...[/tab]\n
			[/tabs]'
		),
		'tab' => array(
			'name' => 'Tabs Widget Tab',
			'description' => 'Tab panel used to wrap tabbed content.',
			'format' => '[tab]content here...[/tab]'
		),
		'accordion' => array(
			'name' => 'Accordion Widget',
			'description' => 'The accordion widget display a set of content panels with headings that toggle the visibilty of the related panel. Only one panel displays at a time.',
			'format' => '[accordion]\n
				\t[panel title="Panel 1 Title"]content here...[/panel]\n
				\t[panel title="Panel 2 Title"]content here...[/panel]\n
			[accordion]'
		),
		'panel' => array(
			'name' => 'Accordion Panel',
			'description' => 'Creates a panel to display accordion content.',
			'format' => '[panel title="Panel Title"]content here...[/panel]'
		),
		'toggle' => array(
			'name' => 'Toggle Content Widget',
			'description' => 'The content toggle creates a link that toggles the visibilty of selected content. The content is hidden by default.',
			'format' => '[toggle title="Show More"]content here...[/toggle]'
		),
		'box' => array(
			'name' => 'Content Box',
			'description' => 'Creates a stylised content box to display content within. The box can be styled based on predefined styles, or alternatively can have custom styles applied.',
			'format' => '[box class="info"]content here...[/box]',
			'reference' => array(
				'class' => 'info, dark, alert, download, check, note',
				'icon' => 'custom image ',
				'border' => 'custom border color',
				'line' => 'solid, dotted, dashed',
				'background' => 'custom bg color', 
				'css' => 'custom css '
			)
		),
		'divider' => array(
			'name' => 'Content Divider',
			'description' => 'Creates a horizontal line to seperate content.',
			'format' => '[divider]'
		),
		'hr' => array(
			'name' => 'Content Divider (Shorthand)',
			'description' => 'Creates a horizontal line to seperate content.',
			'format' => '[hr]'
		),
		'button' => array(
			'name' => 'Button',
			'description' => 'Create a link as a stylised button.',
			'format' => '[button color="red" link="/"]Button Text[/button]',
			'reference' => array(
				'size' => 'small, large, xl',
				'class' => 'custom class',
				'color' => 'red, orange, yellow, green, blue, purple, dark, light',
				'border' => 'see color',
				'text' => 'link hover text',
				'link' => 'link url'
			)
		),
		'dropcap' => array(
			'name' => 'Dropcap',
			'description' => 'Creates a stylized dropcap, used to start paragraphs',
			'format' => '[dropcap class=""]S[/dropcap]content here...',
			'reference' => array(
				'class' => 'none, block, round',
				'color' => 'none, dark',
				'background' => 'custom bg color'
			)
		),
		'list' => array(
			'method' => 'lizt',
			'name' => 'List',
			'description' => 'Apply stylized bullets to an existing html list',
			'format' => '[list class="tick"]<ul><li>content here...</li><ul>[/list]',
			'reference' => array(
				'class' => 'tick, heart, srtoke, burst, thumb, start, cross, phone, print, arrow',
			)
		),
		'blockquote' => array(
			'name' => 'Blockquote',
			'description' => 'Insert a stylized quote, with optional citation, and ability to position the quote to the side of surrounding content.',
			'format' => '[blockquote cite="Somebody"]content here...[/blockquote]',
			'reference' => array(
				'cite' => 'person to be quoted',
				'side' => 'none, left, right',
				'class' => 'custom css class',
			)
		)
	);
	
	function _formatCodeParams() {
		foreach ($this->_code as &$code) {
			$code['group'] = 'Content';
		}
	}
	
	function tabs($atts, $content = null) {
		extract(shortcode_atts(array(), $atts));
		$firsttab = 1;
		global $innertabset;
	
		$innertabset = true;
	
		$output = '<div class="horiz-tabs">';
		foreach($atts as $tab) {
			if($firsttab == 1) {
				$isfirst = ' active-tab'; $firsttab++;
			} else {$isfirst = '';
			}
			$output .= '<div class="single-tab'.$isfirst.'"><div class="tab-inner-glow">'.$tab.'</div><!--glow--></div>';
		}
	
		$output .= '<div class="tabbed-content"><div class="tab-content-glow">';
		$output .= do_shortcode($content);
	
		$output .= '</div><!--tab-content-glow--></div></div>';
		return $output;
	}
	
	
	function tab($atts, $content = null) {
		extract(shortcode_atts(array(), $atts));
		global $innertabset;
	
		if($innertabset) {
			$firstinner = ' active-content'; $innertabset=false;
		} else {$firstinner = '';
		}
	
		$output = '<div class="tab-contents'.$firstinner.'">';
		$output .= do_shortcode($content);
		$output .= '</div>';
		return $output;
	}
	
	function accordion($attr, $content = null, $code) {	
		extract(shortcode_atts(array(
				'title' => '#'
		), $attr));
	
		if($code == "accordion") {
			return '<div class="accordion">'.do_shortcode($content).'</div>';
		} elseif($code == "panel") {
			return '<div class="panel"><h3 class="accordion-title"><a href="#">'.esc_attr($title).'</a></h3><div class="panel-content">'.do_shortcode($content).'</div></div>';
		}
	}
	
	function panel($attr, $content = null, $code) {
		return $this->accordion($attr, $content, $code);
	}
	
	function toggle($attr, $content = null ) {
		extract( shortcode_atts( array(
				'title' => 'Show More',
				'class' => '',
				'id' => '',
				'container' => 'div',
				'container_class' => '',
				'position' => 'before' ), $attr )
		);
	
		static $i = 1;
		if (!$id) {
			$id = 'toggle-' . $i; $i++;
		}
	
		$output = '';
		if ($position == 'before') {
			$output .= '<a href="#' . $id . '" class="toggle ' . $class . '">' . $title . '</a>';
		}
		$output .= '<' . $container . ' id="' . $id . '" class="toggled ' . $container_class . '">' . do_shortcode( $content ) . '</' . $container . '>';
		if ($position != 'before') {
			$output .= '<a href="#' . $id . '" class="toggle ' . $class . '">' . $title . '</a>';
		}
		return $output;
	}
	
	function box($attr, $content = null) {
		
		extract( shortcode_atts( array(
			'class' => '', //predefined types
			'icon' => '', //custom icons
			'border' => '', //custom border color
			'line' => '', //custom border style
			'background' => '', //custom background color,
			'css' => '' //feeling expert?
		), $attr));
		
		$classes = $styles = array();
		
		if (is_array($attr)) {
			foreach ($attr as $i => $val) {
				if (is_int($i)) {
					$classes[] = $val;
				}
			}
		}
		
		if ($class) {
			$classes[] = $class;
		}

		if ($icon) {
			if ($icon != 'none') {
				$classes[] = 'has-icon';
				$icon = 'url('.$icon.')';
			}
			$styles[] = 'backround-image: '.$icon.';'; 
		}
		
		if ($border) {
			if (strpos($border, ':')) {
				$styles[] = $border;
			} else {
				$styles[] = 'border-color:' . $border . ';';
			}
		}
		
		if ($line) {
			$styles[] = 'border-style:' . $line . ';';
		}
		
		if ($background) {
			$styles[] = 'background:' . $background . ';';
		}
		
		if ($css) {
			$styles[] = $css;
		}
		
		$style = $class = '';
		
		if (!empty($styles)) {
			$style = ' style="' . join('', $styles) . '"';
			$classes[] = 'custom';
		}
		
		if ($classes) {
			$class = ' ' . join(' ', $classes);
		}
		
		$output = '<div class="content-box'. $class .'"'. $style .'>';
		$output.= '<div class="content-box-before"></div>';
		$output.= '<div class="content-box-inner">' . do_shortcode( $content ) . '</div>';
		$output.= '<div class="content-box-after"></div></div>';
		return $output;	
	}
	
	function divider($attr, $content = null ) {
		extract( shortcode_atts( array( 'show_top' => false, 'align' => 'center' ), $attr ) );
	
		$top = ( $show_top ) ? do_shortcode( '[rtt]' ) : '' ;
		return '<div class="hr divider" style="text-align:' . $align . ';">' . $top . '</div>';
	}
	
	function hr($attr, $content = null) {
		return $this->divider($attr, $content);
	}
	
	function button($attr, $content = null ) {
		extract( shortcode_atts( array(
				'size' => '',
				'icon' => '',
				'class' => '',
				'color' => '',
				'border' => '',
				'text' => '',
				'link' => '/'), $attr)
		);
	
		// Set custom classes
		$class_out = $style = '';
		if ( $size ) $class_out .= ' ' . $size;
		if ( $icon ) $class_out .= ' ' . $icon;
		if ( $class ) $class_out .= ' ' . $class;
	
		// Set color
		if (
				$color == 'red' OR
				$color == 'orange' OR
				$color == 'yellow' OR
				$color == 'green' OR
				$color == 'blue' OR
				$color == 'purple' OR
				$color == 'dark' OR
				$color == 'light'
		) {
			$class_out .= ' ' . $color;
		} else {
			if (!$border) $border = $color;
			if (!$text) $text = '#FFF';
			$style = 'style="background:' . $color . '; color:' . $text . '; border-color:' . $border . ';"';
		}
	
		$output = '<a href="' . $link . '" class="button' . $class_out . '" ' . $style . '>' . $content . '</a>';
		return $output;
	}
	
	function dropcap($attr, $content = null) {
		extract( shortcode_atts( array(
				'class' => '',
				'color' => '',
				'background' => ''
				), $attr)
		);
		
		$classes = $styles = array();
		
		if (is_array($attr)) {
			foreach ($attr as $i => $val) {
				if (is_int($i)) {
					$classes[] = $val;
				}
			}
		}
		
		if ($class) {
			$classes[] = $class;
		}
		
		if (!empty($color)) {
			$styles[] = 'color: '.$color.';"';
		}
		
		if (!empty($background)) {
			$styles[] = 'background: '.$background.';"';
		}
		
		$style = $class = '';
		
		if (!empty($styles)) {
			$style = ' style="' . join('', $styles) . '"';
			$classes[] = 'custom';
		}
		
		if ($classes) {
			$class = ' ' . join(' ', $classes);
		}
		
		return '<span class="dropcap '. $class.'"' . $style . '>'.do_shortcode($content).'</span>';
	}
	
	function lizt($attr, $content = null) {
		extract( shortcode_atts( array( 'class' => 'bullet' ), $attr ) );
		if (is_array($attr) && isset($attr[0])) {
			$class = $attr[0];
		}
		return str_replace( '<ul>', '<ul class="fancy-list '.$class.'-list">', do_shortcode( $content ) );
	}
	
	function blockquote($attr, $content = null) {
		extract(shortcode_atts(array(
			'cite' => '',
			'side' => '',
			'class' => '',
		), $attr));
		
		$classes = array();
		
		if (is_array($attr)) {
			foreach ($attr as $i => $val) {
				if (is_int($i)) {
					if ($val == 'left' || $val == 'right') {
						$side = $val;
					} else {
						$classes[] = $val;
					}
					
				}
			}
		}
		
		if ($side == 'left' || $side == 'right') {
			$classes[] = "blockquote-$side";
		}
		
		if (!empty($cite)) {
			$cite = '<cite>'.$cite.'</cite>';
		}
		
		if ($classes) {
			$class = ' ' . join(' ', $classes);
		}
		
		$quote = do_shortcode($content);
		return '<blockquote class="quoted ' . $class . '">'.$quote.$cite.'</blockquote>';
	}
}

?>