<?php

class ImageShortcode extends AffiloShortcode {

	var $_code = array(
		'image' => array(
			'group' => 'Media',
			'name' => 'Image',
			'description' => 'Embed an image, optionally resized and linked to additional content displayed via lightbox',
			'usage' => '[img url="http://www.example.com/image.jpg" link="http://www.example.com/image.jpg" lightbox="image" width="200"]',
			'reference' => array(
				'url' => 'full url to image file',
				'width' => 'width in pixels to resize image to',
				'height' => 'height in pixels to resize image to',
				'link' => 'url to link image / link to light box content',
				'align' => 'none, left, right',
				'alt' => 'alt text for the image',
				'title' => 'title text for the image / lightbox title',
				'lightbox' => 'none, image, video - set this in conjunction with the link attribute to display content via lightbox',
				'preload' => 'false, true - preload the image & target on page',
				'resize' => 'true, false - physically reszie image, or just set it\'s display size',
				'mtop' => 'distance in pixels to offset the image display in the page',
				'mleft' => 'distance in pixels to offset the image display in the page',
				'mbottom' => 'distance in pixels to offset the image display in the page',
				'mright' => 'distance in pixels to offset the image display in the page'
			)
		), 
		'thumb' => array(
			'group' => 'Media',
			'name' => 'Thumbnail Image',
			'description' => 'Embed a resized image',
			'usage' => '[img url="http://www.example.com/image.jpg" w="200"]',
			'reference' => array(
				'url' => 'full url to image file',
				'width' => 'width in pixels to resize image to',
				'height' => 'height in pixels to resize image to',
				'alt' => 'alt text for the image',
				'w' => 'shorthand alternative to width',
				'h' => 'shorthand alternative to height'
			)
		)
	);

	function image($atts, $content = null) {
		extract(shortcode_atts(array(
				'url' => '',
				'width' => '',
				'height' => '',
				'link' => '#',
				'align' => '',
				'top' => '',
				'left' => '',
				'bottom' => '',
				'right' => '',
				'mtop' => '0',
				'mleft' => '0',
				'mbottom' => '0',
				'mright' => '0',
				'alt' => '',
				'title' => '',
				'lightbox' => 'none',
				'preload' => 'false',
				'resize' => 'true'
		),$atts));
		
		if (!empty($content) && empty($url)) {
			$url = $content;	
		}
		
		$position = '';
		
		if(esc_attr(esc_attr($top) || esc_attr($bottom) || esc_attr($left) || esc_attr($right)) != '') {
			$position = "position: absolute;";
		}
		foreach (array('top', 'bottom', 'left', 'right') as $p) {
			$v = "{$p}_position";
			$$v = esc_attr($$p) != '' ? $p . ':'.$$p.'px;' : '';
		}	
		
		
		// Lightbox
		if(esc_attr($lightbox) == "image") {
			$lightbox_hover = '<span class="hover-image" style="width: '.$width.'px; height: '.$height.'px;"></span>';
			$rel = "prettyPhoto[gallery]";
		} elseif(esc_attr($lightbox) == "video") {
			$lightbox_hover = '<span class="hover-video" style="width: '.$width.'px; height: '.$height.'px;"></span>';
			$rel = "prettyPhoto[gallery]";
		} else {
			$lightbox_hover = '';
			$rel = '';
		}
		
		$link1 = $link2 = '';
		// Image Link
		if(esc_attr($link) != '#') {
			if(esc_attr($lightbox) == "video") {
				$link1 = '<a href="file='.$link.'&image='.$url.'" title="'.$title.'" rel="'.$rel.'">';
			} else {
				$link1 = '<a href="'.$link.'" title="'.$title.'" rel="'.$rel.'">';
			}
			$link2 = '</a>';
		}
		
		$css = '';
		$image = $url;
		
		// Image & TimThumb
		if($width != "" || $height != "") {
			if ($width) {
				$css.= 'width: '.$width.'px;';
			}
			if ($height) {
				$css.= 'height: '.$height.'px;';
			}
			if ($resize == 'true') {
				$params = array_filter(array(
					'w' => $width,
					'h' => $height
				)) + array(
					'src' => $url
				);
				
				extract($params);
				$image = affilo_timthumb($src, $w, $h);
			}
		}
		
		// Image Preloader
		if($preload == "true") {
			$preload = 'preload';
		} else {
			$preload = '';
		}
		
		return '
			<div class="imagine '.$align.' '.$preload.'" style="background-position: center '.($height - 16).'px; '.$position.' '.$top_position.' '.$bottom_position.' '.$left_position.' '.$right_position.' margin: '.$mtop.'px '.$mright.'px '.$mbottom.'px '.$mleft.'px; width: '.$width.'px;">'.$link1.'
				'.$lightbox_hover.'
				<img class="image '.$preload.'" src="'.$image.'" alt="'.$alt.'" style="'.$css.'" />'.$link2.'
			</div>
		';
	}
	
	function thumb($atts, $content = null) {
		extract(shortcode_atts(array(
			'url' => '',
			'width' => '',
			'height' => '',
			'alt' => '',
			'w' => '',
			'h' => ''
		), $atts));
		
		if (!empty($content) && empty($url)) {
			$url = $content;	
		}
		
		$width = $w != '' ? $w : $width;
		$height = $h != '' ? $h : $height;
		
		$css = '';
		$image = $url;
		
		// Image & TimThumb
		if($width != "" || $height != "") {
			if ($width) {
				$css.= 'width: '.$width.'px;';
			}
			if ($height) {
				$css.= 'height: '.$height.'px;';
			}
			if ($resize == 'true') {
				$params = array_filter(array(
					'w' => $width,
					'h' => $height
				)) + array(
					'src' => $url
				);
				extract($params);
				$image = affilo_timthumb($src, $w, $h);
			}
		}
		return '
			<img class="image" src="'.$image.'" alt="'.$alt.'" style="'.$css.'" />
		';
	}
}

?>