<?php
class AffiloSignup {
	
	var $_initialized = false;
	
	var $_fields = array(
		/*
		'field_name' => array(
			'type' => input type see class affilo_input, or specified as a literal string to display
			'label' => lable for the field
			'desc' => field description
			'default' => the default value
			'required' => indicates if this field is required or optional
			'validate' => function name or regex (will be preg_quote'd) to match when saving this data
			'error' => validation failure message
		)
		 */
	);
	
	var $_url = '';
		
	/**
	 * Static method to intialize subclasess
	 * 
	 * @param string $class
	 */
	static function instance($class = null) {
		static $_instances = array();
		if (!isset($class)) {
			return array_keys($_instances);
		}
		if (!in_array($class, $_instances)) {
			if( !self::load($class)) {
				return;
			}
			$_instances[$class] = new $class();
			$_instances[$class]->__init();
		}
		return $_instances[$class];
	}
	
	/**
	 * Static method to load subclasses
	 * 
	 * @param string $class
	 * @param string $signupPath
	 */
	static function load($class = null, $signupPath = null) {
		if (empty($signupPath)) {
			$signupPath = SIGNUPS_PATH;
		}
	
		//load single class
		if (is_string($class)) {
			if (class_exists($class)) {
				return true;
			} else {
				$paths = array(
					$signupPath . "/providers/{$class}.php",
					$signupPath . "/{$class}.php"
				);
				foreach ($paths as $file) {
					if (file_exists($file)) {
						@include_once($file);
						if(class_exists($class)) {
							return true;
						}
					}
				}
			}
			return false;
		} else {
			//load all
			foreach(glob($signupPath . '/*/*.php')  as $file) {
				include_once($file);
				$classname = basename($file, '.php');
				if(class_exists($classname) && $class === true) {
					self::instance($classname);
				}
			}
		}
	}
	
	/**
	 * Get a list of provider classes with human names
	 */
	static function formList() {
		$list = array();
		if ($classes = self::instance()) {
			foreach ($classes as $class) {
				$list[$class] = self::instance($class)->title();
			}
		}
		return $list;
	}
	
	/**
	 * Format a provider class to human name
	 */
	static function name($class) {
		return trim(preg_replace('/([A-Z])/', ' $1', str_replace('Signup', '', $class)));
	}
	
	static function _uid() {
		static $i = 0;
		return 'signup-form-'  . ++$i;
	}
	
	/**
	 * Initialization method use din place of constructor
	 */
	function __init() {
		if ($this->_initialized) {
			return;
		}
		$this->_initialized = true;
	}
	
	/**
	 * Service title Getter
	 */
	function title() {
		return self::name(get_class($this));
	}
	
	/**
	 * The URL of the service provider
	 */
	function url() {
		return $this->_url;
	}
	
	/**
	 * Service Description Getter
	 */
	function description($full = true) {
		return $this->url();
	}
	
	/**
	 * Admin form fields definition getter
	 */
	function fields() {
		$fields = $this->_fields;
		$defaults = array(
			'type' => 'text',
			'label' => null,
			'desc' => null,
			'default' => null,
			'required' => true,
			'validate' => false,
			'error' => 'This field is invalid.'
		);
		foreach ($fields as $field => &$settings) {
			$settings += $defaults;
			if (!isset($settings['label'])) {
				$settings['label'] = ucwords(str_replace(array('-', '_'), ' ', $field));
			}
		}
		return $fields;
	}
	
	/**
	 * Generate default data set
	 */
	function defaults() {
		$fields = $this->fields();
		$defaults = array_fill_keys(array_keys($fields), null);
		foreach ($fields as $field => $settings) {
			if (isset($settings['default'])) {
				$defaults[$field] = $settings['default'];
			}
		}
		return $defaults;
	}
	
	/**
	 * Validate provider settings
	 */
	function validate($data) {
		$errors = array();
		$fields = $this->fields();
		foreach ($fields as $field => $settings) {
			if ($settings['required'] && empty($data[$field])) {
				$errors[$field] = 'This field is required.';
			} elseif($settings['validate'] && !empty($data[$field])) {
				if (is_callable($settings['validate'])) {
					
				} else if (is_string($settings['validate'])) {
					$match = '/' . preg_quote($settings['validate'], '/') . '/';
					if (@preg_match($match, $data[$field]) !== 1) {
						$errors[$field] = $settings['error'];
					}
				}
			}
		}
		return $errors;
	}
	
	/**
	 * Default form rendering
	 */
	function render($list, $content) {
		$template = $this->_template();
		return $this->_render($template, compact('list', 'content'));
	}
	
	/**
	 * Get form template string
	 * Overide in subclasess to declare the form template
	 * 
	 * @return string
	 */
	function _template(){}
	
	function _templateDefault() {
		return $this->_templateDefaultForm() . $this->_templateDefaultScript();
	
	}
	
	function _templateDefaultForm() {
		$template = '
			<form action="{:form.service_url}" method="post" id="{:uid}">
				<input type="text" name="{:form.name_field}" class="text name" value="" />
				<input type="text" name="{:form.email_field}" class="text from" value="" />
				<input type="submit" name="{:form.submit_field}" class="submit" value="{:content.button_text}" />
				{:form.custom_fields}
			</form>
		';
		return $template;
	}
	
	function _templateDefaultScript() {
		$template = '';
		global $post;
		if ($_REQUEST['preview'] == true || get_post_type($post->ID) == 'sqz-page') {
			$template = '<script type="text/javascript" src="http://ajax.googleapis.com/ajax/libs/jquery/1.7.2/jquery.js"></script>';
		}
		$template = $template . '
			 <script type="text/javascript">
			jQuery(document).ready(function(){
						var name = jQuery(\'#{:uid} input.name\');
						var from = jQuery(\'#{:uid} input.from\');
						name.val("{:content.name_field_label}").data("placeholder", name.val());
						from.val("{:content.email_field_label}").data("placeholder", from.val());
						jQuery(name).add(from).bind({
							focus: function(){
								var self = jQuery(this);
								if(self.val() == self.data("placeholder")) self.val("");
							},
							blur: function(){
								var self = jQuery(this);
								if(jQuery.trim(self.val()) == "") self.val(self.data("placeholder"));
							}
						});
					});
			</script>
		';
		return $template;
	}
	
	/**
	 * Internal default form rendering process that takes a string template
	 * and replaces var tokens with defined values
	 */
	function _render($template, $vars) {
		$renderVars = $this->_renderVars($vars + array('uid' => self::_uid()));
		return str_replace(array_keys($renderVars), $renderVars, $template);
	}
	
	/**
	 * Flatten & format vars with string dot seperated keys for replacement
	 */
	function _renderVars($vars = array(), $path = null) {
		$formatted = array();
		if (isset($path)) {
            $path .= '.';
        }
		foreach ($vars as $key => $val) {
			if (is_array($val)) {
				$formatted += $this->_renderVars($val, $path . $key);
			} else {
				$formatted["{:{$path}{$key}}"] = $val;
			}
		}
		return $formatted;
	}
}

?>