<?php
/**
 * Signup form handeler 
 */
include_once(SIGNUPS_PATH . '/signup_handler.php');

/**
 * Register custom post type used for Squeeze Pages & Signup Forms
 */
function affilo_sqz_page_init() {
	// Add custom post type
	register_post_type('sqz-page', array(
		'labels' => array(
			'name' => _x('Squeeze & Signup Forms', 'post type general name'),
			'singular_name' => _x('Squeeze Page / Sign-up Form', 'post type singular name'),
			'add_new' => _x('Add New', 'affilo' ),
			'add_new_item' => __( 'Add New Squeeze Page / Sign-up Form', 'affilo' ),
			'edit_item' => __( 'Edit', 'affilo' ),
			'new_item' => __( 'New', 'affilo' ),
			'view_item' => __( 'View', 'affilo' ),
			'search_items' => __( 'Search', 'affilo' ),
			'not_found' => __( 'No squeeze pages or sign-up forms found', 'affilo' ),
			'not_found_in_trash' => __( 'No squeeze pages or sign-up forms found in Trash', 'affilo' ),
			'parent_item_colon' => ''
		),
		'label' => __( 'Squeeze Pages', 'affilo' ),
		'singular_label' => __( 'Squeeze Page', 'affilo' ),
		'public' => true,
		'exclude_from_search' => true,
		'show_ui' => true,
		'capability_type' => 'page',
		'hierarchical' => true,
		'rewrite' => array('slug' => 's'),
		'query_var' => false,
		'supports' => array( 'title' ),
		'menu_position' => -10007,
		'menu_icon' => get_template_directory_uri() . '/images/affilo_sidebar_icon.png',
		'show_in_nav_menus' => false,
		'register_meta_box_cb' => 'affilo_sqz_page_meta_box_callback'
	));
}
add_action( 'init', 'affilo_sqz_page_init' );

function affilo_sqz_page_load() {
	if (affilo_sqz_page_detect()) {
		$post_id = get_the_ID();
		$options = array();
		if ($meta = get_post_meta($post_id, 'sqz-page-template-options', true)) {
			foreach ($meta as $key => $opt) {
				if ($opt === '') {
					$options[$key] = false;
				} elseif ($opt === 'true') {
					$options[$key] = true;
				} else {
					$options[$key] = $opt;
				}
			}	
		}
		affilo_sqz_page_template_option($options);
		add_filter('affilo_header_enabled', 'affilo_sqz_page_header_enabled', 10);
		add_filter('affilo_footer_enabled', 'affilo_sqz_page_footer_enabled', 10);
		add_filter('body_class', 'affilo_sqz_page_body_class');
	}
	
	add_action('affilo_after','affilo_sqz_page_popover');	
}
add_action( 'wp', 'affilo_sqz_page_load');

function affilo_sqz_page_body_class($classes) {
	if (!affilo_sqz_page_header_enabled()) {
		$classes[] = 'layout-squeeze-noheader';
	}
	if (!affilo_sqz_page_footer_enabled()) {
		$classes[] = 'layout-squeeze-nofooter';
	}
	return $classes;
}

function affilo_sqz_page_header_enabled() {
	return affilo_sqz_page_template_option('header');
}

function affilo_sqz_page_footer_enabled() {
	return 	affilo_sqz_page_template_option('footer');
}

function affilo_sqz_page_detect() {
	static $current = null;
	if (!isset($current)) {
		$current = false;
		if (is_singular()) {
			if (get_post_meta(get_the_ID(), 'sqz-form-type', true) == 'squeeze') {
				$current = true;
			}
		}
	}
	return $current;
}

function affilo_sqz_page_template_option($option = null) {
	static $options = array('header' => true, 'footer' => true);
	if (is_array($option)) {
		$options = $option + $options;
	} elseif (is_string($option)) {
		return array_key_exists($option, $options) ? $options[$option] : null;
	}
	return $options;
}


/**
 * List all squeeze pages
 */
function affilo_sqz_page_list($type = 'squeeze') {
	global $wpdb;
	$operator = '=';
	if (is_array($type)) {
		list($operator, $_type) = $type;
	} else {
		$_type = $type;
	}
	return $wpdb->get_results("
		SELECT * FROM $wpdb->posts `post`
		LEFT JOIN $wpdb->postmeta `meta`
		ON `post`.`id` = `meta`.`post_id`
		WHERE `post`.`post_type` = 'sqz-page'
		AND `post`.`post_status` NOT IN ('auto-draft', 'trash') 
		AND (`meta`.`meta_key` = 'sqz-form-type'
		AND `meta`.`meta_value` {$operator} '{$_type}')
		ORDER BY `post`.`id` DESC;
	", ARRAY_A);
}

/**
 * List all signup forms
 */
function affilo_signups_list() {
	return affilo_sqz_page_list(array('!=', 'squeeze'));
}

/**
 * Get id => title list of all signups
 */
function affilo_signups_form_list($key = 'ID', $label = 'post_title') {
	$list = array();
	if($result = affilo_signups_list()) {
		foreach ($result as $row) {
			$list[$row[$key]] = $row[$label];
		}
	}
	return $list;
}

/**
 * Render A Squeeze Page
 */
function affilo_sqz_page_render($post_id, $requested = true) {
	$post = get_post($post_id, ARRAY_A);
	if (!$requested && $post['post_status'] == 'trash') {
		return;	
	}
	$provider = get_post_meta( $post_id, 'sqz-form-provider', true );
	$list = get_post_meta( $post_id, 'sqz-form-list', true );
	
	$type = get_post_meta( $post_id, 'sqz-form-type', true );
	$layout = get_post_meta( $post_id, 'sqz-layout', true );
	$variation = get_post_meta( $post_id, 'sqz-variation', true );
	$content = get_post_meta( $post_id, 'sqz-fields', true );
	$css = get_post_meta( $post_id, 'sqz-css', true );	
	
	$form = null;
	if ($provider) {
		$form = AffiloSignup::instance($provider)->render($list, $content);
	}
	return affilo_sqz_page_render_template($post_id, $type, $layout, $variation, $content, $form, $css);
}

/**
 * Render squeeze page template
 */
function affilo_sqz_page_render_template($post_id, $type, $layout, $variation, $content = array(), $form = null, $css = '') {
	static $styles = array();
	$templateFiles = array(
		SQZ_TEMPLATE_PATH . '/' . $layout . '/' . $type . '.php',
		SQZ_TEMPLATE_PATH . '/' . $type . '.php'
	);
	$__output = '';
	$styleImport = array();
	$stylesheets = array(
		'reset.css',
		$layout . '/styles.css'
	);
	foreach ($stylesheets as $stylesheet) {
		if (!in_array($stylesheet, $styles)) {
			$styles[] = $stylesheet;
			$styleImport[] = SQZ_TEMPLATE_URL . '/' . $stylesheet;
		}
	}
	if (!empty($styleImport) || !empty($css)) {
		$__output.= '<meta http-equiv="X-UA-Compatible" content="IE=edge" /><style type="text/css">';
		foreach ($styleImport as $stylesheet) {
			$__output.= "\n@import url('{$stylesheet}?" . AFFILO_VERSION. "');\n";
		}
		if ($css) {
			$__output.= $css;
		}
		$__output.= '</style>';
	}
	foreach ($templateFiles as $templateFile) {
		$format = $type == 'squeeze' ? $type : 'form';
		$classes = array(
			"sqz-{$type}",
			"sqz-{$type}-{$layout}",
			"sqz-{$type}-{$layout}-{$variation}"
		);
		
		if ($format != $type) {
			$classes[] = "sqz-{$format}";
			$classes[] = "sqz-{$format}-{$layout}";
			$classes[] = "sqz-{$format}-{$layout}-{$variation}";
		} else {
			//Our squeeze page templates have been delivered in a collection of
			//template 'series' where styles are shared, set a common class
			//for use in the global scope of all templates in a series
			if (preg_match('/(theme-\d)(-\d)?/', $layout, $matches)) {
				$series = $matches[1];
				$classes[] = "sqz-{$format}-{$series}-global";
				$classes[] = "sqz-{$format}-{$series}-global-{$variation}";
			}
		}
		
		if (file_exists($templateFile)) {
			$path = str_replace(SQZ_TEMPLATE_PATH, SQZ_TEMPLATE_URL, dirname($templateFile)) . '/';
			ob_start();
			include $templateFile;
			$__template = ob_get_contents();
			ob_end_clean();
			$__output.= '<div class="sqz-inner '.join(' ', $classes).'" id="sqz-id-'.$post_id.'">';
			$__output.= $__template;
			$__output.= '</div>';
			//ensure the current shortcode is not in the content we are about to parse
			//this would cause children of the mighty apache to die a painful death!
			$remove = '[signup id="'.$post_id.'"]';
			$__output = str_replace($remove, "", $__output);
			return do_shortcode($__output);
		}	
	}
}

/**
 * Render A Signup Form
 */
function affilo_signup_render($post_id) {
	return affilo_sqz_page_render($post_id, false);
}

function affilo_sqz_page_popover_defaults() {
	return array(
		'enabled' => false,
		'locations' => array(),
		'mode' => 'load',
		'delay' => 0,
		'close' => 0,
		'exit_text' => 'Wait before you go, take advantge of this special offer!',
		'limit' => 'none',
		'frequency' => 200,
		'period' => 'day',
		'position' => '50 50',
		'overlay' => 'true',
		'o_color' => '#000000',
		'o_opacity' => '0.6',
		'close_pos' => 'left'
	);
}

/**
 * Handle embedding of popovers
 * 
 * Note: there is room for scripting imporvements here, primarily shifting the
 * control script solely to JS, passing in the config values as json.
 */
function affilo_sqz_page_popover() {
	global $wp_query;
	if (AFFILO_PREVIEW) return;
	$post_id = $wp_query->get('p');
	if(!($popoverPost = get_post_meta($post_id, 'sqz-popover-post', true))) {
		return;
	}
	if(!($popoverHTML = @affilo_sqz_page_render($popoverPost, false))) {
		return;
	}
	$options = (array) get_post_meta($popoverPost, 'sqz-popover-options', true) + affilo_sqz_page_popover_defaults();
	if (empty($options['enabled'])) {
		return;
	}
	if ($options['limit'] == 'defined' && !($frequency = (int) $options['frequency'])) {
		return;	
	}
	$domId = 'sqz-popover-' . $popoverPost;
	$_domId = 'sqz-id-' . $popoverPost;
	echo '
	<style type="text/css">
		#'.$domId.' {
			display:none;
			z-index:999998 !important;			
		}
		.sqz-popover a.close {
	';
	if($options['close_pos'] !== 'none') {
		echo '
			background: url('.get_template_directory_uri().'/images/close.png);
			width:28px;
			height:28px;
			'.$options['close_pos'].':-10px;
			top:-10px;
			display:block;
			position:absolute;
			z-index:999999 !important;
		';
	} else {
		echo '
			display:none;
		';
	}
		echo '
		}
		.sqz-popover .sqz-inner {
			position:relative;
			left: 0px;
		}
		
	</style>
	';
	echo '<div id="'.$domId.'" class="sqz-popover">';
	echo $popoverHTML;
	echo '</div>';
	echo '<script type="text/javascript" src="'.SCRIPTS_URL . '/jquery.tools.min.js'.'"></script>';
	
	list($_left, $_top) = explode(' ', $options['position']);
	$top = $_top . '%';
	if ($_top == 0 && $options['close_pos'] !== 'none') {
		$top = 10 .'%';
	}
	$left = $_left . '%';
	
	$load = empty($options['delay']) && ($options['mode'] == 'load') ? true : false;
	$display = compact('top', 'left', 'load');
	if (!empty($options['overlay'])) {
		$display['mask'] = array(
			'loadSpeed' => 200,
			'color' => $options['o_color'],
			'opacity' => $options['o_opacity']			
		);
	}
	$display['fixed'] =  false;
	$display['left']  = "center";
	$display['top']   = $top;
	echo '<script type="text/javascript">
	var affiloPopover = null;
	var affiloPopoverLoad = function(){
		if (affiloPopover !== null) {
			jQuery(affiloPopover).data("overlay").load();			
	';
	
	if ($options['mode'] == 'load' && !empty($options['close'])) {
		echo '
			var closeTime = null;
			var delayedClose = function(){
				closeTime = setTimeout(affiloPopoverClose, '.($options['close']*1000).');
			};
			if ('.$options['delay'].' > 0) {
				setTimeout(delayedClose, '.($options['delay']*1000).');
			} else {
				delayedClose();
			}
			jQuery(affiloPopover).mouseover(function(){
				clearTimeout(closeTime);
			});
		';
	}
	
	echo '
		}
		
	};
	var affiloPopoverClose = function(){		
		if (affiloPopover !== null) {			
			jQuery(affiloPopover).data("overlay").close();			
			affiloPopover = null;
		}
	};
	(function($) {
		$(document).ready(function(){		
			var display = true;
	';
	if ($options['limit'] == 'defined') {
		$cookieKey = "afftpop-{$post_id}-{$popoverPost}";
		echo '
			var current = $.cookie("'.$cookieKey.'") || 0;
			var frequency = '.$frequency.';
			if (current) {
				current = parseInt(current);
			}
			if (current >= frequency) {
				display = false;
			} else {
				current++;
				var daysInMonth = function (month, year) {
					return [31, isLeapYear(year) ? 29 : 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31][month];
				}
				var isLeapYear = function (year) {
					return ((year % 4 === 0) && (year % 100 !== 0)) || (year % 400 === 0);
				}
				var curDate = new Date();
				var m = curDate.getMonth();
				var y = curDate.getFullYear();
	';
		if ($options['period'] == 'week'){
				echo '
					var d = curDate.getDay();
					var i = curDate.getDate();
					if (d < 6) { //not sunday
						var diff = 6 - d + 1;
						while(diff) {
							diff--;
							if(++i >= daysInMonth(m, y)) {
								i = 1;
								if (m < 11) {
									m++;
								} else {
									m = 0;
									y++;
								}
							}
						}
						curDate.setDate(i);
						curDate.setMonth(m);
						curDate.setFullYear(y);
					}
				';
		} else if ($options['period'] == 'month'){
				echo '
					curDate.setDate(daysInMonth(m, y));
				';
				break;
		}
	echo '		
				curDate.setHours(23,59,59,0);
				$.cookie("'.$cookieKey.'", current, {expires: curDate});
			}
		';
	}
	echo '
			if (!display) {
				return;
			}
			var popoverOptions = '.json_encode($display).';
			popoverOptions.closeOnClick = false;
			
			popoverOptions.onBeforeClose = function(){
				window.affilopopped = true;
			};			
			affiloPopover = $("#'.$domId.'").overlay(popoverOptions);
	';
	
	if ($options['mode'] == 'exit') {
		echo '
			window.affilopopped = false;
			$("form").submit(function(){
				window.affilopopped = true;
			});
			$("a").click(function(){
				window.affilopopped = true;
			});
			$(window).mouseleave(function(){
				if (window.affilopopped) {
					return;
				}
				window.affilopopped = true;
				affiloPopoverLoad();
			});
			window.onbeforeunload = function(){
				if (window.affilopopped) {
					return;
				}
				window.affilopopped = true;
				affiloPopoverLoad();
				var exit_text = "'.addslashes($options['exit_text']).'";
				if ($.trim(exit_text) != "") {
					exit_text = "*****************************************************\n\n" + exit_text + "\n\n*****************************************************";
				} else {
					exit_text = true;
				}
				return exit_text;
			};
		';
	} elseif (!empty($options['delay'])) {
		echo '
			setTimeout(affiloPopoverLoad, '.($options['delay']*1000).');
		';
	}
	
			
	echo '		
		});
	})(jQuery);
	</script>
	';
}
?>