<?php
/**
 * AffiloTheme Upgrade Handler
 *
 */

class affilo_upgrade {

	var $theme = 'affilotheme_2'; //see function setThemeName

	var $packageUrl = 'http://www.affilorama.com/files/affilotheme/affilotheme.zip';

	var $detailsUrl = '';

	var $enableAutomaticChecking = true;

	var $optionName = 'affilo_update';

	var $automaticCheckDone = false;

	function __construct() {
		$this->setThemeName();
		$this->detailsUrl =  admin_url('admin.php?page=affilo_changelog');
		$this->installHooks();
	}

	function installHooks(){
		//Check for updates when WordPress does. We can detect when that happens by tracking
		//updates to the "update_themes" transient, which only happen in wp_update_themes().
		if ( $this->enableAutomaticChecking ){
			add_filter('pre_set_site_transient_update_themes', array($this, 'onTransientUpdate'));
		}


		//Insert our update info into the update list maintained by WP.
		add_filter('site_transient_update_themes', array($this,'injectUpdate'));


		//Delete our update info when WP deletes its own.
		//This usually happens when a theme is installed, removed or upgraded.
		add_action('delete_site_transient_update_themes', array($this, 'deleteStoredData'));

		add_action('admin_menu', array( $this, 'menuUpdate'));

		add_action('admin_notices', array( $this, 'nagUpdate') );

		add_filter('upgrader_pre_install', array($this, 'saveThemeSettings'),1,2);

		/*
		 * Upgrader filters used to foce the Theme Upgrader to accept our multi theme package
		 */
		add_filter('upgrader_clear_destination', array($this, 'prepareUpdate'), 5, 4);
		add_filter('upgrader_clear_destination', array($this, 'prepareUpdate'), 15, 4);
		add_filter('upgrader_post_install', array($this, 'stabilizeUpdate'), 5, 2);
		add_filter('upgrader_post_install', array($this, 'finalizeUpdate'), 15, 2);
	}


	function saveThemeSettings($classes, $themeName) {
        echo "<br>Saving current theme settings..." ;
        // Theme name will be affilotheme_2 so use the current stylesheet
        update_option('_affilo_transient_current_theme', get_stylesheet());
        update_option('_affilo_transient_current_theme_settings', get_option(THEME_OPTIONS));
        $themeFolder = get_theme_root() . '/'.get_stylesheet();
        if (!empty($themeName['theme']) && $themeName['theme'] !== 'affilotheme_2') {
            //if current theme is not a parent theme then try to delete child theme folder
            @delete_recursive($themeFolder);
        }
    }


	/**
	 * Retrieve update info from the configured metadata URL.
	 *
	 * Returns either an instance of ThemeUpdate, or NULL if there is
	 * no newer version available or if there's an error.
	 *
	 * @uses wp_remote_get()
	 *
	 * @param array $queryArgs Additional query arguments to append to the request. Optional.
	 */
	function requestUpdate(){
		$themeUpdate = null;
		if ($body = $this->requestMetaData()){
			$themeUpdate = $this->formatVersionData($body);
			//The update should be newer than the currently installed version.
			if ( ($themeUpdate != null) && version_compare($themeUpdate->version, $this->getInstalledVersion(), '<=') ){
				$themeUpdate = null;
			}
		}
		return $themeUpdate;
	}

	function requestChangelog() {
		if ($body = $this->requestMetaData()){
			return $this->formatChangelogData($body);
		}
	}

	function formatVersionData($xml) {
		$version = $xml->getElementByPath('latest/version');
		if ($version && $versionNum = $version->getValue()) {
			$metaData = new stdClass();
			$metaData->version = $versionNum;
			$metaData->formatted = array(
				'new_version' => $versionNum,
				'url' => $this->detailsUrl,
				'package' => $this->packageUrl
			);
			return $metaData;
		}
	}

	function formatChangelogData($xml) {
		$data = array(
			'version' => @$xml->getElementByPath('latest/version')->getValue(),
			'date' => @$xml->getElementByPath('latest/date')->getValue(),
			'details' => @$xml->getElementByPath('latest/changelog')->getValue(),
			'history' => @$xml->getElementByPath('history/changelog')->getValue()
		);
		if (array_filter($data) == $data) {
			return $data;
		}
	}

	function requestMetaData() {
		$transient = 'AFFILO_CHANGELOG_DATA';
		if ($cached = get_transient($transient)) {
			return $cached;
		}
		if ($changelog = affilo_api_changelog()) {
			$expires = 60 * 60 * 6;//cache for a couple of hours to relax api hits
			set_transient($transient, $changelog, $expires);
			return $changelog;
		}
	}

	/**
	 * Get the currently installed version of our theme.
	 *
	 * @return string Version number.
	 */
	function getInstalledVersion(){
		return AFFILO_VERSION;
	}

	/**
	 * Check for theme updates.
	 *
	 * @return void
	 */
	function checkForUpdates(){
		$state = get_option($this->optionName);
		if (empty($state)) {
			$state = new stdClass();
			$state->lastCheck = 0;
			$state->checkedVersion = '';
			$state->update = null;
		}

		$state->lastCheck = time();
		$state->checkedVersion = $this->getInstalledVersion();
		update_option($this->optionName, $state); //Save before checking in case something goes wrong

		$state->update = $this->requestUpdate();
		update_option($this->optionName, $state);
	}

	/**
	 * Run the automatic update check, but no more than once per pageload.
	 * This is a callback for WP hooks. Do not call it directly.
	 *
	 * @param mixed $value
	 * @return mixed
	 */
	function onTransientUpdate($value){
		if ( !$this->automaticCheckDone ){
			$this->checkForUpdates();
			$this->automaticCheckDone = true;
		}
		return $value;
	}

	/**
	 * Insert the latest update (if any) into the update list maintained by WP.
	 *
	 * @param array $updates Update list.
	 * @return array Modified update list.
	 */
	function injectUpdate($updates){
		//Is there an update to insert?
		if ( $state = $this->updateAvailable() ){
			$updates->response[get_template()] = $state->formatted;
		} elseif (is_object($updates) && isset($updates->response)) {
			unset($updates->response[get_template()]);
		}
		return $updates;
	}

	/**
	 * Nag them about the update on other admin pages also.
	 */
	function nagUpdate() {
		if (!($state = $this->updateAvailable())) {
			return;
		}
		$update_url = wp_nonce_url('update.php?action=upgrade-theme&amp;theme=' . get_template(), 'upgrade-theme_' . get_template());
		$update_onclick = __('Updating this theme will lose any customizations you have made.  \'Cancel\' to stop, \'OK\' to update.', 'affilo');
		$output = '<div class="update-nag">';
		$nag = 'There is a new version of AffiloTheme available. <a href="%s" >View version %s details</a> or <a href="%s" onclick="if ( confirm(\'%s\') ) {return true;}return false;">update automatically</a>.';
		$output .= sprintf( __($nag, 'affilo'), esc_url( $state->formatted['url'] ), esc_html( $state->formatted['new_version'] ), $update_url, esc_js( $update_onclick ) );
		$output .= '</div>';
		echo $output;
	}


	function menuUpdate() {
		if (!($state = $this->updateAvailable())) {
			return;
		}
		add_submenu_page( 'affilo_admin', __('Update Available', 'affilotheme'), __('Update Available', 'affilotheme'), 'manage_options', 'affilo_changelog', 'affilo_changelog');
	}

	function updateAvailable() {
		if (!affilo_get_option('enable_updates') || affilo_get_option('disable_updates')) {
			return false;
		}
		$state = get_option($this->optionName);
		return (!empty($state) && isset($state->update) && !empty($state->update)) ? $state->update : false;
	}

	/**
	 * Delete any stored book-keeping data.
	 *
	 * @return void
	 */
	function deleteStoredData(){
		delete_option($this->optionName);
	}


	function prepareUpdate($removed, $local_destination, $remote_destination, $theme) {
		@set_time_limit(0);
		if (isset($theme['theme']) && strpos($theme['theme'], 'affilotheme_2/') === 0) {
			$this->_tmpStyles();
		}
		return $removed;
	}


	function stabilizeUpdate($return, $theme) {
		if (isset($theme['theme']) && strpos($theme['theme'], 'affilotheme_2/') === 0) {
			$this->_tmpStyles();
		}
		return $return;
	}


	function finalizeUpdate($return, $theme) {
		if (isset($theme['theme']) && strpos($theme['theme'], 'affilotheme') === 0) {
			$themeName = get_option('_affilo_transient_current_theme');
			$themeName = empty($themeName) ? (isset($theme['theme'])  && !empty($theme['theme']) ? $theme['theme'] : 'affilotheme_2') : $themeName;

			$mytheme = wp_get_theme($themeName);
			echo "<br>Restructuring folders...";
			affilo_restructure();
			echo "<br><br>Switching to theme ". $mytheme->get_stylesheet();
			switch_theme($mytheme->get_template(), $mytheme->get_stylesheet());
			echo "<br><br>Restoring theme settings...";
	    	update_option(THEME_OPTIONS,get_option('_affilo_transient_current_theme_settings'));
	    	// Because we have came here with the theme name affilotheme_2
	    	// We can't let the user click the Activate button, so send them to the affilo_admin area
	    	echo "<script>window.location = '" . admin_url('admin.php?page=affilo_admin&updateComplete=1') ."';</script>";
	    	echo "<br><br>Click <a href='" . admin_url('admin.php?page=affilo_admin&updateComplete=1') ."'>here</a> to start using the new version";
		}
		return $return;
	}


	function _tmpStyles($delete = false) {
		$path = get_template_directory();
		$tmpStyles = dirname($path) . '/style.css';
		if ($delete) {
			if (file_exists($tmpStyles) && @file_get_contents($tmpStyles) == '') {
				@unlink($tmpStyles);
			}
		} else {
			if (!file_exists($tmpStyles)) {
				@touch($tmpStyles);
			}
		}
	}

	/*
	  The theme name will either be affilotheme_2 or affilotheme_2/affilotheme_2
	  This depend on if they are using the OLD structure, or the new structure
	  If they are using the old, we must have a name of affilotheme_2/affilotheme_2
	  For it to properly remove the old folder.

	  From that point on, they should be using the new structure
	*/
	function setThemeName() {
		if (file_exists(get_theme_root() . '/affilotheme_2/affilotheme_2/style.css')) {
			$this->theme = 'affilotheme_2/affilotheme_2';
		} else {
			$this->theme = 'affilotheme_2';
		}
	}

}

global $affilo_upgrade;

$affilo_upgrade = new affilo_upgrade;


function affilo_changelog() {
	global $affilo_upgrade;
	if ( ! current_user_can( 'update_themes' ) )
		wp_die( __( 'You do not have sufficient permissions to update themes for this site.' ) );

	$changelog = $affilo_upgrade->requestChangelog();

	$update_url = wp_nonce_url('update.php?action=upgrade-theme&amp;theme=' . get_stylesheet(), 'upgrade-theme_' . get_stylesheet());
	$update_onclick = __('Updating this theme will lose any customizations you have made.  \'Cancel\' to stop, \'OK\' to update.', 'affilo');
?>

	<div class="wrap">
	    <div id="icon-tools" class="icon32"><br/></div>

	    <h2><?php _e( 'AffiloTheme Update Information', 'affilo'); ?></h2>
	    <h4>Current Version: <i><?php echo AFFILO_VERSION;?></i></h4>

	    <div id="poststuff" class="metabox-holder">
		    <div id="post-body" class="has-sidebar">

			    <?php if($changelog): ?>

			    <h2>Latest Update <a class="button-primary affilo-update-latest-version" href="<?php echo $update_url; ?>" onclick="if ( confirm('<?php echo esc_js( $update_onclick ); ?>') ) {return true;}return false;">Update Now</a></h2>
			    <h4>Version <?php echo $changelog['version'];?>, Release Date: <i><?php echo $changelog['date'];?></i></h4>
				<div class="afflo-latest-version">
			    	<?php echo $changelog['details'];?>
			    </div>

			    <h2>Version History</h2>
			    <div class="afflo-previous-version">
			    	<?php echo $changelog['history'];?>
			    </div>
				<?php
				else:
					affilo_render_error('Update information not currently available.');
				endif;
				?>
			</div>
    	</div>
    </div>
    <style type="text/css">
    	#post-body {
			max-width:960px;
    	}
    </style>
	<?php



}

?>