<?php
/**
 * Affilo Slideshows
 *
 * Feature image content using Javascript-powered slideshows. Each slideshow can be customized to suit your needs.
 * This plugin creates a custom post type called Slideshows which integrates with the Media Library.
 * To embed a slideshow into a post or page, simply insert [slideshow id=""] anywhere in the post, page or widget content.
 *
 * @package Affilo
 * @subpackage Widgets
 * @since Affilo 2.4.8
 * @author Joel Jcuzmarski
 * @link http://www.joelak.com
 * @version 4.0.8
 */

// Check to see if current theme supports slideshows
if (!current_theme_supports( 'affilo-slideshows' )) return;

// Define Globals
global $wpdb, $affilo_slideshow_slides, $affilo_slideshow_used_ids, $affilo_slideshow_footer_javascript, $affilo_slideshow_interface;

$affilo_slideshow_slides = $affilo_slideshow_used_ids = array();
$affilo_slideshow_footer_javascript = '';
$affilo_slideshow_interface = apply_filters( 'affilo_slideshow_interface', array( 
	'transitions' 		=> array( 'sliceDown', 'sliceDownLeft', 'sliceUp', 'sliceUpLeft', 'sliceUpDown', 'sliceUpDownLeft', 'fold', 'fade' ),
	'controls' 		=> array( 
						'arrows' 		=> __( 'Show Overlay Arrows', 'affilo' ), 
						'navigation' 	=> __( 'Show Bottom Navigation', 'affilo' ) ),
	'ssorris' 		=> array( 
						'slideshow_on' 		=> __('Slideshow', 'affilo'), 
						'slideshow_off' 	=> __('Random Image', 'affilo')  ),
	'sizes' 			=> array( 
						'max' 	=> __( 'Largest Image', 'affilo' ), 
						'min' 	=> __( 'Smallest Image', 'affilo' ), 
						'custom' 	=> __( 'Custom', 'affilo' ) ),
	'link_text' 		=> 'http://',
	'pause' 			=> 3000,
	'opacity'			=> 0.8,
	'color' 			=> '#FFFFFF',
	'slide_width' 		=> 300,
	'slide_height' 	=> 188,
	'filter_width'		=> 60,
	'filter_height' 	=> 60,
	'mime_types' 		=> array( 'image/jpeg', 'image/png', 'image/gif' ) ) );
	
$affilo_slideshow_interface['mysql_select'] = "SELECT ID, post_date, post_content, post_excerpt, post_mime_type FROM $wpdb->posts WHERE 
	post_type = 'attachment' AND post_status != 'trash' AND
	post_mime_type = '" . implode( "' OR post_mime_type='", $affilo_slideshow_interface['mime_types'] ) . "'";
/*
 * Use add_filter('affilo_slideshow_interface', 'your_filter_function'); to filter interface options for a custom player
 * Filters used for implimenting a custom player located in affilo_slideshow_shortcode():
 *	add_filter('affilo_slideshow_footer_javascript', 'your_filter_function', 10, 5); // your filter function should expect 5 parameters
 *	add_filter('affilo_slideshow_result', 'your_filter_function', 10, 5); // your filter function should expect 5 parameters
 * Actions used for replacing nivo scripts/styles:
 *	add_action('affilo_slideshow_enqueue', 'your_custom_enqueues_function'); // is executed at template_redirect, replaces default enqueues
 *	add_action('affilo_slideshow_wp_head', 'your_custom_script_and_style'); // a controlled way of adding to the head for the custom player
 */

// Utility: Verify Post Type
function affilo_slideshow_verify_post_type() {
	global $post_type;
	
	if (isset( $_GET['post_type'] ) && $_GET['post_type'] == 'slideshow'
		|| isset( $post_type ) && $post_type == 'slideshow') return true; // return true if on a slideshow page
		
	return false;
}

// Utility: Generate Shortcode Input
function affilo_slideshow_embed_input( $post_id ) {
	return '<input class="text urlfield" readonly="readonly" 
		value="[slideshow id=&quot;' . $post_id . '&quot;]" type="text">';
}

// Utility: Sort Slides
function affilo_slideshow_slide_sort( $a, $b ) {
	if ($a['order'] == $b['order']) return 0;
	return ($a['order'] < $b['order'] ? -1 : 1);
}

// Utility: Verify Slideshow ID
function affilo_slideshow_verify_id( $id ) {
	global $affilo_slideshow_used_ids;
	
	while (in_array( $id, $affilo_slideshow_used_ids )) $id++;
	
	array_push( $affilo_slideshow_used_ids, $id );
	
	return $id;
}

// Utility: Generate A Checkbox
function affilo_slideshow_checkbox( $value, $key, $name, $checked = array() ) {
	return '<input type="checkbox" name="affilo_' . $name . '[]" id="' . $name . '_' . $value . '" 
		value="' . $value . '"' . (in_array( $value, (array)$checked ) ? 'checked="checked"' : '') . ' /> 
		<label for="' . $name . '_' . $value . '">' . $key . '</label><br />';
}

// Utility: Generate A Radio Select
function affilo_slideshow_radio( $value, $key, $name, $checked = '' ) {
	return '<input type="radio" name="affilo_' . $name . '" id="' . $name . '_' . $value . '" 
		value="' . $value . '"' . ($value == $checked ? 'checked="checked"' : '') . ' /> 
		<label for="' . $name . '_' . $value . '">' . $key . '</label><br />';
}

// Plugin Initialization
function affilo_slideshow_init() {	
	// Add custom post type
	register_post_type( 'slideshow', array(
		'labels' 				=> array(
								'name' 				=> _x('Slideshows', 'post type general name'),
								'singular_name' 		=> _x('Slideshow', 'post type singular name'),
								'add_new' 			=> _x('Add New', 'affilo' ),
								'add_new_item' 		=> __( 'Add New Slideshow', 'affilo' ),
								'edit_item' 			=> __( 'Edit Slideshow', 'affilo' ),
								'new_item' 			=> __( 'New Slideshow', 'affilo' ),
								'view_item' 			=> __( 'View Slideshow', 'affilo' ),
								'search_items' 		=> __( 'Search Slideshows', 'affilo' ),
								'not_found' 			=> __( 'No slideshows found', 'affilo' ),
								'not_found_in_trash' 	=> __( 'No slideshows found in Trash', 'affilo' ), 
								'parent_item_colon' 	=> '' ),
		'label' 				=> __( 'Slideshows', 'affilo' ),
		'singular_label' 		=> __( 'Slideshow', 'affilo' ),
		'public' 				=> true,
		'exclude_from_search' 	=> true,
		'show_ui' 			=> true,
		'capability_type' 		=> 'post',
		'hierarchical' 		=> false,
		'rewrite' 			=> array( 
								'slug' 		=> 'slideshows', 
								'with_front' 	=> false ),
		'query_var' 			=> true,
		'supports' 			=> array( 'title' ),
		'menu_position' 		=> 5,
		'show_in_nav_menus' 	=> false,
		'register_meta_box_cb' 	=> 'affilo_slideshow_meta_box_callback' ));
}
add_action( 'init', 'affilo_slideshow_init' );

// Callback From register_post_type In affilo_slideshow_init
function affilo_slideshow_meta_box_callback() {
	global $wpdb, $affilo_slideshow_interface, $affilo_slideshow_slides;
	
	affilo_slideshow_slides( $affilo_slideshow_interface['mysql_select'] ); // push slides
	
	// Add custom meta boxes to custom post type
	add_meta_box( 'affilo_slides', __( 'Slides', 'affilo' ), 'affilo_slideshow_slides_meta', 'slideshow', 'normal', 'low' );
	add_meta_box( 'affilo_library', __( 'Media Library', 'affilo' ), 'affilo_slideshow_library_meta', 'slideshow', 'normal', 'low' );
	add_meta_box( 'affilo_shortcode', __( 'Shortcode', 'affilo' ), 'affilo_slideshow_shortcode_meta', 'slideshow', 'side', 'low' );
	add_meta_box( 'affilo_slide_options', __( 'Options', 'affilo' ), 'affilo_slideshow_options_meta', 'slideshow', 'side', 'low' );
}

// Output "Slides" Meta Box
function affilo_slideshow_slides_meta() {
	echo '<input type="hidden" name="affilo_noncename" id="affilo_noncename" 
		value="' . wp_create_nonce( plugin_basename( __FILE__ ) ) . '" />'; // security nonce
		
	affilo_slideshow_meta_box( 'slides' );
}

// Output "Media Library" Meta Box
function affilo_slideshow_library_meta() {
	global $affilo_slideshow_interface, $affilo_slideshow_slides;
	
	$mime_types = $years = $months = array();
	foreach( $affilo_slideshow_slides as $slide ) {
		if (!in_array( $type = $slide['attachment']['type'], $mime_types )) array_push( $mime_types, $type );		
		if (!in_array( $year = $slide['attachment']['year'], $years )) array_push( $years, $year );
		if (!in_array( $month = $slide['attachment']['month'], $months )) array_push( $months, $month );
		if (!isset( $month_years[$month] )) $month_years[$month] = array();
		if (!in_array( $year = 'y' . $year, $month_years[$month] )) array_push( $month_years[$month], $year );
	}
	
	sort( $years, SORT_NUMERIC );
	sort( $months, SORT_NUMERIC );
	
	affilo_slideshow_meta_box( 'library' );
?>
	<div id="libraryFilters">
		<div> <em><?php _e( 'Library Filters', 'affilo' ); ?></em> </div>
		<div class="filterGroup"> <a href="#" id="clear-filters"><?php _e( 'Clear', 'affilo' ); ?></a> </div>
		<div class="filterGroup">
			<label for="filter_year"> <?php _e( 'Year', 'affilo' ); ?>: </label>
			<select id="filter_year">
				<option value="all">&infin;&nbsp;</option>
				<?php foreach ($years as $year) : ?>
				<option value="<?php echo $year; ?>"><?php echo $year; ?></option>
				<?php endforeach; ?>
			</select>
			<label for="filter_month">&nbsp;<?php _e( 'Month', 'affilo' ); ?>: </label>
			<select id="filter_month">
				<option value="all">&infin;&nbsp;</option>
				<?php foreach ($months as $month) : ?>
				<option value="<?php echo $month; ?>" class="<?php echo implode( ' ', $month_years[$month] ); ?>"><?php echo $month; ?></option>
				<?php endforeach; ?>
			</select>
		</div>
		<div class="filterGroup">
			<label for="filter_type"> <?php _e( 'Media Type', 'affilo' ); ?>: </label>
			<select id="filter_type">
				<option value="all">&infin;&nbsp;</option>
				<?php foreach ($mime_types as $type) : ?>
				<option value="<?php echo $type; ?>"><?php echo $type; ?></option>
				<?php endforeach; ?>
			</select>
		</div>
		<div class="filterGroup">
			<label for="filter_width_ltgt"> <?php _e( 'Width', 'affilo' ); ?>: </label>
			<select id="filter_width_ltgt">
				<option value="gt"><?php _e( 'greater than', 'affilo' ); ?>&nbsp;</option>
				<option value="lt"><?php _e( 'less than', 'affilo' ); ?></option>
			</select>
			<input type="text" id="filter_width" class="pixelfield" 
				value="<?php echo $affilo_slideshow_interface['filter_width']; ?>" /><code>px</code>
			<label for="filter_height_ltgt">&nbsp;<?php _e( 'Height', 'affilo' ); ?>: </label>
			<select id="filter_height_ltgt">
				<option value="gt"><?php _e( 'greater than', 'affilo' ); ?>&nbsp;</option>
				<option value="lt"><?php _e( 'less than', 'affilo' ); ?></option>
			</select>
			<input type="text" id="filter_height" class="pixelfield" 
				value="<?php echo $affilo_slideshow_interface['filter_height']; ?>" /><code>px</code>
		</div>
	</div>
	<div id="uploaddiv"> <a title="Upload a file" id="uploadlink" class="button" href="#"><?php _e( 'Add New', 'affilo' ); ?></a> <span id="uploadresult"></span> </div>
<?php
}

// Output "Shortcode" Meta Box
function affilo_slideshow_shortcode_meta() {
	global $post;
	echo affilo_slideshow_embed_input( $post->ID );
}

// Output "Options" Meta Box
function affilo_slideshow_options_meta() {
	global $post, $affilo_slideshow_interface;
	
	$pause = get_post_meta( $post->ID, 'pause', true );
	$opacity = get_post_meta( $post->ID, 'opacity', true );
	$effect = get_post_meta( $post->ID, 'effect', true );
	$control = get_post_meta( $post->ID, 'control', true );
	$size = get_post_meta( $post->ID, 'size', true );
	$size_custom = get_post_meta( $post->ID, 'size_custom', true );
	$ssorri = get_post_meta($post->ID, 'ssorri', true);
?>
	
    <p><strong><?php _e('Shortcode Output', 'affilo'); ?></strong></p>
    <p><?php _e('Should slides be used for a slideshow or single, random image?', 'affilo'); ?></p>
    <p id="slideshow_radio_buttons">
    <?php //foreach($slideshow_or_random_image as $key => $value) { echo affilo_slideshow_radio($key, $value, 'ssorri', ($ssorri == '' ? 'slideshow_on' : $ssorri)); } ?>
    <?php foreach ($affilo_slideshow_interface['ssorris'] as $key => $value) echo affilo_slideshow_radio( $key, $value, 'ssorri', ($ssorri == '' ? 'slideshow_on' : $ssorri) ); ?>
    </p>
    
	<p><strong><?php _e( 'Slideshow Size', 'affilo' ); ?></strong></p>
	<p id="size_radio_buttons">
	<?php foreach ($affilo_slideshow_interface['sizes'] as $key => $value) echo affilo_slideshow_radio( $key, $value, 'size', ($size == '' ? 'min' : $size) ); ?>
	<span id="custom_size" class="hide-if-js">
	<label for="custom_width"><?php _e( 'Width', 'affilo' ); ?></label> 
		<input type="text" id="custom_width" class="pixelfield" name="affilo_size_custom[width]" 
			value="<?php echo (isset($size_custom['width']) ? $size_custom['width'] : ''); ?>" /> <code>px</code> 
	<label for="custom_height"><?php _e( 'Height', 'affilo' ); ?></label> 
		<input type="text" id="custom_height" class="pixelfield" name="affilo_size_custom[height]" 
			value="<?php echo (isset($size_custom['height']) ? $size_custom['height'] : ''); ?>" /> <code>px</code>
	</span>
	</p>
	<div id="slideshow_on_options">
	<p><strong><?php _e( 'Pause Timer', 'affilo' ); ?></strong></p>
	<p><?php _e( 'How long, in miliseconds, to pause on a slide before transitioning.', 'affilo' ); ?></p>
	<p><input type="text" size="4" name="affilo_pause" 
		value="<?php echo ($pause == '' ? $affilo_slideshow_interface['pause'] : $pause); ?>" /> <code><?php _e( 'miliseconds', 'affilo' ); ?></code></p>
		
	<p><strong><?php _e( 'Caption Opacity', 'affilo' ); ?></strong></p>
	<p><?php _e( 'How opaque to make the slide caption.', 'affilo' ); ?></p>
	<p><input type="text" size="4" name="affilo_opacity" 
		value="<?php echo ($opacity == '' ? $affilo_slideshow_interface['opacity'] : $opacity); ?>" /> <code><?php _e( '1 = 100%. Default: 0.8.', 'affilo' ); ?></code></p>
<?php
	if( isset( $affilo_slideshow_interface['transitions'] ) && 
		is_array( $affilo_slideshow_interface['transitions'] ) && 
		count( $affilo_slideshow_interface['transitions'] ) > 0 ) :
?>
		<p><strong><?php _e( 'Transition Effects', 'affilo' ); ?></strong></p>
		<p><?php _e( 'If no transition effect is checked, all effects will be used at random.', 'affilo' ); ?></p>
		<p><?php foreach ($affilo_slideshow_interface['transitions'] as $option) echo affilo_slideshow_checkbox( $option, $option, 'effect', $effect ); ?></p>
<?php
	endif;
	
	if( isset( $affilo_slideshow_interface['controls'] ) && 
		is_array( $affilo_slideshow_interface['controls'] ) && 
		count( $affilo_slideshow_interface['controls'] ) > 0 ) :
?>
		<p><strong><?php _e( 'Show', 'affilo' ); ?></strong></p>
		<p><?php foreach ($affilo_slideshow_interface['controls'] as $key => $value) 
			echo affilo_slideshow_checkbox( $key, $value, 'control', ($control == '' ? $key : $control) ); ?></p>
        </div>    
<?php
	endif;
}

// Output "Slides" OR "Media Library" Meta Boxes
function affilo_slideshow_meta_box( $box ) {
	global $affilo_slideshow_slides;
?>
	<div class="scrollingContainer">
		<div class="scrollingHotSpotLeft"></div><div class="scrollingHotSpotRight"></div>
		<ul class="connectedSortable">
<?php 
		foreach( $affilo_slideshow_slides as $index => $slide ) {
			if ($slide['box'] == $box) affilo_slideshow_sortable_item( $index );
		}
?>
		</ul>
	</div>
<?php
}

// Push Attachments Onto Global Slide Array And Return Added Indexes
function affilo_slideshow_slides( $sql ) {
	global $wpdb, $post, $affilo_slideshow_interface, $affilo_slideshow_slides;
	
	$slides = get_post_meta( (!isset( $post->ID ) ? $_POST['id'] : $post->ID), 'slide', false ); // set single (third parameter) to false to pull ALL records with key "slide"
	
	$attachments = $wpdb->get_results( $wpdb->prepare( $sql ) );
	
	// push all image attachments info into array
	$indexes = array();
	foreach( $attachments as $attachment ) {
		array_push( $indexes, count( $affilo_slideshow_slides ) );
		
		$box = 'library';
		$order = '';
		foreach( $slides as $slide ) {
			if( $slide['attachment_id'] == $attachment->ID ) {
				$box = 'slides'; 
				$order = $slide['order'];
				break;
			}
		}
		
		$metadata = wp_get_attachment_metadata( $attachment->ID );
		
		array_push( $affilo_slideshow_slides, array(
			'box' 			=> $box,
			'order'			=> $order,
			'attachment'		=> array(
								'id' 	=> $attachment->ID,
								'year' 	=> mysql2date( 'Y', $attachment->post_date ),
								'month' 	=> mysql2date( 'm', $attachment->post_date ),
								'width'	=> $metadata['width'],
								'height' 	=> $metadata['height'],
								'type' 	=> $attachment->post_mime_type,
								'link'	=> $attachment->post_excerpt,
								'content'	=> $attachment->post_content ),
			'image' 			=> affilo_post_image( $affilo_slideshow_interface['slide_width'], $affilo_slideshow_interface['slide_height'], NULL, 1, array( 
								'image_id' 	=> $attachment->ID, 
								'echo' 		=> false, 
								'alt' 		=> 'Sortable Image', 
								'title' 		=> 'Click and drag' ) ) ) );
	}
	
	usort( $affilo_slideshow_slides, 'affilo_slideshow_slide_sort' ); // order the elements of the array
	
	return $indexes;
}

// Output A Sortable Item To Be Used In "Slides" OR "Media Library"
function affilo_slideshow_sortable_item( $index ) {
	global $affilo_slideshow_interface, $affilo_slideshow_slides;
	
	$slide = $affilo_slideshow_slides[$index];
	$attachment = $slide['attachment'];
	
	$post = get_post( $attachment['id'] );
	
	if (isset( $_POST['index_offset'] )) $index += $_POST['index_offset']; // required to properly index ajax uploads
?>
	<li id="attachment_id-<?php echo $post->ID; ?>" class="affilo_<?php echo $slide['box']; ?> affilo_item">
		<div class="affilo_right">
			<a href="#" class="move-to-library"><?php _e( 'Remove Slide', 'affilo' ); ?></a>
			<a href="#" class="move-to-slides"><?php _e( 'Add Slide', 'affilo' ); ?></a>
		</div>
		<?php echo $slide['image']; ?>
		<textarea name="slide[<?php echo $index; ?>][post_content]"><?php echo $post->post_content; ?></textarea>
		<label for="slide-link-<?php echo $index; ?>"><?php _e( 'Link to:', 'affilo' ); ?></label>
		<input type="text" class="slide-link" name="slide[<?php echo $index; ?>][post_excerpt]" id="slide-link-<?php echo $index; ?>" 
			value="<?php echo ($post->post_excerpt != '' ? $post->post_excerpt : $affilo_slideshow_interface['link_text']); ?>" />
		<input type="hidden" name="slide[<?php echo $index; ?>][attachment_id]" 
			value="<?php echo $post->ID; ?>" />
		<input type="hidden" name="slide[<?php echo $index; ?>][box]" class="affilo_box" 
			value="<?php echo $slide['box']; ?>" />
		<input type="hidden" name="slide[<?php echo $index; ?>][order]" class="affilo_order" 
			value="<?php echo $slide['order']; ?>" />
	</li>
<?php
}

// Save Custom Data
function affilo_slideshow_save( $post_id ) {
	global $affilo_slideshow_interface;
	
	if (!isset( $_POST['affilo_noncename'] ) || !wp_verify_nonce( $_POST['affilo_noncename'], plugin_basename( __FILE__ ) ) // security check
		|| defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE // avoid auto save routine
		|| 'page' == $_POST['post_type'] && !(current_user_can( 'edit_page', $post_id ) || current_user_can( 'edit_post', $post_id )) // check permissions
		|| !affilo_verify_post_type('slideshow')) return $post_id; // verify post type
	
	delete_post_meta( $post_id, 'slide' ); // flush all post meta entries with "slide" as their key
	
	// initialize default min and max image sizes
	$image_size = array( 
		'min' 	=> array( 
					'width' 	=> 1000, 
					'height' 	=> 1000 ),
		'max' 	=> array( 
					'width' 	=> 100, 
					'height' 	=> 100 ) );
	
	foreach( $_POST['slide'] as $slide ) {
		// update attachment details for any slide
		wp_update_post( array( 
			'ID' 			=> $slide['attachment_id'], 
			'post_excerpt' 	=> apply_filters( 'affilo_pre_link_url', 
								($slide['post_excerpt'] != $affilo_slideshow_interface['link_text'] ? $slide['post_excerpt'] : '') ),
			'post_content'		=> apply_filters( 'affilo_link_description', $slide['post_content'] ) ) );
		
		if ($slide['box'] == 'library') continue; // stop here if slide is from library
		
		// create a post meta record with key "slide" to hold this slide's details
		add_post_meta( $post_id, 'slide', array( 
			'attachment_id' 	=> $slide['attachment_id'], 
			'order' 			=> $slide['order'] ) );
		
		// from here on is just doing some checks to figure out the max and min image heights and widths
		$image = wp_get_attachment_image_src( $slide['attachment_id'], 'full' );
		
		// min
		if ($image[1] < $image_size['min']['width']) $image_size['min']['width'] = $image[1];
		if ($image[2] < $image_size['min']['height']) $image_size['min']['height'] = $image[2];
			
		// max
		if ($image[1] > $image_size['max']['width']) $image_size['max']['width'] = $image[1];
		if ($image[2] > $image_size['max']['height']) $image_size['max']['height'] = $image[2];
	}
	
	// update post meta records for all of the options
	update_post_meta($post_id, 'ssorri', $_POST['affilo_ssorri']);
	update_post_meta( $post_id, 'effect', (isset($_POST['affilo_effect']) ? $_POST['affilo_effect'] : null) );
	update_post_meta( $post_id, 'control', $_POST['affilo_control'] );
	update_post_meta( $post_id, 'pause', (is_numeric( $_POST['affilo_pause'] ) ? $_POST['affilo_pause'] : $affilo_slideshow_interface['pause']) );
	update_post_meta( $post_id, 'opacity', (is_numeric( $_POST['affilo_opacity'] ) ? $_POST['affilo_opacity'] : $affilo_slideshow_interface['opacity']) );
	update_post_meta( $post_id, 'size', $_POST['affilo_size'] );
	$size_custom = $_POST['affilo_size_custom'];
	if ($size_custom['width'] == '') $size_custom['width'] = $image_size['min']['width'];
	if ($size_custom['height'] == '') $size_custom['height'] = $image_size['min']['height'];
	update_post_meta( $post_id, 'size_custom', $size_custom );
	update_post_meta( $post_id, 'size_min', $image_size['min'] );
	update_post_meta( $post_id, 'size_max', $image_size['max'] );
	
	return $post_id;
}
add_action( 'save_post', 'affilo_slideshow_save' );

// Handle Shortcode
function affilo_slideshow_shortcode( $atts, $content = NULL ) {
	extract( shortcode_atts( array( 'id' => 0 ), $atts ) );
	
	//This checks whether the post can be viewed by the current user
	$query = new WP_Query(array('post_type'=>'slideshow', "ID" => $id));
	if(!$query->have_posts()) {
		return false;
	}
	
	// get various options stored as post meta records
	$ssorri = get_post_meta($id, 'ssorri', true);
	$effect = get_post_meta( $id, 'effect', true );
	$control = get_post_meta( $id, 'control', true );
	if (!$control) $control = array(); // so the in_array() below doesn't error out
	$pause = get_post_meta( $id, 'pause', true );
	$opacity = get_post_meta( $id, 'opacity', true );
	$size = get_post_meta( $id, 'size', true );
	
	// get the width and height array that corresponds to the chosen slideshow size
	switch( $size ) {
		case 'max':
			$dimensions = get_post_meta( $id, 'size_max', true );
		break;
		case 'custom':
			$dimensions = get_post_meta( $id, 'size_custom', true );
		break;
		case 'min':
		default:
			$dimensions = get_post_meta( $id, 'size_min', true );
		break;
	}
	
	if($ssorri == 'slideshow_on'){
	
	// get and sort all slides stored as post meta records
	$slides = get_post_meta( $id, 'slide', false ); // set single (third parameter) to false to pull ALL records with key "slide"
	usort( $slides, 'affilo_slideshow_slide_sort' ); // order the elements of the array
	
	// add javascript to be output in the footer (safer than outputing in the content area)
	global $affilo_slideshow_footer_javascript, $affilo_slideshow_interface;
	$id = affilo_slideshow_verify_id( $id ); // need to do this to allow for the same slideshow to be embedded multiple times on one page
	$controlNav = in_array( 'navigation', $control );
	$affilo_slideshow_footer_javascript .= apply_filters(
		'affilo_slideshow_footer_javascript', 
		'$("#slider-' . $id . '").nivoSlider({
			effect:"' . ($effect == '' ? 'random' : implode( ',', $effect )) . '",
			pauseTime:' . ($pause == '' ? $affilo_slideshow_interface['pause'] : $pause) . ',
			captionOpacity: ' . ($opacity == '' ? $affilo_slideshow_interface['opacity'] : $opacity) . ',
			directionNav:' . (in_array( 'arrows', $control ) ? 'true' : 'false') . ',
			controlNav:' . ($controlNav ? 'true' : 'false') . '
		});', $id, $effect, $pause, $control, $opacity );
	
	// create the code for the slideshow
	$result = '';
	$result .= '<div class="slider-wrapper' . ($controlNav ? ' with-controlNav' : '') . '" style="width:' . $dimensions['width'] . 'px;">
		<div class="slider" id="slider-' . $id . '">';
	foreach( $slides as $slide ) {
		$attachment = get_post( $slide['attachment_id'] );
		$description = $attachment->post_content;
		if ($attachment->post_excerpt != '') $result .= '<a href="' . $attachment->post_excerpt . '">';
		$result .= affilo_post_image( $dimensions['width'], $dimensions['height'], NULL, 1, array( 
			'image_id' 	=> $slide['attachment_id'], 
			'title' 		=> $description, 
			'alt' 		=> $description,
			'echo' 		=> false ) );
		if ($attachment->post_excerpt != '') $result .= '</a>';
	}
	$result .= '</div></div>';
	
	return apply_filters( 'affilo_slideshow_result', $result, $id, $dimensions, $control, $slides ); // finally, output the resulting code
	
	} else {
		$slides = get_post_meta($id, 'slide', false);
	//usort($slides, 'affilo_slide_sort'); // order the elements of the array
	$total = count($slides); 
	$random = (mt_rand()%$total);
	$slide = $slides[$random];
	
	$result = '';
	$result .= '<div class="slider_wrapper" style="width:' . $dimensions['width'] . 'px">';
	$result .= affilo_post_image( $dimensions['width'], $dimensions['height'], null, 1, array( 'image_id' => $slide['attachment_id'], 'title' => strip_tags($slide['caption']), 'alt' => strip_tags($slide['caption']), 'echo' => false ) );
	
	$result .= '<span class="slide_caption">'.$slide['caption'].'</span>';
	$result .= '</div>';
	
	$result .= '';
	
	return $result;
	}
}
add_shortcode( 'slideshow', 'affilo_slideshow_shortcode' );

// Add Custom Management Columns
function affilo_slideshow_columns( $columns ) {
	unset( $columns['date'] ); // remove date column
	$columns['id'] = 'ID';
	$columns['shortcode'] = 'Shortcode';
	$columns['date'] = 'Date'; // add date column back, at the end
	
	return $columns;
}
add_filter( 'manage_edit-slideshow_columns', 'affilo_slideshow_columns', 10, 1 );

// Handle Custom Management Columns
function affilo_slideshow_custom_columns( $column, $post_id ) {	
	switch( $column ) {
		case 'id':
			echo $post_id;
		break;
		case 'shortcode':
			echo affilo_slideshow_embed_input( $post_id );
		break;
	}
}
add_action( 'manage_slideshow_posts_custom_column', 'affilo_slideshow_custom_columns', 10, 2 );

// Filter Slideshow Post Content (for when visiting a slideshow's public URL)
function affilo_slideshow_content_filter( $content ) {
	global $post;
	
	if( $post->post_type == 'slideshow' )
		return '[slideshow id="' . $post->ID . '"]';
	else
		return $content;
}
add_filter( 'the_content', 'affilo_slideshow_content_filter' );

// Add Scripts To Head On Front End Only
function affilo_slideshow_template_redirect() {
	wp_enqueue_script( 'jquery' );
	
	if( has_action( 'affilo_slideshow_enqueue' ) ) { // allow default enqueues to be replaced
		do_action( 'affilo_slideshow_enqueue' );
	} else {
		wp_enqueue_script( 'nivoslider' );
		wp_enqueue_style( 'nivo_slider' );
		wp_enqueue_style( 'nivo_custom' );
	}
}
add_action( 'template_redirect', 'affilo_slideshow_template_redirect' );

// Exclusively Output In Head On Front End
function affilo_slideshow_wp_head() {
	do_action( 'affilo_slideshow_wp_head' ); // allow for a safe place to add to the head
}
add_action( 'wp_head', 'affilo_slideshow_wp_head' );

// Add Javascript To Footer On Front End Only
function affilo_slideshow_footer_javascript() {
	global $affilo_slideshow_used_ids, $affilo_slideshow_footer_javascript;
	
	if (empty( $affilo_slideshow_used_ids )) return; // don't add javascript to footer if there are no slideshows
?>
	<script type="text/javascript">
	//<![CDATA[
	;(function($) {
		$(document).ready(function(){
<?php
			echo $affilo_slideshow_footer_javascript;
?>
			// center any existing nivo control navs
			$('.with-controlNav').each(function( index, value ) {
				ctrlnav = $('.nivo-controlNav', this);
				ctrlnav.css('left', ($(this).width() - ctrlnav.width()) / 2);
			});
		});
	})(jQuery);
	//]]>
	</script>
<?php
}
add_action( 'wp_footer', 'affilo_slideshow_footer_javascript' );

// Add Plugin Javascript To Head On Back End Post Pages
function affilo_slideshow_post_admin_print_scripts() {
	// enqueue scripts
	wp_enqueue_script( 'jquery-ui-core' );
	wp_enqueue_script( 'jquery-ui-sortable' );
	wp_enqueue_script( 'jquery-ui-widget' );
	wp_enqueue_script( 'jquery-ajaxuploader', SCRIPTS_URL . '/jquery.ajaxupload.js' );
}
add_action( 'admin_print_scripts-post.php', 'affilo_slideshow_post_admin_print_scripts' );
add_action( 'admin_print_scripts-post-new.php', 'affilo_slideshow_post_admin_print_scripts' );

// Add Plugin Javascript And Style To Head On Back End Post Pages
function affilo_slideshow_post_admin_head() {
	global $post, $affilo_slideshow_interface, $affilo_slideshow_slides;
	
	$attachments = array();
	foreach ($affilo_slideshow_slides as $slide) array_push( $attachments, $slide['attachment'] );
	
	if (!affilo_slideshow_verify_post_type()) return; // verify post type
?>
	<script type="text/javascript">
		//<![CDATA[
		;(function($) {
			$(document).ready(function(){
				var attachments = <?php echo json_encode( $attachments ); ?>
				// sortable container resize
				function container_resize() {
					$.each(['#affilo_slides', '#affilo_library'], function( index, obj ) {
						$(obj).removeClass( 'closed' ); // make sure meta box is opened before calculating width
						var sortable = $('ul.connectedSortable', obj);
						sortable.outerWidth( ($('li.affilo_item:visible', sortable).length + 1) * $('li.affilo_item:visible:first', sortable).outerWidth() );
						$('div.scrollingHotSpotLeft, div.scrollingHotSpotRight', obj).outerHeight( sortable.outerHeight() );
					});
					
					checkScrollPos();
				}
				container_resize(); // initial sizing
				
				// update hidden sortable inputs
				function hidden_inputs() {
					$('#affilo_slides ul.connectedSortable li').each(function(index) {
						$('.affilo_order', this).val( index );
					});
					$('#affilo_slides ul.connectedSortable li .affilo_box').val( 'slides' );
					$('#affilo_library ul.connectedSortable li .affilo_box').val( 'library' );
				}
				
				// prepend an item to a box
				function prepend_to( location, affilo_item ) {
					var sortable = $('#affilo_' + location + ' ul.connectedSortable');
					sortable.parent().stop().animate({ scrollLeft: 0 }, 'slow'); // alternative: sortable.outerWidth() - $(this).scrollLeft()
					affilo_item = $(affilo_item); // force object
					affilo_item.fadeOut('fast', function() {
						affilo_item.prependTo( sortable ); // alternative: append
						affilo_item.fadeIn('slow');
						filter_library();
						container_resize();
						hidden_inputs();
					});
				}
				
				// move sortable item via add/remove link
				$('.move-to-library').live('click', function() {
					prepend_to( 'library', $(this).parent('div.affilo_right').parent('li.affilo_item') );
					return false;
				});
				$('.move-to-slides').live('click', function() {
					prepend_to( 'slides', $(this).parent('div.affilo_right').parent('li.affilo_item') );
					return false;
				});
	
				// connected sortable lists
				$('#affilo_slides ul.connectedSortable, #affilo_library ul.connectedSortable').sortable({
					connectWith: '.connectedSortable',
					handle: 'img',
					forceHelperSize: false,
					forcePlaceholderSize: true,
					helper: function( ev, el ) { return $('img', el).clone().width(<?php 
						echo floor( $affilo_slideshow_interface['slide_width'] / 3 ); ?>).height(<?php 
						echo floor( $affilo_slideshow_interface['slide_height'] / 3 ); ?>); },
					placeholder: 'placeholder',
					revert: true,
					cursor: 'move',
					cursorAt: { top: -1, left: <?php echo floor( $affilo_slideshow_interface['slide_height'] / 4.2 ); ?> },
					containment: '#normal-sortables',
					scrollSensitivity: 0,
					tolerance: 'pointer'
				});
				$('#affilo_slides ul.connectedSortable, #affilo_library ul.connectedSortable').bind('sortreceive', function( ev, ui ) {
					filter_library();
					container_resize();
				});
				$('#affilo_slides ul.connectedSortable').bind('sortupdate', function( ev, ui ) {
					hidden_inputs();
				});
				
				// sortable list scrolling
				var interval_id = 0;
				$('div.scrollingHotSpotLeft, div.scrollingHotSpotRight').mouseenter(function() {
					var scrollDiv = $(this).parent();
					var scrollAmount = $('li.affilo_item:first', scrollDiv).outerWidth() * 2;
					scrollAmount *= ($(this).attr('class') == 'scrollingHotSpotLeft' ? -1 : 1);
						
					if( interval_id == 0 ) {
						interval_id = setInterval(function() {
							scrollDiv.stop().animate({ scrollLeft: scrollDiv.scrollLeft() + scrollAmount }, 280);
						}, 400);									
					}
				});
				$('div.scrollingHotSpotLeft, div.scrollingHotSpotRight').mouseleave(function() {
					if( interval_id != 0 ) {
						clearInterval(interval_id);
						interval_id = 0;
					}
				});
				$('div.scrollingContainer').scroll(function() {
					checkScrollPos();
				});
				function checkScrollPos() {
					$('div.scrollingContainer').each(function() {
						var scrollLeft = $(this).scrollLeft();
						var left = $('div.scrollingHotSpotLeft', this);
						var right = $('div.scrollingHotSpotRight', this);
						var sortableW = $('ul.connectedSortable', this).outerWidth();
						var containerW = $(this).outerWidth();
						
						if( sortableW > containerW ) {
							if( scrollLeft == 0 )
								left.fadeOut('slow');
							else
								left.fadeIn('slow');
							
							if( scrollLeft == (sortableW - containerW) )
								right.fadeOut('slow');
							else
								right.fadeIn('slow');						
						} else {
							left.fadeOut('slow');
							right.fadeOut('slow');
						}
					});
				}
				
				// library filtering
				$('div#libraryFilters input').keypress(function( e ) {
					if( e.which == 13 ) {
						e.preventDefault();					
						return false;
					}
				});
				$('div#libraryFilters input').keyup(function() {
					var oldVal = $(this).val();
					var newVal = (!isNaN( parseInt( oldVal, 10 ) ) ? parseInt( oldVal ) : '');	
					newVal = String( newVal ).replace( /[^0-9]/g, '' );
					
					if( newVal == '0' )
						$(this).val( 0 ); 
					else
						$(this).val( newVal );
					
					if (oldVal == '' || oldVal.slice( 0, -1 ) != newVal) filter_library();
				});
				$('div#libraryFilters select').not('select#filter_year').change(function() {
					filter_library();
				});
				// show/hide filter months on year change
				function filterMonthToggle( monthClass ) {
					var monthClass = (monthClass != 'all' ? ', option.y' + monthClass : '');
					$('select#filter_month option').removeAttr( 'selected' ).removeAttr( 'disabled' ).not('option:first' + monthClass).attr( 'disabled', 'disabled' );					
					$('select#filter_month option:first').attr( 'selected', 'selected' );
				}
				$('select#filter_year').change(function() {
					filterMonthToggle( $(this).val() );
					filter_library();
				});
				filterMonthToggle( $('select#filter_year').val() ); // initial month input value
				var stopFiltering;
				function filter_library() {
					stopFiltering = true;
					
					var year = $('#filter_year').val();
					var month = $('#filter_month').val();
					var type = $('#filter_type').val();
					var width_ltgt = $('#filter_width_ltgt').val();
					var width = parseInt( $('#filter_width').val() );
					var height_ltgt = $('#filter_height_ltgt').val();
					var height = parseInt( $('#filter_height').val() );
				
					$(attachments).each(function( index, attachment ) {
						if( index == 0 ) {
							stopFiltering = false;
						} else {
							if (stopFiltering) return false; // stop if mid-way through when a new is filter initiated
						}
											
						slide = $('#affilo_library ul.connectedSortable li#attachment_id-' + attachment.id);
						
						if( slide.length != 0 ) { // check if slide exists
							var hide = false;
							
							if( year != 'all' && attachment.year != year ) hide = true;
							
							if( month != 'all' && attachment.month != month ) hide = true;
							
							if( type != 'all' && attachment.type != type ) hide = true;
							
							attachment.width = parseInt( attachment.width );
							if( typeof width == 'number' && typeof attachment.width == 'number' ) {
								if (width_ltgt == 'lt' && attachment.width > width) hide = true;
								if (width_ltgt == 'gt' && attachment.width < width) hide = true;
							}
							
							attachment.height = parseInt( attachment.height );
							if( typeof height == 'number' && typeof attachment.height == 'number' ) {
								if (height_ltgt == 'lt' && attachment.height > height) hide = true;
								if (height_ltgt == 'gt' && attachment.height < height) hide = true;
							}
							
							if (hide) slide.hide(); else slide.show();
						}
						
						if (index == $(attachments).length-1) container_resize(); // resize container when finished filtering
					});
				}
				filter_library(); // initial filtering
				
				// clear filters
				$('#clear-filters').click(function() {
					$('div#libraryFilters select').each(function( i, v ) {
						$('option:selected', this).removeAttr( 'selected' );
						$('option:first', this).attr( 'selected', 'selected' );
					});
					$('div#libraryFilters input#filter_width').val(<?php echo $affilo_slideshow_interface['filter_width']; ?>);
					$('div#libraryFilters input#filter_height').val(<?php echo $affilo_slideshow_interface['filter_height']; ?>);
					
					filter_library();
					
					return false;
				});
				
				// file upload
				var fid = 'userfile';
				new AjaxUpload($('a#uploadlink'), {
					action: ajaxurl,
					name: fid,
					data: { action: 'affilo_action_handle_upload_ajax', _ajax_nonce: '', file_id: fid },
					responseType: 'json',
					onSubmit: function( file , ext ){
						if( ext && /^(jpg|png|jpeg|gif)$/.test(ext) ) {							
							$('span#uploadresult').html( 'Uploading ' + file + '...' );
						} else {
							// extension is not allowed
							$('span#uploadresult').html( 'Error: Only images are allowed.' );
							return false;	// cancel upload			
						}
					},
					onComplete: function( file, response ){
						if( response.error != '' ) {
							$('span#uploadresult').html( response.error ); // show user the error
						} else {
							$('span#uploadresult').html( '<a href="' + response.full + '" target="_blank" class="previewlink">' + file + '</a> has been uploaded!' );
							
							var offset = $(attachments).length;
							$.post(ajaxurl, { action: 'affilo_slideshow_upload', id: '<?php echo $post->ID; ?>', index_offset: offset }, function(response) {
								attachments[offset] = $.parseJSON( response.object ); // append to attachments array
								addToSelect( 'type', attachments[offset]['type'], null ); // add mime type to filter area if not already present
								
								// add year and month to filter if not already present
								var year = attachments[offset]['year'];									
								addToSelect( 'year', year, null );
								addToSelect( 'month', attachments[offset]['month'], year );
														
								$('select#filter_month option').sort( sortNum ).appendTo( 'select#filter_month' ); // sort the months to make sure they are in order	
								filterMonthToggle( $('select#filter_year').val() ); // enable/disable months based on year value
								prepend_to( 'library', response.html ); // prepend to library
							}, 'json');
						}
					}
				});
				
				// this is retarded but it works for now
				function addToSelect( key, text, year ) {
					sel = 'select#filter_' + key;
					
					var kill = false;
					$(sel + ' option').each(function( i, v ) {
						if ($(this).val() == text) {
							if (year != null) $(this).addClass('y' + year);
							
							kill = true; // not able to add to select, option already exists
						}
					});
					
					if (kill) return false;
										
					if (year != null)
						$('<option>').val( text ).text( text ).addClass('y' + year).appendTo( sel );
					else
						$('<option>').val( text ).text( text ).appendTo( sel );
					
					return true; // option added to select
				}
				
				// custom number sorting funtion
				function sortNum( a, b ){
					if ($(a).val() == 'all') return -1;
					return $(a).val() > $(b).val() ? 1 : -1;
				};
				
				// show/hide custom size
				$('#size_radio_buttons input[type="radio"]').change(function() {
					if( $(this).val() == 'custom' )
						$('#custom_size').show();
					else
						$('#custom_size').hide();
				});
				if( $('#size_radio_buttons input[id="size_custom"]').is(':checked') )
					$('#custom_size').show(); // initial custom size show/hide
					
				// slideshow options view 
				$('#slideshow_radio_buttons input[type="radio"]').change(function() {
					if($(this).val() == 'slideshow_on')
						$('#slideshow_on_options').show();
					else
						$('#slideshow_on_options').hide();
				});
				if( $('#slideshow_radio_buttons input[id="ssorri_slideshow_off"]').is(':checked') )
					$('#slideshow_on_options').hide();	
				
				// slideshow title is required
				$('input#publish, input#save-post, a#post-preview').mousedown(function(e) {
					if( $('input#title').val() == '' ) {
						e.preventDefault();
						$('input#title').focus();
						alert( 'You must enter a title for this slideshow!' );
						return false;
					}
				});
				

				// clear default link
				$('input.slide-link').live('focus', function() {
					if ($(this).val() == '<?php echo $affilo_slideshow_interface['link_text']; ?>') $(this).val( '' );
				});
				$('input.slide-link').live('blur', function() {
					if ($(this).val() == '') $(this).val( '<?php echo $affilo_slideshow_interface['link_text']; ?>' );
				});
			});
		})(jQuery);	
		//]]>
	</script>
	
	<style type="text/css">		
		/* slides and library */
		#affilo_slides div.inside,
		#affilo_library div.inside { position:relative; }
		div.scrollingContainer {
			overflow:auto;
			white-space:nowrap;
			margin:0;
		}
		ul.connectedSortable { width:9999px; overflow:auto; }
		ul.connectedSortable li {
			float:left;
			display:inline;
			position:relative;
			margin:0;
		}
		ul.connectedSortable img { cursor:move;	}
		ul.connectedSortable li,
		.ui-sortable-helper { padding:5px; }
		.placeholder { background:#257DA6 !important; }
		div.affilo_right { position:absolute; top:1px; right:2px; padding:5px 10px; }
		div.affilo_right a { text-decoration:none; }		
		
		/* slides */
		#affilo_slides ul.connectedSortable { 
			min-width:<?php echo $affilo_slideshow_interface['slide_width'] * 2; ?>px; 
			min-height:<?php echo $affilo_slideshow_interface['slide_height'] + 87; ?>px; 
		}
		#affilo_slides.closed ul.connectedSortable { min-height:0; }
		#affilo_slides ul.connectedSortable img { 
			width:<?php echo $affilo_slideshow_interface['slide_width']; ?>px; 
			height:<?php echo $affilo_slideshow_interface['slide_height']; ?>px; 
		}
		#affilo_slides ul.connectedSortable .placeholder { 
			width:<?php echo $affilo_slideshow_interface['slide_width'] + 2; ?>px; 
			height:<?php echo $affilo_slideshow_interface['slide_height'] + 77; ?>px; 
		}
		#affilo_slides ul.connectedSortable textarea {
			width:<?php echo $affilo_slideshow_interface['slide_width']; ?>px;
			height:50px;
			display:block;
		}
		#affilo_slides ul.connectedSortable label { float:left; line-height:32px; width:55px; }
		#affilo_slides ul.connectedSortable .slide-link {
			height:25px;
			margin-top:5px;
			display:block; width:<?php echo $affilo_slideshow_interface['slide_width'] - 54; ?>px;
		}
		#affilo_slides ul.connectedSortable .affilo_right a.move-to-slides { display:none; }
		
		/* library */
		#affilo_library ul.connectedSortable { 
			min-width:<?php echo $affilo_slideshow_interface['slide_width'] * 2; ?>px; 
			min-height:<?php echo ($affilo_slideshow_interface['slide_height'] / 3) + 10; ?>px; 
		}
		#affilo_library ul.connectedSortable img,
		#affilo_library .placeholder {
			width:<?php echo floor($affilo_slideshow_interface['slide_width'] / 3); ?>px;
			height:<?php echo floor($affilo_slideshow_interface['slide_height'] / 3); ?>px;
		}
		#affilo_library ul.connectedSortable textarea,
		#affilo_library ul.connectedSortable label,
		#affilo_library ul.connectedSortable .slide-link,
		#affilo_library ul.connectedSortable .affilo_right a.move-to-library { display:none !important; }
		
		/* scrolling hotspots */
		div.scrollingHotSpotLeft, div.scrollingHotSpotRight {
			display:none;
			width:50px;
			height:100%;
			top:0;
			position:absolute;
			z-index:200;
			background-position:center center;
			background-repeat:no-repeat;
			background-color:#F9F9F9;
			opacity:0.35;
			-moz-opacity:0.35;
			filter:alpha(opacity = 35);
			zoom:1; /* trigger "hasLayout" in Internet Explorer 6 or older */
		}
		div.scrollingHotSpotLeft	{
			left: 0;
			background-image: url(<?php echo IMAGES_URL; ?>/admin/arrow_left.gif);
			cursor: url(<?php echo IMAGES_URL; ?>/admin/cursors/cursor_arrow_left.cur), 
				url(images/cursors/cursor_arrow_left.cur), w-resize;
		}
		div.scrollingHotSpotRight {
			right: 0;
			background-image: url(<?php echo IMAGES_URL; ?>/admin/arrow_right.gif);
			cursor: url(<?php echo IMAGES_URL; ?>/admin/cursors/cursor_arrow_right.cur), 
				url(images/cursors/cursor_arrow_right.cur), w-resize;
		}
		
		/* interface */
		div.scrollingContainer, 
		.ui-sortable-helper, 
		div.affilo_right, 
		ul.connectedSortable li {
			background:<?php echo $affilo_slideshow_interface['color']; ?>;
		}
		input.pixelfield { width:44px; }
		input.urlfield { width:155px; }
		#uploaddiv { position:absolute; top:-29px; left:115px; }
		#uploadresult {padding-left:10px;}
		div#libraryFilters { margin-top:8px; text-align:left; overflow:auto; }
		div#libraryFilters div {
			margin-top:6px;
			line-height:2em;
			white-space:nowrap;
			float:left;
			margin-left:10px;
		}
		div#libraryFilters div em { line-height:2em; display:block; }
		div.filterGroup {
			padding-left:10px;
			border-left:1px solid #EAEAEA;
		}
	</style>
<?php
}
add_action( 'admin_head-post.php', 'affilo_slideshow_post_admin_head' );
add_action( 'admin_head-post-new.php', 'affilo_slideshow_post_admin_head' );

// Add Uploaded File To Library
function affilo_slideshow_upload() {	
	global $affilo_slideshow_interface, $affilo_slideshow_slides;
	
	// create slide array for newest attachment
	$index = affilo_slideshow_slides( $affilo_slideshow_interface['mysql_select'] . ' ORDER BY post_date DESC LIMIT 1' );
	
	ob_start();
	affilo_slideshow_sortable_item( $index[0] );
	$html = ob_get_clean();

	die( json_encode( array( 
		'object' 	=> json_encode( $affilo_slideshow_slides[$index[0]]['attachment'] ), 
		'html' 	=> $html ) ) );
}
add_action( 'wp_ajax_affilo_slideshow_upload', 'affilo_slideshow_upload' );

// Add Plugin Style To Head On Back End Edit Page
function affilo_slideshow_edit_admin_style() {
	if (!affilo_slideshow_verify_post_type()) return; // verify post type
?>
	<style type="text/css">
		th.column-id { width:50px; }
		th.column-shortcode { width:180px; }
		input.urlfield { width:155px; }
	</style>
<?php
}
add_action( 'admin_print_styles-edit.php', 'affilo_slideshow_edit_admin_style' );

?>